version 7.0
set matsize 120
tempfile reg tot

/* Choose Settings */
local choice 3
/* Choice 3: FGV-IPA (and general)  Deflators 86-98 */
if `choice'==3 {local ext "ipa"}
local fdfl 2
/* Choice 2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */

confirm new file "brazprod/data/pia-use-`ext'`fdfl'-output-notrend-fe-3x"

use "brazcomp\data\use-firms-`ext'`fdfl'", clear
keep firm year niv reg uf sales labf*
gen labftot = labfbl + labfwh
label var labftot "Labor Force: Total"
drop labfbl labfwh

gen byte regmix = uf
replace regmix = 10 if int(uf/10)==1
replace regmix = 50 if int(uf/10)==5
replace regmix = 39 if uf==32 | uf==33
replace regmix = 20 if uf==21 | uf==22 | uf==24 | uf==25 | uf==27 | uf==28
replace regmix = . if regmix<10 | regmix>50
drop region uf

rename niv100 nivmix
replace nivmix = 415  if nivmix==410 | nivmix==420
replace nivmix = 1335 if nivmix==1330 | nivmix==1340
replace nivmix = 1515 if nivmix==1510 | nivmix==1520
replace nivmix = 2215 if nivmix==2210 | nivmix==2220
replace nivmix = 2615 if nivmix==2610 | nivmix==2620
replace nivmix = 3015 if nivmix==3010 | nivmix==3020

label var regmix "Headquarter location (Adjstd UF)"
label var nivmix "Sector of Firm (Adjusted Niv100)"

order firm year nivmix regmix sales labftot

egen _regsale = sum(sales),   by(year nivmix regmix)
egen _reglabf = sum(labftot), by(year nivmix regmix)
egen _totsale = sum(sales),   by(year nivmix)
egen _totlabf = sum(labftot), by(year nivmix)

gen mktshreg = sales/_regsale
gen mktshtot = sales/_totsale
gen labshreg = labftot/_reglabf
gen labshtot = labftot/_totlabf
label var mktshreg "Market Share, by region"
label var mktshtot "Market Share, all Brazil"
label var labshreg "Employment Share, by region"
label var labshtot "Employment Share, all Brazil"
drop _* sales labftot


/* Herfindahl indices */

foreach var in mktshreg mktshtot labshreg labshtot {
    gen _sq_`var' = `var'^2
    }
egen herfsalereg = sum(_sq_mktshreg), by(year nivmix regmix)
egen herfsaletot = sum(_sq_mktshtot), by(year nivmix)
egen herflabfreg = sum(_sq_labshreg), by(year nivmix regmix)
egen herflabftot = sum(_sq_labshtot), by(year nivmix)
drop _*

label var herfsalereg "Herfindahl Market Share, by reg"
label var herfsaletot "Herfindahl Market Share, all reg"
label var herflabfreg "Herfindahl Employment, by reg"
label var herflabftot "Herfindahl Employment, all reg"


/* 3-firm and 4-firm concentration indices */

sort year nivmix regmix mktshreg
by year nivmix regmix: gen frm3salereg = mktshreg[_n] + mktshreg[_n-1] + mktshreg[_n-2] if _n==_N
by year nivmix regmix: replace frm3salereg = frm3salereg[_N]
by year nivmix regmix: gen frm4salereg = mktshreg[_n] + mktshreg[_n-1] + mktshreg[_n-2]  + mktshreg[_n-3] if _n==_N
by year nivmix regmix: replace frm4salereg = frm4salereg[_N]
label var frm3salereg "Top 3-firm Market Share, by reg"
label var frm4salereg "Top 4-firm Market Share, by reg"
sort year nivmix mktshtot
by year nivmix: gen frm3saletot = mktshtot[_n] + mktshtot[_n-1] + mktshtot[_n-2] if _n==_N
by year nivmix: replace frm3saletot = frm3saletot[_N]
by year nivmix: gen frm4saletot = mktshtot[_n] + mktshtot[_n-1] + mktshtot[_n-2]  + mktshtot[_n-3] if _n==_N
by year nivmix: replace frm4saletot = frm4saletot[_N]
label var frm3saletot "Top 3-firm Market Share, all reg"
label var frm4saletot "Top 4-firm Market Share, all reg"

sort year nivmix regmix labshreg
by year nivmix regmix: gen frm3labfreg = labshreg[_n] + labshreg[_n-1] + labshreg[_n-2] if _n==_N
by year nivmix regmix: replace frm3labfreg = frm3labfreg[_N]
by year nivmix regmix: gen frm4labfreg = labshreg[_n] + labshreg[_n-1] + labshreg[_n-2]  + labshreg[_n-3] if _n==_N
by year nivmix regmix: replace frm4labfreg = frm4labfreg[_N]
label var frm3labfreg "Top 3-firm Employment, by reg"
label var frm4labfreg "Top 4-firm Employment, by reg"
sort year nivmix labshtot
by year nivmix: gen frm3labftot = labshtot[_n] + labshtot[_n-1] + labshtot[_n-2] if _n==_N
by year nivmix: replace frm3labftot = frm3labftot[_N]
by year nivmix: gen frm4labftot = labshtot[_n] + labshtot[_n-1] + labshtot[_n-2]  + labshtot[_n-3] if _n==_N
by year nivmix: replace frm4labftot = frm4labftot[_N]
label var frm3labftot "Top 3-firm Employment, all reg"
label var frm4labftot "Top 4-firm Employment, all reg"


/* Create sector and region datasets */

drop firm mktsh* labsh*
sort year nivmix regmix
by year nivmix regmix: keep if _n==1
iis, clear
tis, clear
tsset, clear
order year nivmix regmix herf* frm3* frm4*
preserve
    drop herfsaletot herflabftot frm3saletot frm4saletot frm3labftot frm4labftot 
    sort year nivmix regmix
    compress
    save `reg'
restore
    drop herfsalereg herflabfreg frm3salereg frm4salereg frm3labfreg frm4labfreg 
    foreach var in herfsale herflabf frm3sale frm4sale frm3labf frm4labf { rename `var'tot `var'reg }
    replace regmix=0
    sort year nivmix regmix
    by year nivmix: keep if _n==1
    sort year nivmix regmix
    compress
    save `tot'

use `reg', clear
append using `tot'
foreach var in herfsale herflabf frm3sale frm4sale frm3labf frm4labf { rename `var'reg `var' }
label var herfsale "Herfindahl Index Market Share"
label var frm3sale "Top 3-firm Index Market Share"
label var frm4sale "Top 4-firm Index Market Share"
label var herflabf "Herfindahl Index Employment Sh."
label var frm3labf "Top 3-firm Index Employment Sh."
label var frm4labf "Top 4-firm Index Employment Sh."

sort  nivmix regmix year
order nivmix regmix year
compress 
save "brazcomp\data\use-conc-`ext'`fdfl'", replace
