version 7.0
set matsize 120

capture log close
log using "brazcomp\logs\data-char.log", replace
log off

tempfile nivdef ufdef regdef
use "brazcomp\filters\nivdef", clear
    drop if niv100<200
    rename niv100 niv
    sort niv
    save `nivdef'
insheet using "brazcomp\niv-cnae\regions.csv", comma clear
preserve
    rename v1 ufshort
    rename v2 uf
    rename v3 ufdesc
    sort uf
    keep if uf>=10
    order uf ufshort ufdesc
    drop ufshort
    replace ufdesc = trim(ufdesc)
    save `ufdef'
restore
    drop v1
    rename v2 reg
    rename v3 regdesc
    sort reg
    keep if reg<10
    order reg regdesc
    save `regdef'

use "brazcomp\data\use-firms-ipa2", clear
keep firm year niv100 uf reg
rename reg reg
sort firm year
merge firm year using "brazprod\cgc-list\cgc-cnae-96-98", nokeep
drop _merge
compress

/* Drop problem cases */
/*--------------------*/
drop if (cnae<1000 | cnae>9999) & cnae~=.
drop if (niv<200 | niv>9999) & niv~=.
drop if (uf>99) & uf~=.

order firm year niv100 cnae uf
count if (cnae<1000 | cnae>9999) & cnae~=.
if r(N)>0 { keep if (cnae<1000 | cnae>9999) & cnae~=.
            disp in red "Wrong CNAE definition in " in yellow r(N) in red " cases" 
            exit }
count if (niv<200 | niv>9999) & niv~=.
if r(N)>0 { keep if (niv<200 | niv>9999) & niv~=.
            disp in red "Wrong Niv100 definition in " in yellow r(N) in red " cases" 
            exit }
count if (uf>99) & uf~=.
if r(N)>0 { keep if (uf>99) & uf~=.
            disp in red "Inadmissible UF in " in yellow r(N) in red " cases" 
            exit }

rename niv100 niv
replace uf=. if uf>=60 | uf<11
replace reg = int(uf/10)


preserve
foreach crit in niv uf reg {
    restore, preserve
    gen byte _countr=1
    collapse (sum) number=_countr, by(`crit')
    summ number, meanonly
    local total = r(N)*r(mean)
    gen share=number/`total'
    local newobs = r(N)+1
    set obs `newobs'
    qui replace number=`total' in `newobs'
    qui replace `crit'=9999 in `newobs'
    qui replace share=1 in `newobs'
    sort `crit'
    merge `crit' using ``crit'def'
    drop _merge
    order `crit' `crit'd number share
    sort `crit'
    gen str6  _`crit' = string(`crit') + " &"
    gen str80 _`crit'd = substr(`crit'd,1,78) + " &"
    gen str12   _number = string(number) + " &"
    qui replace _number = string(int(number/1000)) + "," + substr(string(number),-3,3) + " &" if number>=1000 & number~=.
    gen str8  _share  = substr(string(int(share*1000)/1000),1,4) + " \" + "\"
    foreach var in `crit' `crit'd number share {
        drop `var'
        rename _`var' `var'
        }      
    compress
    capture outsheet using "c:\texdocs\brazcomp\stata-origs\tab-`crit'.tex", noquote nonames replace
    }
restore


rename niv niv100
rename reg region
gen int niv50 = int(niv100/100)


preserve
    gen byte _countr=1
    log on
    collapse (sum) number=_countr, by(niv100 uf year)
    count if number<3 & number~=0 & uf~=.
    disp "Share of cells with less than 3 firms: " r(N)/_N
    qui tab niv, matcell(freq)
    qui keep niv
    sort niv
    qui by niv: keep if _n==1
    svmat freq, names(cellnum)
    gsort -cellnum
    disp (324-259)/324
    disp (324-58)/324
    list
    log off
restore


gen byte regmix = uf
replace regmix = 10 if int(uf/10)==1
replace regmix = 50 if int(uf/10)==5
replace regmix = 39 if uf==32 | uf==33
replace regmix = 20 if uf==21 | uf==22 | uf==24 | uf==25 | uf==27 | uf==28
tab regmix
drop region uf

preserve
    gen byte _countr=1
    collapse (sum) number=_countr, by(niv100 regmix year)
    log on
    /* Problem cells before sector merge */
    count if number<3 & number~=0 & regmix~=.
    disp "Share of cells with less than 3 firms: " r(N)/_N
    sort niv
    by niv: count if number<3 & number~=0 & regmix~=.
    log off
restore

rename niv100 nivmix
replace nivmix = 415  if nivmix==410 | nivmix==420
replace nivmix = 1335 if nivmix==1330 | nivmix==1340
replace nivmix = 1515 if nivmix==1510 | nivmix==1520
replace nivmix = 2215 if nivmix==2210 | nivmix==2220
replace nivmix = 2615 if nivmix==2610 | nivmix==2620
replace nivmix = 3015 if nivmix==3010 | nivmix==3020

preserve
    gen byte _countr=1
    collapse (sum) number=_countr, by(nivmix regmix year)
    log on
    /* Problem cells after sector merge */
    count if number<3 & number~=0 & regmix~=.
    disp "Share of cells with less than 3 firms: " r(N)/_N
    sort niv
    by niv: count if number<3 & number~=0 & regmix~=.
    log off
restore

drop cnae niv50
label var nivmix "Sector of Firm (Adjusted Niv100)"
label var regmix "Headquarter location (Adjstd UF)"

