version 6.0
/*----------------------------------*/
/* Careful: Set max size to /k64000 */
/*----------------------------------*/

tempfile entry exit agesuc nolink firmhd tmp corryr

/* Create complete file of life characteristics and economic vars */
/*----------------------------------------------------------------*/
use "brazprod\data\life\firms-entry.dta", clear
keep firm first catentry manborn
sort firm
replace first=first-1900
save `entry', replace
use "brazprod\data\life\firms-exit.dta", clear
keep firm last catlife contgrp miss86-miss98
sort firm
save `exit', replace
use "brazprod\cgc-list\cgc-nasc.dta", clear
merge firm using `entry', nokeep
rename firm cgcsuc
rename born existsuc
replace existsuc=first+1900 if existsuc==.
keep cgcsuc existsuc
sort cgcsuc
save `agesuc', replace
use "brazprod\data\pia-emp.dta", clear
merge firm using `entry'
drop _merge
rename first firstyr
sort firm
merge firm using `exit'
drop _merge
rename last lastyr
sort cgcsuc
merge cgcsuc using `agesuc', nokeep
drop _merge
egen minstate=min(state), by(firm)
egen maxstate=max(state), by(firm)
preserve
  keep if minstate>=5 & maxstate<=6
  keep firm
  rename firm cgcsuc
  gen byte indnolnk=1
  sort cgcsuc
  save `nolink', replace
restore
replace catlife=9.99 if minstate>=5
drop minstate maxstate
sort cgcsuc
merge cgcsuc using `nolink', nokeep
drop _merge
sort firm year
quietly by firm year: keep if _n==_N  /* Deletes doubles */
recast byte year
recast byte firstyr
recast byte lastyr
format indnolnk %1.0f
format firstyr lastyr %2.0f
rename manborn effborn
label var indnolnk "Successor Firm Not Alive"
label var existsuc "Founding Year of Succeeding Firm"
label var effborn "Inferred Founding Year"

/* Change of industrial sector */
/*-----------------------------*/
sort firm year
preserve
  keep firm state niv80 year firstyr
  drop if state==9
  keep if year==firstyr
  drop year state firstyr
  save `firmhd', replace
restore
merge firm using `firmhd', update
preserve
  drop if _merge~=5
  drop _merge
  gen byte indsctch=1
  keep firm year indsctch
  sort firm year
  quietly by firm: keep if _n==1
  sort firm
  save `tmp', replace
restore
drop _merge
sort firm
merge firm using `tmp'
label var indsctch "Change of NIV80 Compat. Sector"
format indsctch %1.0f
drop _merge

order firm year state change cgcsuc cgcemp born effborn firstyr lastyr catentry catlife contgrp chmon chyr indcor existsuc indnolnk indsctch miss86 miss87 miss88 miss89 miss90 miss92 miss93 miss94 miss95 miss96 miss97 miss98 sales difstock resales astot asliq aslr aspsum aspinv aspimmo aspmasum aspdefer asrtimmo aslsimmo deprec fincost balsum crtot crstsum crstdom crstfor crltsum crltdom crltfor labftot labftop labfwh labfbl wagetot wagetop wagewh wagebl acqtot acqbl acqmasum acqmadom acqmause acqmafor acqveh acqother acqcomp asltot aslbl aslmasum aslveh aslother aslcomp intmacq intmdif profit niv100 niv80map region uf genero class weight
sort firm year

/* Some reclassifications and error corrections */
/*----------------------------------------------*/
local reps 4
local i 1
gen helper=firstyr-1
while `i'<=`reps' {
    quietly gen indchg=year if (state==8 | state==5) & change==. & born==firstyr+1900 & year==helper+1 & sales==. & catlife~=float(9.99)
    replace state=2 if (state==8 | state==5) & change==. & born==firstyr+1900 & year==helper+1 & sales==. & catlife~=float(9.99)
    replace catlife=0 if contgrp==3 & indchg==year & indchg~=. & catlife~=float(9.99)
    drop helper
    quietly egen helper=max(indchg), by(firm)
    drop indchg
    local i=`i'+1
    }
drop helper
egen catrepl=max(catlife), by(firm)
egen maxstate=max(state), by(firm)
gen nosale=1 if sale==. & catlife~=catrepl
egen nosale1=max(nosale), by(firm)
replace catlife=catrepl if maxstate<=2 & nosale1==.
egen helper=count(catlife), by(firm)
sort firm
quietly by firm: gen onedot=1 if helper<_N
replace catlife=. if onedot==1
drop catrepl maxstate nosale nosale1 helper onedot

gen helper=1 if state>=3 & state<=6
local reps 11
local i 1
while `i'<=`reps' {
    sort firm year
    replace state=5 if state==8 & change==. & indcor~=2 & cgcsuc==. & (cgcemp==firm | cgcemp==.) & (helper[_n-1]==1 | helper[_n+1]==1) & sales==.
    quietly replace helper=1 if state==5 | state==6
    local i=`i'+1
    }
drop helper
/* Note: Apart from these direct reclassifications to state==5, in the further analysis state==5 and (state==8 & change==. & indcor~=2 & cgcsuc==. & (cgcemp==firm | cgcemp==.) & sales==.) will be treated as equivalent */

replace change=2 if change==3 & (state==6 | state==4)
replace change=3 if change==2 & state==1 & sales~=. & (contgrp==1 | contgrp==3)

replace effborn=firstyr+1900 if born>firstyr+1900 & born~=. & catlife==0

/* Inferring region where possible / Correcting wrong entries */
sort firm year
replace region=int(uf/10) if region==. & uf~=.
replace region=. if region==6
local yr 98
while `yr' >= 86 {
    if `yr'==91 {local yr 90}
    replace region=region[_n+1] if (region==0 | region==.) & year==`yr'
    local yr=`yr'-1
    }

/* Inferring niv100 where possible */
sort firm year
local yr 98
while `yr' >= 86 {
    if `yr'==91 {local yr 90}
    replace niv100=niv100[_n+1] if (niv100==0 | niv100==.) & year==`yr'
    local yr=`yr'-1
    }


/* Note: In following, information in cgcemp is never exploited except as additional restriction in correction procedure */
/*       Reason: Contains uncorrected CGC */


/* Absorbed firms and mere CGC changers */
/*--------------------------------------*/
/* Structure: If 4, keep/create one following year with 6 and drop all further years */
/*            If 6, keep current 6 and drop all further years */
gen byte smplch=1 if state==6 & cgcsuc~=. & (catlife<9 | catlife==.)
replace smplch=1 if state==8 & change==1 & sales==. & cgcsuc~=. & (catlife<9 | catlife==.)
replace smplch=1 if state==8 & change==2 & sales==. & cgcsuc~=. & (catlife<9 | catlife==.)
replace smplch=1 if state==8 & change==4 & sales==. & cgcsuc~=. & (catlife<9 | catlife==.)
replace smplch=1 if state==8 & change==7 & sales==. & cgcsuc~=. & (catlife<9 | catlife==.)
replace smplch=1 if state==8 & change==. & sales==. & cgcsuc~=. & indcor==2 & (catlife<9 | catlife==.)
/* Use the above definitions again for "Recategorizing entering firms" in analyz-refer-emp.do */
egen int yrsmplch=min(year) if smplch==1, by(firm)
egen helper=max(yrsmplch), by(firm)
replace yrsmplch=helper
drop helper
gen byte effextyr=yrsmplch
label var effextyr "Year of Effective Exit"
format effextyr %2.0f
local reps 5
local i 1
while `i'<=`reps' {
    replace effextyr=year if yrsmplch~=. & year==effextyr-1 & (state==5 | state==6 | (state==4 & sales==.) | (state==8 & sales==.))
    replace effextyr=year if yrsmplch~=. & year==90 & year==effextyr-2 & (state==5 | state==6 | (state==4 & sales==.) | (state==8 & sales==.))
    quietly egen helper=min(effextyr), by (firm)
    quietly replace effextyr=helper if yrsmplch~=.
    drop helper
    local i=`i'+1
    }
drop if yrsmplch~=. & sales==. & year>yrsmplch
gen helper1=1 if state==6 & change~=2 & yrsmplch~=.
egen stat6=count(helper1), by(firm)
gen helper2=1 if (state==5 | (state==8 & change==. & indcor~=2 & cgcsuc==. & (cgcemp==firm | cgcemp==.) & sales==.)) & yrsmplch~=.
egen stat5=count(helper2), by(firm)
gen helper3=1 if state==4 & cgcsuc~=. & yrsmplch~=.
egen stat4=count(helper3), by(firm)
gen helper4=1 if state==8 & sales==. & cgcsuc~=. & yrsmplch~=.
egen stat8=count(helper4), by(firm)
drop helper1 helper2 helper3 helper4
replace catlife=1.4 if stat4<1 & (stat5>=1 | stat6>=2 | stat8>=1)
drop stat4 stat5 stat6 stat8
egen helper=max(existsuc), by(firm)
replace existsuc=helper if yrsmplch~=.
drop helper
replace catlife=1.3 if yrsmplch~=. & existsuc<yrsmplch+1900 & int(catlife)~=1
gen helper=1 if change==1 & smplch==1
egen indmerge=count(helper), by(firm)
replace catlife=1.2 if yrsmplch~=. & indmerge>=1
drop helper indmerge
replace catlife=1.1 if yrsmplch~=. & existsuc>=yrsmplch+1900 & int(catlife)~=1
replace catlife=5.5 if yrsmplch~=. & existsuc==. & catlife~=float(1.2) & catlife~=float(1.4)
drop smplch yrsmplch

gen byte smplch=1 if state==4 & cgcsuc~=. & int(catlife)~=9 & int(catlife)~=1 & catlife~=float(5.5)
replace smplch=1 if state==8 & change==1 & cgcsuc~=. & int(catlife)~=9 & int(catlife)~=1 & catlife~=float(5.5)
replace smplch=1 if state==8 & change==2 & cgcsuc~=. & int(catlife)~=9 & int(catlife)~=1 & catlife~=float(5.5)
replace smplch=1 if state==8 & change==4 & cgcsuc~=. & int(catlife)~=9 & int(catlife)~=1 & catlife~=float(5.5)
replace smplch=1 if state==8 & change==7 & cgcsuc~=. & int(catlife)~=9 & int(catlife)~=1 & catlife~=float(5.5)
replace smplch=1 if state==1 & change==10 & cgcsuc~=. & year==lastyr & year<98 &  int(catlife)~=1 & catlife~=float(5.5)
/* Use the above definitions again for "Recategorizing entering firms"  in analyz-refer-emp.do */
egen int yrsmplch=min(year) if smplch==1, by(firm)
egen helper=max(yrsmplch), by(firm)
replace yrsmplch=helper
drop helper
replace effextyr=yrsmplch+1 if yrsmplch~=.
replace effextyr=92 if effextyr==90 & yrsmplch~=.
local reps 1
local i 1
while `i'<=`reps' {
    replace effextyr=effextyr+1 if year==effextyr+1 & state==4
    replace effextyr=effextyr+1 if year==92 & year==effextyr+2 & state==4
    quietly egen helper=max(effextyr), by (firm)
    quietly replace effextyr=helper if yrsmplch~=.
    drop helper
    local i=`i'+1
    }
drop if yrsmplch~=. & sales==. & year>yrsmplch
expand =2 if smplch==1
sort firm year
quietly by firm year: gen helper=1 if _n<_N
replace year=yrsmplch+1 if helper==1
replace state=9 if helper==1
drop helper
drop if year>98
egen helper=max(existsuc), by(firm)
replace existsuc=helper if yrsmplch~=.
drop helper
replace catlife=1.3 if yrsmplch~=. & existsuc<yrsmplch+1900 & int(catlife)~=1
gen helper=1 if change==1 & smplch==1
egen indmerge=count(helper), by(firm)
replace catlife=1.2 if yrsmplch~=. & indmerge>=1
drop helper indmerge
replace catlife=1.1 if yrsmplch~=. & existsuc>=yrsmplch+1900 & int(catlife)~=1
replace catlife=5.5 if yrsmplch~=. & existsuc==. & catlife~=float(1.2) & catlife~=float(1.4)
drop smplch yrsmplch


/* Exiting firms */
/*---------------*/
/* Structure: If 4, keep/create one following year with 6 and drop all further years */
/*            If 6, keep current 6 and drop all further years */
gen byte smplch=1 if state==6 & cgcsuc==. & int(catlife)~=9 & int(catlife)~=1 & catlife~=float(5.5)
replace smplch=1 if indnolnk==1 & (int(catlife)==1 | catlife==float(5.5)) & year<98 & (state==4 | state==6)
replace smplch=1 if state==5 & year==lastyr & cgcsuc==. & int(catlife)~=9 & int(catlife)~=1 & catlife~=float(5.5)
replace smplch=1 if (state==8 & change==. & indcor~=2 & cgcsuc==. & (cgcemp==firm | cgcemp==.) & sales==.) & year==lastyr & cgcsuc==. & int(catlife)~=9 & int(catlife)~=1 & catlife~=float(5.5)
egen int yrsmplch=min(year) if smplch==1, by(firm)
egen helper=max(yrsmplch), by(firm)
replace yrsmplch=helper
drop helper
replace effextyr=yrsmplch if yrsmplch~=.
local reps 8
local i 1
while `i'<=`reps' {
    replace effextyr=year if yrsmplch~=. & year==effextyr-1 & (state==5 | state==6 | (state==4 & sales==.) | (state==8 & sales==.))
    replace effextyr=year if yrsmplch~=. & year==90 & year==effextyr-2 & (state==5 | state==6 | (state==4 & sales==.) | (state==8 & sales==.))
    quietly egen helper=min(effextyr), by (firm)
    quietly replace effextyr=helper if yrsmplch~=.
    drop helper
    local i=`i'+1
    }
drop if yrsmplch~=. & sales==. & year>yrsmplch
replace catlife=2 if yrsmplch~=.
drop smplch yrsmplch

gen byte smplch=1 if state==4 & cgcsuc==. & int(catlife)~=9 & int(catlife)~=1 & catlife~=float(5.5) & catlife~=float(2)
replace smplch=1 if indnolnk==1 & (int(catlife)==1 | catlife==float(5.5)) & year==98 & state==4
egen int yrsmplch=min(year) if smplch==1, by(firm)
egen helper=max(yrsmplch), by(firm)
replace yrsmplch=helper
drop helper
replace effextyr=yrsmplch+1 if yrsmplch~=.
replace effextyr=92 if effextyr==90 & yrsmplch~=.
local reps 1
local i 1
while `i'<=`reps' {
    replace effextyr=effextyr+1 if year==effextyr+1 & state==4
    replace effextyr=effextyr+1 if year==92 & year==effextyr+2 & state==4
    quietly egen helper=max(effextyr), by (firm)
    quietly replace effextyr=helper if yrsmplch~=.
    drop helper
    local i=`i'+1
    }
drop if yrsmplch~=. & sales==. & year>yrsmplch
expand =2 if smplch==1
sort firm year
quietly by firm year: gen helper=1 if _n<_N
replace year=yrsmplch+1 if helper==1
replace state=9 if helper==1
drop helper
drop if year>98
replace catlife=2 if yrsmplch~=.
drop smplch yrsmplch


/* Firms with suspended production in at least one year */
/*------------------------------------------------------*/
/* Note: Rent-out with no sales is considered a standstill */
gen helper=1 if (state==3 | state==5 | (state==8 & change==8 & sales==.) | (state==8 & change==. & indcor~=2 & cgcsuc==. & (cgcemp==firm | cgcemp==.) & sales==.))
egen countpar=count(helper), by(firm)
gen byte helpyr=year if (state==3 | state==5 | (state==8 & change==8 & sales==.) | (state==8 & change==. & indcor~=2 & cgcsuc==. & (cgcemp==firm | cgcemp==.) & sales==.))
egen byte fstsusyr=min(helpyr), by(firm)
replace catlife=3.11 if catlife==float(1.1) & countpar>=1 & fstsusyr<effextyr-1
replace catlife=3.12 if catlife==float(1.2) & countpar>=1 & fstsusyr<effextyr-1
replace catlife=3.13 if catlife==float(1.3) & countpar>=1 & fstsusyr<effextyr-1
replace catlife=3.14 if catlife==float(1.4) & countpar>=1 & fstsusyr<effextyr-1
replace catlife=3.2 if catlife==float(2) & countpar>=1 & fstsusyr<effextyr-1
replace catlife=3.0 if catlife==. & countpar>=1
drop helper countpar helpyr
label var fstsusyr "Earliest Year of Suspended Prod."
format fstsusyr %2.0f


/* Firms with missing data */
/*-------------------------*/
/* local repsj 2
local j 1
while `j'<=`repsj' { */
gen byte newextyr=98 if effextyr==99 & miss98==1
replace newextyr=97 if effextyr==98 & miss97==1 | (effextyr==99 & miss98==1 & miss97==1)
replace newextyr=96 if effextyr==97 & miss96==1 | (effextyr==98 & miss97==1 & miss96==1) | (effextyr==99 & miss98==1 & miss97==1 & miss96==1)
replace newextyr=95 if effextyr==96 & miss95==1 | (effextyr==97 & miss96==1 & miss95==1) | (effextyr==98 & miss97==1 & miss96==1 & miss95==1) | (effextyr==99 & miss98==1 & miss97==1 & miss96==1 & miss95==1)
replace newextyr=94 if effextyr==95 & miss94==1 | (effextyr==96 & miss95==1 & miss94==1) | (effextyr==97 & miss96==1 & miss95==1 & miss94==1) | (effextyr==98 & miss97==1 & miss96==1 & miss95==1 & miss94==1) | (effextyr==99 & miss98==1 & miss97==1 & miss96==1 & miss95==1 & miss94==1)
replace newextyr=93 if effextyr==94 & miss93==1 | (effextyr==95 & miss94==1 & miss93==1) | (effextyr==96 & miss95==1 & miss94==1 & miss93==1) | (effextyr==97 & miss96==1 & miss95==1 & miss94==1 & miss93==1) | (effextyr==98 & miss97==1 & miss96==1 & miss95==1 & miss94==1 & miss93==1) | (effextyr==99 & miss98==1 & miss97==1 & miss96==1 & miss95==1 & miss94==1 & miss93==1)
replace newextyr=92 if effextyr==93 & miss92==1 | (effextyr==94 & miss93==1 & miss92==1) | (effextyr==95 & miss94==1 & miss93==1 & miss92==1) | (effextyr==96 & miss95==1 & miss94==1 & miss93==1 & miss92==1) | (effextyr==97 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1) | (effextyr==98 & miss97==1 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1) | (effextyr==99 & miss98==1 & miss97==1 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1)
replace newextyr=90 if effextyr==92 & miss90==1 | (effextyr==93 & miss92==1 & miss90==1) | (effextyr==94 & miss93==1 & miss92==1 & miss90==1) | (effextyr==95 & miss94==1 & miss93==1 & miss92==1 & miss90==1) | (effextyr==96 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1) | (effextyr==97 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1) | (effextyr==98 & miss97==1 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1) | (effextyr==99 & miss98==1 & miss97==1 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1)
replace newextyr=89 if effextyr==90 & miss89==1 | (effextyr==92 & miss90==1 & miss89==1) | (effextyr==93 & miss92==1 & miss90==1 & miss89==1) | (effextyr==94 & miss93==1 & miss92==1 & miss90==1 & miss89==1) | (effextyr==95 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1) | (effextyr==96 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1) | (effextyr==97 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1) | (effextyr==98 & miss97==1 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss90==1) | (effextyr==99 & miss98==1 & miss97==1 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1)
replace newextyr=88 if effextyr==89 & miss88==1 | (effextyr==90 & miss89==1 & miss88==1) | (effextyr==92 & miss90==1 & miss89==1 & miss88==1) | (effextyr==93 & miss92==1 & miss90==1 & miss89==1 & miss88==1) | (effextyr==94 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1) | (effextyr==95 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1) | (effextyr==96 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1) | (effextyr==97 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1) | (effextyr==98 & miss97==1 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1) | (effextyr==99 & miss98==1 & miss97==1 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1)
replace newextyr=87 if effextyr==88 & miss87==1 | (effextyr==89 & miss88==1 & miss87==1) | (effextyr==90 & miss89==1 & miss88==1 & miss87==1) | (effextyr==92 & miss90==1 & miss89==1 & miss88==1 & miss87==1) | (effextyr==93 & miss92==1 & miss90==1 & miss89==1 & miss88==1 & miss87==1) | (effextyr==94 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1 & miss87==1) | (effextyr==95 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1 & miss87==1) | (effextyr==96 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1 & miss87==1) | (effextyr==97 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1 & miss87==1) | (effextyr==98 & miss97==1 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1 & miss87==1) | (effextyr==99 & miss98==1 & miss97==1 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1 & miss87==1)
replace newextyr=86 if effextyr==87 & miss86==1 | (effextyr==88 & miss87==1 & miss86==1) | (effextyr==89 & miss88==1 & miss87==1 & miss86==1) | (effextyr==90 & miss89==1 & miss88==1 & miss87==1 & miss86==1) | (effextyr==92 & miss90==1 & miss89==1 & miss88==1 & miss87==1 & miss86==1) | (effextyr==93 & miss92==1 & miss90==1 & miss89==1 & miss88==1 & miss87==1 & miss86==1) | (effextyr==94 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1 & miss87==1 & miss86==1) | (effextyr==95 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1 & miss87==1 & miss86==1) | (effextyr==96 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1 & miss87==1 & miss86==1) | (effextyr==97 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1 & miss87==1 & miss86==1) | (effextyr==98 & miss97==1 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1 & miss87==1 & miss86==1) | (effextyr==99 & miss98==1 & miss97==1 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1 & miss87==1 & miss86==1)
local reps 5
local i 1
while `i'<=`reps' {
    replace newextyr=year if newextyr~=effextyr & newextyr~=. & year==newextyr-1 & (state==5 | state==6 | (state==4 & sales==.) | (state==8 & sales==.))
    replace newextyr=year if newextyr~=effextyr & newextyr~=. & year==90 & year==newextyr-2 & (state==5 | state==6 | (state==4 & sales==.) | (state==8 & sales==.))
    quietly egen helper=min(newextyr), by (firm)
    quietly replace newextyr=helper if newextyr~=effextyr & newextyr~=.
    drop helper
    local i=`i'+1
    }
replace catlife=5.11 if catlife==float(1.1) & newextyr~=effextyr & newextyr~=.
replace catlife=5.12 if catlife==float(1.2) & newextyr~=effextyr & newextyr~=.
replace catlife=5.13 if (catlife==float(1.3) | catlife==float(5.5)) & newextyr~=effextyr & newextyr~=.
replace catlife=5.14 if catlife==float(1.4) & newextyr~=effextyr & newextyr~=.
replace catlife=5.2 if catlife==float(2) & newextyr~=effextyr & newextyr~=.
expand =2 if year==lastyr & newextyr~=effextyr & newextyr~=.
sort firm year
quietly by firm year: gen helper=1 if _n<_N
replace year=effextyr if helper==1
replace state=9 if helper==1
sort firm year state
quietly by firm year: drop if _N>1 & state==9
drop helper
replace effextyr=newextyr if newextyr~=effextyr & newextyr~=.
drop newextyr
/* local j=`j'+1
} */
replace fstsusyr=effextyr if fstsusyr>effextyr

preserve
  keep firm year state born effborn firstyr lastyr catentry catlife effextyr fstsusyr contgrp indsctch miss86-miss98
  drop if state==9
  keep if year==firstyr
  drop state year
  save `firmhd', replace
restore
fillin firm year
merge firm using `firmhd', update
drop _merge
drop if year<firstyr & _fillin==1
drop if (year>effextyr | year>lastyr) & _fillin==1
gen byte newparyr=97 if fstsusyr==98 & miss97==1 | (fstsusyr==99 & miss98==1 & miss97==1)
replace newparyr=96 if fstsusyr==97 & miss96==1 | (fstsusyr==98 & miss97==1 & miss96==1) | (fstsusyr==99 & miss98==1 & miss97==1 & miss96==1)
replace newparyr=95 if fstsusyr==96 & miss95==1 | (fstsusyr==97 & miss96==1 & miss95==1) | (fstsusyr==98 & miss97==1 & miss96==1 & miss95==1) | (fstsusyr==99 & miss98==1 & miss97==1 & miss96==1 & miss95==1)
replace newparyr=94 if fstsusyr==95 & miss94==1 | (fstsusyr==96 & miss95==1 & miss94==1) | (fstsusyr==97 & miss96==1 & miss95==1 & miss94==1) | (fstsusyr==98 & miss97==1 & miss96==1 & miss95==1 & miss94==1) | (fstsusyr==99 & miss98==1 & miss97==1 & miss96==1 & miss95==1 & miss94==1)
replace newparyr=93 if fstsusyr==94 & miss93==1 | (fstsusyr==95 & miss94==1 & miss93==1) | (fstsusyr==96 & miss95==1 & miss94==1 & miss93==1) | (fstsusyr==97 & miss96==1 & miss95==1 & miss94==1 & miss93==1) | (fstsusyr==98 & miss97==1 & miss96==1 & miss95==1 & miss94==1 & miss93==1) | (fstsusyr==99 & miss98==1 & miss97==1 & miss96==1 & miss95==1 & miss94==1 & miss93==1)
replace newparyr=92 if fstsusyr==93 & miss92==1 | (fstsusyr==94 & miss93==1 & miss92==1) | (fstsusyr==95 & miss94==1 & miss93==1 & miss92==1) | (fstsusyr==96 & miss95==1 & miss94==1 & miss93==1 & miss92==1) | (fstsusyr==97 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1) | (fstsusyr==98 & miss97==1 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1) | (fstsusyr==99 & miss98==1 & miss97==1 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1)
replace newparyr=90 if fstsusyr==92 & miss90==1 | (fstsusyr==93 & miss92==1 & miss90==1) | (fstsusyr==94 & miss93==1 & miss92==1 & miss90==1) | (fstsusyr==95 & miss94==1 & miss93==1 & miss92==1 & miss90==1) | (fstsusyr==96 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1) | (fstsusyr==97 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1) | (fstsusyr==98 & miss97==1 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1) | (fstsusyr==99 & miss98==1 & miss97==1 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1)
replace newparyr=89 if fstsusyr==90 & miss89==1 | (fstsusyr==92 & miss90==1 & miss89==1) | (fstsusyr==93 & miss92==1 & miss90==1 & miss89==1) | (fstsusyr==94 & miss93==1 & miss92==1 & miss90==1 & miss89==1) | (fstsusyr==95 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1) | (fstsusyr==96 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1) | (fstsusyr==97 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1) | (fstsusyr==98 & miss97==1 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1) | (fstsusyr==99 & miss98==1 & miss97==1 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1)
replace newparyr=88 if fstsusyr==89 & miss88==1 | (fstsusyr==90 & miss89==1 & miss88==1) | (fstsusyr==92 & miss90==1 & miss89==1 & miss88==1) | (fstsusyr==93 & miss92==1 & miss90==1 & miss89==1 & miss88==1) | (fstsusyr==94 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1) | (fstsusyr==95 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1) | (fstsusyr==96 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1) | (fstsusyr==97 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1) | (fstsusyr==98 & miss97==1 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1) | (fstsusyr==99 & miss98==1 & miss97==1 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1)
replace newparyr=87 if fstsusyr==88 & miss87==1 | (fstsusyr==89 & miss88==1 & miss87==1) | (fstsusyr==90 & miss89==1 & miss88==1 & miss87==1) | (fstsusyr==92 & miss90==1 & miss89==1 & miss88==1 & miss87==1) | (fstsusyr==93 & miss92==1 & miss90==1 & miss89==1 & miss88==1 & miss87==1) | (fstsusyr==94 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1 & miss87==1) | (fstsusyr==95 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1 & miss87==1) | (fstsusyr==96 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1 & miss87==1) | (fstsusyr==97 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1 & miss87==1) | (fstsusyr==98 & miss97==1 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1 & miss87==1) | (fstsusyr==99 & miss98==1 & miss97==1 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1 & miss87==1)
replace newparyr=86 if fstsusyr==87 & miss86==1 | (fstsusyr==88 & miss87==1 & miss86==1) | (fstsusyr==89 & miss88==1 & miss87==1 & miss86==1) | (fstsusyr==90 & miss89==1 & miss88==1 & miss87==1 & miss86==1) | (fstsusyr==92 & miss90==1 & miss89==1 & miss88==1 & miss87==1 & miss86==1) | (fstsusyr==93 & miss92==1 & miss90==1 & miss89==1 & miss88==1 & miss87==1 & miss86==1) | (fstsusyr==94 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1 & miss87==1 & miss86==1) | (fstsusyr==95 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1 & miss87==1 & miss86==1) | (fstsusyr==96 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1 & miss87==1 & miss86==1) | (fstsusyr==97 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1 & miss87==1 & miss86==1) | (fstsusyr==98 & miss97==1 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1 & miss87==1 & miss86==1) | (fstsusyr==99 & miss98==1 & miss97==1 & miss96==1 & miss95==1 & miss94==1 & miss93==1 & miss92==1 & miss90==1 & miss89==1 & miss88==1 & miss87==1 & miss86==1)
replace newparyr=firstyr if newparyr<firstyr & newparyr~=.
replace state=9 if _fillin==1 & year>=newparyr & year<fstsusyr
sort firm year
replace state=9 if _fillin==1 & (state[_n-1]==3 | state[_n-1]==5 | (state[_n-1]==8 & change[_n-1]==8 & sales[_n-1]==.) | (state[_n-1]==8 & change[_n-1]==. & indcor[_n-1]~=2 & cgcsuc[_n-1]==. & (cgcemp[_n-1]==firm[_n-1] | cgcemp[_n-1]==.) & sales[_n-1]==.) | (state[_n-1]==9 & _fillin[_n-1]==1))
sort firm year
replace state=9 if _fillin==1 & (state[_n+1]==3 | state[_n+1]==5 | (state[_n+1]==8 & change[_n+1]==8 & sales[_n+1]==.) | (state[_n+1]==8 & change[_n+1]==. & indcor[_n+1]~=2 & cgcsuc[_n+1]==. & (cgcemp[_n+1]==firm[_n+1] | cgcemp[_n+1]==.) & sales[_n+1]==.) | (state[_n+1]==9 & _fillin[_n+1]==1))
drop if year==91
gen helper=1 if state==9 & _fillin==1
egen countmrk=count(helper), by(firm)
replace catlife=5.311 if catlife==float(3.11) & countmrk>=1
replace catlife=5.312 if catlife==float(3.12) & countmrk>=1
replace catlife=5.313 if catlife==float(3.13) & countmrk>=1
replace catlife=5.314 if catlife==float(3.14) & countmrk>=1
replace catlife=5.32  if catlife==float(3.2) & countmrk>=1
replace catlife=5.30  if catlife==. & countmrk>=1
drop helper countmrk
replace fstsusyr=newparyr if newparyr~=fstsusyr & newparyr~=.
drop newparyr
drop if _fillin==1 & state~=9
drop _fillin

replace catlife=5.0 if catlife==. & (miss86==1 | miss87==1 | miss88==1 | miss89==1 | miss90==1 | miss92==1 | miss93==1 | miss94==1 | miss95==1 | miss96==1 | miss97==1 | miss98==1)

replace catlife=9.3 if effextyr<=firstyr
egen maxsale=max(sale), by(firm)
replace catlife=9.3 if maxsale==.
drop maxsale


/* Non-industrial firm in at least one period before effective exit */
/*------------------------------------------------------------------*/
gen helper=1 if state==7 & year<effextyr
egen counter=count(helper), by(firm)
gen byte indnoind=1 if counter>=1
format indnoind %1.0f
label var indnoind "Firm Non-Industrial before exit"
drop helper counter


/* Not categorized */
/*-----------------*/
gen helper=1 if catlife==. & indcor~=2 & cgcsuc==. & state==1 & sales==.
egen counter=count(helper), by(firm)
egen minch=min(change), by(firm)
replace catlife=8.0 if counter>=1 & (minch==. | minch==10)
drop helper minch counter
gen helper=1 if (state~=. & change==10 & cgcsuc~=.)
egen counthlp=count(helper), by(firm)
replace catlife=8.1 if catlife==. & counthlp>=1
drop helper counthlp
gen helper=1 if (state==8 & change==10 & cgcsuc==.)
egen counthlp=count(helper), by(firm)
replace catlife=8.2 if catlife==. & counthlp>=1
drop helper counthlp
gen helper=1 if (state==8 | change==10)
egen counthlp=count(helper), by(firm)
replace catlife=8.3 if catlife==. & counthlp>=1
drop helper counthlp
gen helper=1 if state==7
egen counthlp=count(helper), by(firm)
replace catlife=8.7 if catlife==. & counthlp>=1
drop helper counthlp


/* Infer missing/Correct contradictory change month in year of effective exit */
/*----------------------------------------------------------------------------*/
preserve
    keep firm year chyr chmon
    rename year repyear
    gen byte year=chyr
    gen byte chyr0=chyr
    gen byte chmon0=chmon
    sort firm year chyr0 chmon0             /* Prepare to delete doubles */
    quietly by firm year: keep if _n==_N    /* Keep latest reported exit month -- Deflation error is the least */
    sort firm year
    save `corryr', replace
restore
sort firm year
merge firm year using `corryr', nokeep
replace chyr0=. if (change~=1 & change~=2 & change~=4 & change~=7)
replace chmon0=. if chyr0==. 
/* Rule out changes in these cases: */
replace chmon0=. if chmon>=chmon0 & repyear>=year & chyr==chyr0
replace chyr0=. if chmon>=chmon0 & repyear>=year & chyr==chyr0
replace chyr0=. if chmon==. & chmon0==.
replace chmon0=. if chyr0>chyr & chyr0>=year & sales==.
replace chyr0=. if chyr0>chyr & chyr0>=year & sales==.
replace chmon0=. if repyear<year
replace chyr0=. if repyear<year
/* Do change chmon or chyr in the following cases: */
replace chmon=chmon0 if chmon<chmon0 & repyear>=year & chyr==chyr0 & _merge==3 & year==effextyr /* Use latest reported exit month -- Deflation error is the least */
replace chyr = chyr0 if chyr0==year & chyr==.  & repyear>=year     & _merge==3 & year==effextyr
replace chmon=chmon0 if chyr0==year & chmon==. & repyear>=year     & _merge==3 & year==effextyr
replace chyr = chyr0 if chyr>=year & chyr0<=year & repyear>=year   & _merge==3 & year==effextyr /* Error correction */
replace chmon=chmon0 if chyr>=year & chyr0<=year & repyear>=year   & _merge==3 & year==effextyr /* Error correction */
drop _merge repyear chyr0 chmon0

/* Insert new code here (above this line) */

replace sales=. if state==9
replace difstock=. if state==9
replace resales=. if state==9
replace astot=. if state==9
replace asliq=. if state==9
replace aslr=. if state==9
replace aspsum=. if state==9
replace aspinv=. if state==9
replace aspimmo=. if state==9
replace asrtimmo=. if state==9
replace aslsimmo=. if state==9
replace aspmasum=. if state==9
replace aspdefer=. if state==9
replace deprec=. if state==9
replace fincost=. if state==9
replace balsum=. if state==9
replace crtot=. if state==9
replace crstsum=. if state==9
replace crstdom=. if state==9
replace crstfor=. if state==9
replace crltsum=. if state==9
replace crltdom=. if state==9
replace crltfor=. if state==9
replace labftot=. if state==9
replace labftop=. if state==9
replace labfwh=. if state==9
replace labfbl=. if state==9
replace wagetot=. if state==9
replace wagetop=. if state==9
replace wagewh=. if state==9
replace wagebl=. if state==9
replace acqtot=. if state==9
replace acqbl=. if state==9
replace acqmasum=. if state==9
replace acqmadom=. if state==9
replace acqmause=. if state==9
replace acqmafor=. if state==9
replace acqveh=. if state==9
replace acqother=. if state==9
replace acqcomp=. if state==9
replace asltot=. if state==9
replace aslbl=. if state==9
replace aslmasum=. if state==9
replace aslveh=. if state==9
replace aslother=. if state==9
replace aslcomp=. if state==9
replace intmacq=. if state==9
replace intmdif=. if state==9
replace profit=. if state==9

order firm year state change cgcsuc cgcemp born effborn firstyr lastyr catentry catlife effextyr fstsusyr contgrp indnolnk existsuc indsctch indnoind chmon chyr indcor miss86 miss87 miss88 miss89 miss90 miss92 miss93 miss94 miss95  miss96 miss97 miss98 sales difstock resales astot asliq aslr aspsum aspinv aspimmo aspmasum aspdefer asrtimmo aslsimmo deprec fincost balsum crtot crstsum crstdom crstfor crltsum crltdom crltfor labftot labftop labfwh labfbl wagetot wagetop wagewh wagebl acqtot acqbl acqmasum acqmadom acqmause acqmafor acqveh acqother acqcomp asltot aslbl aslmasum aslveh aslother aslcomp intmacq intmdif niv100 niv80 region uf genero class weight
sort firm year
save "brazprod\data\pia-finl.dta", replace
