version 6.0
local yr 86     /* Do not use values other than 86, 87, 88, 89, 90 */


/* Set Missing Observations Properly */
/*-----------------------------------*/
capture program drop missobs
program define missobs
args i imax
while `i' < 10 {
    quietly replace v000`i'=. if v000`i'==-1
    local i = `i' + 1
}
while `i' < 100 {
    quietly replace v00`i'=. if v00`i'==-1
    local i = `i' + 1
}
while `i' < `imax' + 1 {
    quietly replace v0`i'=. if v0`i'==-1
    local i = `i' + 1
}
end


while `yr'<=90 {

insheet using "brazprod\pia-e\piae`yr'.csv", clear

missobs 1 158

/* General Information on the Firm */
/*---------------------------------*/
rename empresa firm
label var firm "Tax Number (CGC)"
format firm %8.0f

drop ano
gen byte year=`yr'
label var year "Calendar Year"
format year %2.0f

rename reg region
label var region "Region of Headquarters"

label var uf "UF of Headquarters"

label var genero "Industry (Genero) of Firm"

label var niv100 "Sector of Firm (NIV100)"
rename classe class
label var class "IBGE Classification of Firm"

rename peso weight
label var weight "Representative of N other Firms"
rename v2101 state
label var state "State of Activity"

rename v2600 change
label var change "Change of Legal/Economic Status"

drop v2801
order firm year niv100 state change


/* Variables */
/*-----------*/
egen _adjden=rsum(v0103 v0104 v0105)
gen _adjfac=v0109/_adjden
egen sales=rsum(v0103 v0105)
replace sales=_adjfac*sales if _adjfac~=. & _adjfac~=0
label var sales "Sales of Final Goods"
rename v0104 resales
replace resales=_adjfac*resales if _adjfac~=. & _adjfac~=0
label var resales "Resales of Merchandise"
rename v0142 difstock
label var difstock "Change in Processed Goods Stocks"
/* POSITIVE Value means DECREASE in Stocks */
drop _adj*

rename v0011 astot
label var astot "Assets (Total)"
rename v0001 asliq
label var asliq "Liquid Assets"
rename v0006 aslr
label var aslr "Long-run Assets"
rename v0007 aspsum
label var aspsum "Permanent Assets (Sum)"
rename v0008 aspinv
label var aspinv "Perm A.: Holdings of Investments"
rename v0009 aspimmo
label var aspimmo "Perm A.: Equipment & Real Estate"
rename v0097 aspmasum
label var aspmasum "Perm A.: Machinery (Eq.&R.Est.)"
rename v0010 aspdefer
label var aspdefer "Perm A.: R&D & Fiscal Operations"

rename v0023 balsum
label var balsum "Total Liabilities"
egen crtot=rsum(v0012 v0017)
label var crtot  "Credit (Total)"
rename v0012 crstsum
label var crstsum "Short-Term Credit (Sum)"
rename v0014 crstdom
label var crstdom "Short-Term Credit: Domestic"
rename v0015 crstfor
label var crstfor "Short-Term Credit: Foreign"
rename v0017 crltsum
label var crltsum "Long-Term Credit (Sum)"
rename v0018 crltdom
label var crltdom "Long-Term Credit: Domestic"
rename v0019 crltfor
label var crltfor "Long-Term Credit: Foreign"

rename v0028 labftot
label var labftot "Labor (Total)"
rename v0026 labfbl
label var labfbl "Labor Force: Blue-Collar"
rename v0025 labfwh
label var labfwh "Labor Force: White-Collar"
rename v0024 labftop
label var labftop "Labor Force: Top Management"
rename v0033 wagetot
label var wagetot "Salaries (Total)"
gen _grat=v0032*v0031/(v0030+v0031)
egen wagebl=rsum(v0031 _grat)
label var wagebl "Salaries: Blue-Collar"
replace _grat=v0032*v0030/(v0030+v0031)
egen wagewh=rsum(v0030 _grat)
drop _grat
label var wagewh "Salaries: White-Collar"
rename v0029 wagetop
label var wagetop "Salaries: Top Management"

rename v0056 acqtot
label var acqtot "Acquisitions of Assets (Total)"
egen acqbl=rsum(v0042 v0043)
label var acqbl "Acquisition of Ground & Premises"
rename v0046 acqmasum
label var acqmasum "Acquisitions of Machinery (Sum)"
rename v0047 acqmadom
label var acqmadom "Acquis. of Machinery: Domestic"
rename v0049 acqmause
label var acqmause "Acquis. of Machinery: Used"
rename v0048 acqmafor
label var acqmafor "Acquis. of Machinery: Foreign"
rename v0050 acqveh
label var acqveh "Acquisitions of Vehicles"
egen acqother=rsum(v0053 v0054 v0055)
label var acqother "Acquisitions of Other Assets"
rename v0054 acqcomp
label var acqcomp "Acquis. of Other Ass.: Computers"

rename v0072 asltot
label var asltot "Sales of Assets (Total)"
egen aslbl=rsum(v0065 v0066)
label var aslbl "Sales of Ground & Premises"
rename v0067 aslmasum
label var aslmasum "Sales of Machinery"
rename v0068 aslveh
label var aslveh "Sales of Vehicles"
egen aslother=rsum(v0069 v0070 v0071)
label var aslother "Sales of Other Assets"
rename v0070 aslcomp
label var aslcomp "Sales of Other Ass.: Computers"

rename v0135 deprec
label var deprec "Asset Depreciation Cost"
rename v0117 fincost
label var fincost "Financial Expenditures"
rename v0132 asrtimmo
label var asrtimmo "Rental of Equipment & Real Est."
rename v0133 aslsimmo
label var aslsimmo "Leasing of Equipment"

rename v0140 intmacq
label var intmacq "Acquis. of Intermediate Goods"
rename v0141 intmdif
label var intmdif "Change in Interm Goods Stocks"
/* POSITIVE value means DECREASE in stocks */

gen byte _miss=1 if v0126==. & v0127==.
gen _loss=-v0127
egen profit=rsum(v0126 _loss v0124 v0125)
label var profit "Profit before tax"
replace profit=. if _miss==1
drop _*

/* Finalize */
/*----------*/
order firm year niv100 state change sales resales difstock astot asliq aslr aspsum aspinv aspimmo aspmasum aspdefer asrtimmo aslsimmo deprec fincost balsum crtot crstsum crstdom crstfor crltsum crltdom crltfor labftot labftop labfwh labfbl wagetot wagetop wagewh wagebl acqtot acqbl acqmasum acqmadom acqmause acqmafor acqveh acqother acqcomp asltot aslbl aslmasum aslveh aslother aslcomp intmacq intmdif profit region uf genero class weight
drop v0002-v0158
sort firm

save "brazprod\data\pia-e\piae`yr'.dta", replace
disp
disp 1900+`yr'
desc

local yr=`yr'+1
}
