version 6.0
local yr 96     /* Do not use values other than 96, 97, 98 */
tempfile cnae96 cnae97 cnae98 cnaeniv

/* Prepare CNAE-Niv100 Filter */
/*----------------------------*/
insheet using "brazprod\filters\cnae-niv100.csv", clear
drop remark
drop if cnae==.
replace cnae=int(cnae)
gen niv100=int(nivel100)
compress
sort cnae
save `cnaeniv', replace


while `yr'<=98 {

insheet using "brazprod\pia-e\pianova`yr'.csv", clear

* drop if modelo=="S"  /* Drop simplified ("S") questionnaires, inactive */
drop firm indsuc indpred

/* General Information on the Firm */
/*---------------------------------*/
rename empresa firm
label var firm "Tax Number (CGC)"
format firm %8.0f

gen byte year=`yr'
label var year "Calendar Year"
format year %2.0f

quietly gen byte region=.
label var region "Region of Headquarters"

rename ufsede uf
label var uf "UF of Headquarters"

quietly gen byte genero=.
label var genero "Industry (Genero) of Firm"

quietly gen int niv100=.
label var niv100 "Sector of Firm (NIV100)"

quietly gen byte class=.
label var class "IBGE Classification of Firm"

rename cnaesemp cnae
label var cnae "CNAE Classification of Firm"

quietly gen int weight=.
label var weight "Representative of N other Firms"

rename sitcad state
label var state "State of Activity"

gen byte change=int(real(mudestr))
label var change "Change of Legal/Economic Status"
format change %2.0f

/* Variables */
/*-----------*/

foreach var in v0015 v0016 v0028 v0043 v0044 v0047 v0048 v0058 v0061 v0063 v0067 v0068 v0071 v0074 v0075 v0080 v0085 {
    capture confirm numeric variable `var'
    if _rc==7 {
        gen _`var' = real(`var')
        drop `var'
        rename _`var' `var'
        }
    }
foreach var in x01 x03 x05 x07 x09 x10 x11 x12 x14 x15 x26 x27 x28 x36 x37 x53 x54 x55 x56 x57 x58 x59 x60 x61 x62 x63 x64 x65 x66 x67 x68 x69 x70 {
    capture confirm numeric variable `var'
    if _rc==7 {
        gen _`var' = real(`var')
        drop `var'
        rename _`var' `var'
        }
    }
compress

egen _adjden=rsum(x15 v0015 v0016)
gen _adjfac=x14/_adjden
egen sales=rsum(x15 v0016)
replace sales=_adjfac*sales if _adjfac~=. & _adjfac~=0
label var sales "Sales of Final Goods"
rename v0015 resales
replace resales=_adjfac*resales if _adjfac~=. & _adjfac~=0
label var resales "Resales of Merchandise"
gen _dummy47=-v0047
gen _dummy48=-v0048
egen difstock=rsum(_dummy47 v0043 _dummy48 v0044)
label var difstock "Change in Processed Goods Stocks"
/* POSITIVE Value means DECREASE in Stocks */
drop _adj*
drop _dummy4*

quietly gen astot=.
label var astot "Assets (Total)"
quietly gen asliq=.
label var asliq "Liquid Assets"
quietly gen aslr=.
label var aslr "Long-run Assets"
quietly gen aspsum=.
label var aspsum "Permanent Assets (Sum)"
quietly gen aspinv=.
label var aspinv "Perm A.: Holdings of Investments"
quietly gen aspimmo=.
label var aspimmo "Perm A.: Equipment & Real Estate"
quietly gen aspmasum=.
label var aspmasum "Perm A.: Machinery (Eq.&R.Est.)"
quietly gen aspdefer=.
label var aspdefer "Perm A.: R&D & Fiscal Operations"

quietly gen balsum=.
label var balsum "Total Liabilities"
quietly gen crtot=.
label var crtot "Credit (Total)"
quietly gen crstsum=.
label var crstsum "Short-Term Credit (Sum)"
quietly gen crstdom=.
label var crstdom "Short-Term Credit: Domestic"
quietly gen crstfor=.
label var crstfor "Short-Term Credit: Foreign"
quietly gen crltsum=.
label var crltsum "Long-Term Credit (Sum)"
quietly gen crltdom=.
label var crltdom "Long-Term Credit: Domestic"
quietly gen crltfor=.
label var crltfor "Long-Term Credit: Foreign"

rename x01 labftot
label var labftot "Labor (Total)"
rename x03 labfbl
label var labfbl "Labor Force: Blue-Collar"
rename x05 labfwh
label var labfwh "Labor Force: White-Collar"
rename x07 labftop
label var labftop "Labor Force: Top Management"
rename x09 wagetot
label var wagetot "Salaries (Total)"
rename x10 wagebl
label var wagebl "Salaries: Blue-Collar"
rename x11 wagewh
label var wagewh "Salaries: White-Collar"
rename x12 wagetop
label var wagetop "Salaries: Top Management"

egen acqtot=rsum(v0080 v0085 x53)
label var acqtot "Acquisitions of Assets (Total)"
egen acqbl=rsum(x55 x59 x63)
label var acqbl "Acquisition of Ground & Premises"
egen acqmasum=rsum(x56 x60 x64)
label var acqmasum "Acquisitions of Machinery (Sum)"
quietly gen acqmadom=.
label var acqmadom "Acquis. of Machinery: Domestic"
quietly gen acqmause=.
label var acqmause "Acquis. of Machinery: Used"
quietly gen acqmafor=.
label var acqmafor "Acquis. of Machinery: Foreign"
egen acqveh=rsum(x57 x61 x65)
label var acqveh "Acquisitions of Vehicles"
egen acqother=rsum(x58 x62 x66)
label var acqother "Acquisitions of Other Assets"
quietly gen acqcomp=.
label var acqcomp "Acquis. of Other Ass.: Computers"

rename x54 asltot
label var asltot "Sales of Assets (Total)"
rename x67 aslbl
label var aslbl "Sales of Ground & Premises"
rename x68 aslmasum
label var aslmasum "Sales of Machinery"
rename x69 aslveh
label var aslveh "Sales of Vehicles"
rename x70 aslother
label var aslother "Sales of Other Assets"
quietly gen aslcomp=.
label var aslcomp "Sales of Other Ass.: Computers"

rename v0061 deprec
label var deprec "Asset Depreciation Cost"
gen _v0028=-v0028
egen fincost=rsum(v0067 v0068 _v0028)
label var fincost "Financial Expenditures"
rename x36 asrtimmo
label var asrtimmo "Rental of Equipment & Real Est."
rename x37 aslsimmo
label var aslsimmo "Leasing of Equipment"
drop _v0028

egen intmacq=rsum(x26 v0058 v0063 v0071)
label var intmacq "Acquis. of Intermediate Goods"
gen _dummy28=-x28
egen intmdif=rsum(_dummy28 x27)
drop _dummy28
label var intmdif "Change in Interm Goods Stocks"
/* POSITIVE value means DECREASE in stocks */

gen byte _miss=1 if v0074==. & v0075==.
gen _loss=-v0075
egen profit=rsum(v0074 _loss)
label var profit "Profit before tax"
replace profit=. if _miss==1
drop _*

/* Transform CNAE to Nivel 100 */
/*-----------------------------*/
sort cnae
merge cnae using `cnaeniv', update nokeep
drop if firm==.
preserve
    keep firm year cnae
    sort firm year
    save `cnae`yr'', replace
restore
drop cnae


/* Finalize */
/*----------*/
order firm year niv100 state change sales resales difstock astot asliq aslr aspsum aspinv aspimmo aspmasum aspdefer asrtimmo aslsimmo deprec fincost crtot crstsum crstdom crstfor crltsum crltdom crltfor labftot labftop labfwh labfbl wagetot wagetop wagewh wagebl acqtot acqbl acqmasum acqmadom acqmause acqmafor acqveh acqother acqcomp asltot aslbl aslmasum aslveh aslother aslcomp intmacq intmdif profit region uf genero class weight
keep firm year niv100 state change sales resales difstock astot asliq aslr aspsum aspinv aspimmo aspmasum aspdefer asrtimmo aslsimmo deprec fincost crtot crstsum crstdom crstfor crltsum crltdom crltfor labftot labftop labfwh labfbl wagetot wagetop wagewh wagebl acqtot acqbl acqmasum acqmadom acqmause acqmafor acqveh acqother acqcomp asltot aslbl aslmasum aslveh aslother aslcomp intmacq intmdif profit region uf genero class weight
sort firm

save "brazprod\data\pia-e\piae`yr'", replace

disp
disp 1900+`yr'
desc

local yr=`yr'+1
}

use `cnae96', clear
append using `cnae97'
append using `cnae98'
sort firm year
save "brazprod\cgc-list\cgc-cnae-96-98", replace
