version 7
set matsize 200

tempfile master tmp5 tmp6 forppi
tempfile inout86 inout87 inout88 inout89 inout90 inout91 inout92 inout93 inout94 inout95 inout96 inout97 inout98
tempfile indfl86 indfl87 indfl88 indfl89 indfl90 indfl91 indfl92 indfl93 indfl94 indfl95 indfl96 indfl97 indfl98 indfl99

/* Produced Deflators  1: Mesquita (and general) Deflators 90-98 */
/*                     2: PIM-IBGE (and general) Deflators 86-98 */
/*                     3: FGV-IPA  (and general) Deflators 86-98 */
/*                     4: FGV-DI   (and general) Deflators 86-98 */
/* All deflator types will be created in loops */

local forpidx 2
/* Choice 1: Foreign input deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input deflators based on World PPI, WPI, CPI series * USD exchange rate */
local fdfl = `forpidx'

capture program drop rebase90
program define rebase90
    args yr
    while `yr'<=98 {
    if `yr'~=90 {quietly replace jan`yr'=(jan`yr'/jan90)*100}
    quietly replace feb`yr'=(feb`yr'/jan90)*100
    quietly replace mar`yr'=(mar`yr'/jan90)*100
    quietly replace apr`yr'=(apr`yr'/jan90)*100
    quietly replace may`yr'=(may`yr'/jan90)*100
    quietly replace jun`yr'=(jun`yr'/jan90)*100
    quietly replace jul`yr'=(jul`yr'/jan90)*100
    quietly replace aug`yr'=(aug`yr'/jan90)*100
    quietly replace sep`yr'=(sep`yr'/jan90)*100
    quietly replace oct`yr'=(oct`yr'/jan90)*100
    quietly replace nov`yr'=(nov`yr'/jan90)*100
    quietly replace dec`yr'=(dec`yr'/jan90)*100
    local yr=`yr'+1
    }
    quietly replace jan90=100
end


/* Foreign price matrix: (1 + Tariff) * USDEXCH * PPI */
/*----------------------------------------------------*/

use "brazprod/addl/tariffs-intm-monthly", clear
drop ativ80
* save "brazprod/addl/trfinpmo", replace
* clear
* matload trfinpmo, path("brazprod/addl") rowname(niv100) overwrite
rename niv100 _rowname
local j 1
while `j' <= _N {
  local rownm`j'=_rowname[`j']
  local j = `j'+1
  }
drop _rowname
mkmat _all, matrix(trfinpmo)
local j = 1
while `j' <= _N {
  matname trfinpmo `rownm`j'', rows(`j') explicit
  local j = `j'+1
  }
local cnam : colfullnames trfinpmo
tokenize "`cnam'"
local j 1
while `j' <= colsof(trfinpmo) {
  local `j'=subinword("``j''","__cons","_cons",1)
  local `j'=subinword("``j''","__b","_b",1)
  local `j'=subinword("``j''","__coef","_coef",1)
  matname trfinpmo ``j'' , columns(`j') explicit
  local j=`j'+1
}

/* Foreign price matrix: USDEXCH * PIDX */
/*--------------------------------------*/
if `forpidx' == 1 { use "brazprod/deflate/foreign-ppi", clear 
                    keep if series=="oecd*usdex"
                    drop series
                    }
if `forpidx' == 2 { use "brazprod/deflate/foreign-mix", clear 
                    keep if series=="world*usdex"
                    drop series
                    }
* gen _jan86 = jan86
* order niv _jan86 jan86
* matrix trfjan86 = trfinpmo[1..64,1]
* svmat trfjan86
* gen _chkjan86 = jan86 * (1 + trfjan86)
* order niv _jan86 jan86 trfjan86 _chkjan86
local j = 0
forvalues yr = 86/98 {
foreach mon in "jan" "feb" "mar" "apr" "may" "jun" "jul" "aug" "sep" "oct" "nov" "dec" {
  local j = `j'+1
  local i = 0
  forvalues sec = 1/64 {
    local i = `i' + 1
    qui replace `mon'`yr' = `mon'`yr' * (1 + trfinpmo[`i',`j']) in `i'
    }
 }
}
rebase90 86
save `forppi'


/* Create Temp. Input-Output Matrices */
/*------------------------------------*/
/* Niv80 x Sector (Activity) Weights Matrices, 90-98 */
local yr 90
while `yr'<=98 {
insheet using "brazprod/deflate/contas-nacionais/in-out-`yr'.csv", clear
drop if nivel80==.
drop total
rename nivel80 niv80
local i 2
while `i'<=9 {
    local name=`i'-1
    rename v`i' ativ`name'
    label var ativ`name' "Activity  `name' (NIV80)"
    local i=`i'+1
}
local i 10
while `i'<=32 {
    rename v`i' ativ`i'
    label var ativ`i' "Activity `i' (NIV80)"
    local i=`i'+1
}
drop ativ1 v33-v44
sort niv80
save `inout`yr'', replace
local yr=`yr'+1
}
/* Make matrices 1986-1989 from 1985 and 1990 */
/* Method: W85 + (DIFF/5)*Step = W90 */
insheet using "brazprod/deflate/contas-nacionais/in-out-85-orig.csv", clear
drop if ativ80==.
drop v82
mkmat v2-v81, matrix(IO85)
matrix input sec=(0101,0102,0103,0104,0105,0106,0107,0108,0109,0110,0199,0201,0202,0301,0302,0401,0501,0502,0601,0701,0801,0802,1001,1101,1201,1301,1401,1501,1601,1701,1702,1801,1802,1803,1804,1805,1806,1901,1902,1903,2001,2101,2201,2202,2203,2204,2205,2301,2401,2501,2601,2602,2603,2701,2702,2801,2802,2901,3001,3002,3101,3102,3201,3301,3401,3501,3601,3701,3801,3802,3901,3902,3903,4001,4101,4102,4201,4202,4203,4301)
matrix IO85=sec' , IO85'
drop _all
svmat double IO85
matrix drop IO85 sec
rename IO851 niv80
label var niv80 "NIVEL 80"
local i 2
while `i'<=9 {
    local name=`i'-1
    rename IO85`i' start`name'
    label var start`name' "Activity  `name' (NIV80)"
    local i=`i'+1
}
while `i'<=43 {
    rename IO85`i' start`i'
    label var start`i' "Activity `i' (NIV80)"
    local i=`i'+1
}
rename IO8544 start46
label var start46 "46"
sort niv80
preserve
    local i 1
    while `i'<=50 {
        capture rename start`i' v`i'
        local i=`i'+1
    }
    outsheet using "brazprod/deflate/contas-nacionais/in-out-85-transpo.csv", replace comma
restore
drop start1 start33-start46
merge niv80 using `inout90'
drop _merge
local i 2
while `i'<=32 {
    if `i'==9 {local i 10}
    quietly egen tot`i'=sum(ativ`i')
    qui replace ativ`i'=ativ`i'/tot`i'
    drop tot`i'
    quietly egen tot`i'=sum(start`i')
    qui replace start`i'=start`i'/tot`i'
    drop tot`i'
    local i=`i'+1
}
local step 1
while `step'<=4 {
    local i 2
    while `i'<=32 {
        if `i'==9 {local i 10}
        gen new`i'=start`i'+`step'*((ativ`i'-start`i')/5)
        local i=`i'+1
    }
preserve
    local yr=`step'+85
    keep niv80 new2-new32
    local i 2
    while `i'<=32 {
        if `i'==9 {local i 10}
        rename new`i' ativ`i'
        if `i'<10 {label var ativ`i' "Activity  `i' (NIV80)"}
            else {label var ativ`i' "Activity `i' (NIV80)"}
        local i=`i'+1
    }
    sort niv80
    save `inout`yr'', replace
restore
drop new2-new32
local step=`step'+1
}


/* Marc and Adriana's Input Deflators */
/*------------------------------------*/
/* Niv80 x Deflators Matrix */
local choice 1
while `choice'<=5 {
use "brazprod/filters/niv10080", clear
sort niv100
merge niv100 using "brazprod/deflate/comp-defl"   /* Read-in indtype */
keep niv80 niv100 nivmap indtype
sort niv100
if `choice'==1 {merge niv100 using "brazprod/deflate/output-defl-mesq"}
if `choice'==2 {merge niv100 using "brazprod/deflate/output-defl-pim"}
if `choice'==3 {merge niv100 using "brazprod/deflate/output-defl-ipa"}
if `choice'==4 {merge niv100 using "brazprod/deflate/output-defl-di"}
if `choice'==5 {merge niv100 using "`forppi'"}
keep if _merge==3  /* Keep Only if Deflator for Sector Exists */
drop _merge
/* keep if indtype~="bk" & indtype~="bket" */  /* Keep Only if Non-Capital Good */
/* Here: Keep capital goods since Table2 of the National Accounting Department is only for inputs and outputs, and disregards investment */
keep if jan90~=.
keep niv100 nivmap jan86-dec98
sort niv100 nivmap
quietly by niv100 nivmap: keep if _n==1
local yr 86
while `yr'<=98 {
    quietly egen mjan`yr'=mean(jan`yr'), by(nivmap)
    quietly egen mfeb`yr'=mean(feb`yr'), by(nivmap)
    quietly egen mmar`yr'=mean(mar`yr'), by(nivmap)
    quietly egen mapr`yr'=mean(apr`yr'), by(nivmap)
    quietly egen mmay`yr'=mean(may`yr'), by(nivmap)
    quietly egen mjun`yr'=mean(jun`yr'), by(nivmap)
    quietly egen mjul`yr'=mean(jul`yr'), by(nivmap)
    quietly egen maug`yr'=mean(aug`yr'), by(nivmap)
    quietly egen msep`yr'=mean(sep`yr'), by(nivmap)
    quietly egen moct`yr'=mean(oct`yr'), by(nivmap)
    quietly egen mnov`yr'=mean(nov`yr'), by(nivmap)
    quietly egen mdec`yr'=mean(dec`yr'), by(nivmap)
    drop jan`yr'-dec`yr'
    rename mjan`yr' jan`yr'
    rename mfeb`yr' feb`yr'
    rename mmar`yr' mar`yr'
    rename mapr`yr' apr`yr'
    rename mmay`yr' may`yr'
    rename mjun`yr' jun`yr'
    rename mjul`yr' jul`yr'
    rename maug`yr' aug`yr'
    rename msep`yr' sep`yr'
    rename moct`yr' oct`yr'
    rename mnov`yr' nov`yr'
    rename mdec`yr' dec`yr'
    local yr=`yr'+1
}
sort nivmap 
quietly by nivmap: keep if _n==1
drop niv100
preserve
   use "brazprod/filters/niv10080", clear
   drop niv100 
   sort niv80
   quietly by niv80: keep if _n==1
   sort nivmap
   save `tmp5', replace
restore
joinby nivmap using `tmp5'
drop nivmap
order niv80 jan86-dec98
sort niv80
if `choice'==1 {drop jan86-dec89}
save `master', replace

/* Merge data, create & multiply matrices */
local yr 86
if `choice'==1 {local yr 90}
while `yr'<=98 {
use `inout`yr'', clear
merge niv80 using `master'
keep if _merge==3
drop _merge
local i 2
while `i'<=32 {
    if `i'==9 {local i 10}
    quietly egen tot`i'=sum(ativ`i')
    qui replace ativ`i'=ativ`i'/tot`i'
    drop tot`i'
    local i=`i'+1
}
sort niv80
mkmat ativ2-ativ32, matrix(W)
mkmat jan`yr'-dec`yr', matrix(M)
matrix DEFL=W'*M
matrix drop W M
matrix input ativ = (2,3,4,5,6,7,8,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32)
matrix DEFL = ativ' , DEFL
if `choice'~=1 {drop niv80 ativ2-ativ32 jan86-dec98}
    else       {drop niv80 ativ2-ativ32 jan90-dec98}
svmat double DEFL, names(col)
gen byte ativ80=r1
drop r1
format ativ80 %2.0f
label var ativ80 "Activity (NIV80 Ativ.)"
label var jan`yr' "Jan-`yr'"
label var feb`yr' "Feb-`yr'"
label var mar`yr' "Mar-`yr'"
label var apr`yr' "Apr-`yr'"
label var may`yr' "May-`yr'"
label var jun`yr' "Jun-`yr'"
label var jul`yr' "Jul-`yr'"
label var aug`yr' "Aug-`yr'"
label var sep`yr' "Sep-`yr'"
label var oct`yr' "Oct-`yr'"
label var nov`yr' "Nov-`yr'"
label var dec`yr' "Dec-`yr'"
format jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr' %10.0g  
sort ativ80
save `indfl`yr'', replace
local yr=`yr'+1
}
if `choice'~=1 {
    use `indfl86', replace
    local yr 87
}
 else {
    use `indfl90', replace
    local yr 91
    }
while `yr'<=98  {
    merge using `indfl`yr''
    drop _merge
    local yr=`yr'+1
}
preserve
    use "brazprod/filters/niv10080", clear
    gen byte ativ80=int(niv80/100)
    keep ativ80 niv100
    sort niv100
    quietly by niv100: keep if _n==1
    sort ativ80
    format ativ80 %2.0f
    format niv100 %4.0f
    label var niv100 "Sector of Firm (NIV100)"
    label var ativ80 "Activity (NIV80 Ativ.)"
    save `tmp6', replace
restore
joinby ativ80 using `tmp6'
order ativ80 niv100
sort ativ80 niv100
compress
if `choice'==1 {save "brazprod/deflate/input-defl-mesq", replace}
if `choice'==2 {save "brazprod/deflate/input-defl-pim", replace}
if `choice'==3 {save "brazprod/deflate/input-defl-ipa", replace}
if `choice'==4 {save "brazprod/deflate/input-defl-di", replace}
if `choice'==5 {save "brazprod/deflate/input-defl-forppi`fdfl'", replace}
local choice=`choice'+1
}

matrix drop DEFL ativ trfinpmo
