version 7
set matsize 200

tempfile mesq pim fgvipa fgvdi master tmp0 tmp1 tmp2 tmp3 tmp4 

/* Produced Deflators  1: Mesquita (and general) Deflators 90-98 */
/*                     2: PIM-IBGE (and general) Deflators 86-98 */
/*                     3: FGV-IPA  (and general) Deflators 86-98 */
/*                     4: FGV-DI   (and general) Deflators 86-98 */
/* All deflator types will be created in loops */


/* Mesquita Output Deflators */
/*---------------------------*/
insheet using "brazprod\deflate\mesquita\mesq-deflators.csv", clear
rename nivel100 niv100
rename v1 descript
label var indtype "Type of Industry"
label var niv100 "Sector of Firm (NIV100)"
label var descript "Sector Description (NIV100)"
format niv100 %4.0f
format indtype %-4s
format descript %-45s
drop if niv100==.
order niv100 indtype jan90-dec98
sort niv100
save `mesq', replace

/* PIM Output Deflators */
/*----------------------*/
local yr 86
while `yr'<=99 {
    insheet using "brazprod\deflate\pim-deflatores\pim-deflatores.csv", clear
    gen byte year=v1-1900
    keep if year==`yr'
    drop v1
    rename v2 month
    gen byte genero=int(real(substr(v3,1,2)))
    drop v3
    rename v4 defl
    quietly reshape wide defl, i(genero) j(month)
    rename defl1  jan`yr'
    rename defl2  feb`yr'
    rename defl3  mar`yr'
    rename defl4  apr`yr'
    rename defl5  may`yr'
    rename defl6  jun`yr'
    rename defl7  jul`yr'
    rename defl8  aug`yr'
    rename defl9  sep`yr'
    rename defl10 oct`yr'
    rename defl11 nov`yr'
    rename defl12 dec`yr'
    label var jan`yr' "Jan-`yr'"
    label var feb`yr' "Feb-`yr'"
    label var mar`yr' "Mar-`yr'"
    label var apr`yr' "Apr-`yr'"
    label var may`yr' "May-`yr'"
    label var jun`yr' "Jun-`yr'"
    label var jul`yr' "Jul-`yr'"
    label var aug`yr' "Aug-`yr'"
    label var sep`yr' "Sep-`yr'"
    label var oct`yr' "Oct-`yr'"
    label var nov`yr' "Nov-`yr'"
    label var dec`yr' "Dec-`yr'"
    label var genero "Industry (Genero) of Firm"
    drop year
    sort genero
    save `tmp1', replace
    capture use `master', clear
    capture merge genero using `tmp1'
    drop _merge
    sort genero
    save `master', replace
    local yr=`yr'+1
}
sort genero
save `pim', replace

/* FGV-IPA Deflators */
/*-------------------*/
insheet using "brazprod\deflate\fgv\ipa.csv", clear
rename colunas coluna
sort coluna
save `tmp0', replace
insheet using "brazprod\deflate\fgv\n100fgv.csv", clear
rename nivel100 niv100
format niv100 %4.0f
rename descricaoibge descript
format descript %-80s
rename descricaofgv descipa
format descipa %-39s
rename colunac coluna
label var niv100 "Sector of Firm (NIV100)"
label var descript "Sector Description (NIV100)"
label var descipa "Sector Description (IPA-FGV)"
label var coluna "Wholesale Price Index (IPA-FGV)"
sort coluna 
order niv100 descript coluna descipa
merge coluna using `tmp0', nokeep
drop _merge
sort coluna
save `fgvipa', replace

/* FGV-DI Deflators */
/*-------------------*/
insheet using "brazprod\deflate\fgv\ipadi.csv", clear
rename v1 ipadi
sort ipadi
save `tmp0', replace
insheet using "brazprod\deflate\fgv\n100ipadi.csv", clear
rename nivel100 niv100
format niv100 %4.0f
rename v2 descdi
format descdi %-80s
format ipadi %-9s
label var niv100 "Sector of Firm (NIV100)"
label var descdi "Sector Description (DI-FGV)"
label var ipadi "Domestic Price Index (DI-FGV)"
sort ipadi
order niv100 ipadi descdi
merge ipadi using `tmp0', nokeep
keep if _merge==3
drop _merge
local yr 86
while `yr'<=99 {
    egen mjan`yr'=mean(jan`yr'), by(niv100)
    egen mfeb`yr'=mean(feb`yr'), by(niv100)
    egen mmar`yr'=mean(mar`yr'), by(niv100)
    egen mapr`yr'=mean(apr`yr'), by(niv100)
    egen mmay`yr'=mean(may`yr'), by(niv100)
    egen mjun`yr'=mean(jun`yr'), by(niv100)
    egen mjul`yr'=mean(jul`yr'), by(niv100)
    egen maug`yr'=mean(aug`yr'), by(niv100)
    egen msep`yr'=mean(sep`yr'), by(niv100)
    egen moct`yr'=mean(oct`yr'), by(niv100)
    egen mnov`yr'=mean(nov`yr'), by(niv100)
    egen mdec`yr'=mean(dec`yr'), by(niv100)
    drop jan`yr'-dec`yr'
    rename mjan`yr' jan`yr'
    rename mfeb`yr' feb`yr'
    rename mmar`yr' mar`yr'
    rename mapr`yr' apr`yr'
    rename mmay`yr' may`yr'
    rename mjun`yr' jun`yr'
    rename mjul`yr' jul`yr'
    rename maug`yr' aug`yr'
    rename msep`yr' sep`yr'
    rename moct`yr' oct`yr'
    rename mnov`yr' nov`yr'
    rename mdec`yr' dec`yr'
    label var jan`yr' "Jan-`yr'"
    label var feb`yr' "Feb-`yr'"
    label var mar`yr' "Mar-`yr'"
    label var apr`yr' "Apr-`yr'"
    label var may`yr' "May-`yr'"
    label var jun`yr' "Jun-`yr'"
    label var jul`yr' "Jul-`yr'"
    label var aug`yr' "Aug-`yr'"
    label var sep`yr' "Sep-`yr'"
    label var oct`yr' "Oct-`yr'"
    label var nov`yr' "Nov-`yr'"
    label var dec`yr' "Dec-`yr'"
    local yr=`yr'+1
}
sort niv100
quietly by niv100: keep if _n==1
sort ipadi
save `fgvdi', replace

/* INPC AND FURTHER GENERAL DEFL'S  */
/*----------------------------------*/
insheet using "brazprod\deflate\ibge\inpc.csv", clear
drop if substr(data,5,2)=="85"
mkmat inpc-inpcrea, matrix(SER)
matrix SER=SER'
drop data-inpcrea
svmat double SER
gen str10 defltype="inpc"
replace defltype="igp-di" in 2
replace defltype="inpc-real" in 3
format defltype %-10s
label var defltype "Deflator"
local i 1
while `i'<=168 {
  local yr=85+int(`i'/12+(1-1/12))
  if (`i'+11)/12==int((`i'+11)/12) {rename SER`i' jan`yr'}
  capture label var jan`yr' "Jan-`yr'"
  if (`i'+10)/12==int((`i'+10)/12) {rename SER`i' feb`yr'}
  capture label var feb`yr' "Feb-`yr'"
  if (`i'+9)/12==int((`i'+9)/12)   {rename SER`i' mar`yr'}
  capture label var mar`yr' "Mar-`yr'"
  if (`i'+8)/12==int((`i'+8)/12)   {rename SER`i' apr`yr'}
  capture label var apr`yr' "Apr-`yr'"
  if (`i'+7)/12==int((`i'+7)/12)   {rename SER`i' may`yr'}
  capture label var may`yr' "May-`yr'"
  if (`i'+6)/12==int((`i'+6)/12)   {rename SER`i' jun`yr'}
  capture label var jun`yr' "Jun-`yr'"
  if (`i'+5)/12==int((`i'+5)/12)   {rename SER`i' jul`yr'}
  capture label var jul`yr' "Jul-`yr'"
  if (`i'+4)/12==int((`i'+4)/12)   {rename SER`i' aug`yr'}
  capture label var aug`yr' "Aug-`yr'"
  if (`i'+3)/12==int((`i'+3)/12)   {rename SER`i' sep`yr'}
  capture label var sep`yr' "Sep-`yr'"
  if (`i'+2)/12==int((`i'+2)/12)   {rename SER`i' oct`yr'}
  capture label var oct`yr' "Oct-`yr'"
  if (`i'+1)/12==int((`i'+1)/12)   {rename SER`i' nov`yr'}
  capture label var nov`yr' "Nov-`yr'"
  if (`i')/12==int((`i')/12)       {rename SER`i' dec`yr'}
  capture label var dec`yr' "Dec-`yr'"
  local i=`i'+1
}
order defltype
preserve
    insheet using "brazprod\deflate\fgv\ipa.csv", clear
    sort coluna
    keep if coluna==3 | coluna==27 | coluna==29
    gen str10 defltype="ipa-og" in 1
    replace defltype="ipa-indtot" in 2
    replace defltype="ipa-transf" in 3
    drop coluna
    save `tmp0', replace
restore
append using `tmp0'
preserve
    insheet using "brazprod\deflate\us-fedstat\defl-usd-cpia.csv", clear
    drop half-avgavg
    rename june jun
    rename july jul
    replace year=year-1900
    gen str10 defltype="usd-cpiai"
    keep if year>=86 & year<=99
    reshape wide jan feb mar apr may jun jul aug sep oct nov dec, i(defltype) j(year)
    save `tmp0', replace
restore
append using `tmp0'
preserve
    insheet using "brazprod\deflate\us-fedstat\defl-usd-prod.csv", clear
    drop ann
    replace year=year-1900
    gen str10 defltype="usd-prodpi"
    keep if year>=86 & year<=99
    reshape wide jan feb mar apr may jun jul aug sep oct nov dec, i(defltype) j(year)
    save `tmp0', replace
restore
append using `tmp0'
preserve
    insheet using "brazprod\deflate\us-fedstat\defl-usd-intl.csv", clear
    replace year=year-1900
    gen str10 defltype="usd-intlpi"
    keep if year>=86 & year<=99
    drop if jan==. | feb==. | mar==. | apr==. | may==. | jun==. | jul==. | aug==. | sep==. | oct==. | nov==. | dec==.
    reshape wide jan feb mar apr may jun jul aug sep oct nov dec, i(defltype) j(year)
    save `tmp0', replace
restore
append using `tmp0'
egen byte inddefl=group(defltype)
format inddefl %1.0f
label var inddefl "Number of Deflator"
order defltype inddefl
local yr 86
while `yr'<=99 {
    if `yr'~=90 {quietly replace jan`yr'=(jan`yr'/jan90)*100}
    quietly replace feb`yr'=(feb`yr'/jan90)*100
    quietly replace mar`yr'=(mar`yr'/jan90)*100
    quietly replace apr`yr'=(apr`yr'/jan90)*100
    quietly replace may`yr'=(may`yr'/jan90)*100
    quietly replace jun`yr'=(jun`yr'/jan90)*100
    quietly replace jul`yr'=(jul`yr'/jan90)*100
    quietly replace aug`yr'=(aug`yr'/jan90)*100
    quietly replace sep`yr'=(sep`yr'/jan90)*100
    quietly replace oct`yr'=(oct`yr'/jan90)*100
    quietly replace nov`yr'=(nov`yr'/jan90)*100
    quietly replace dec`yr'=(dec`yr'/jan90)*100
    local yr=`yr'+1
}
    quietly replace jan90=100
sort defltype
save "brazprod\deflate\general-defl", replace

/* OTN, BTN, FAP, UFIR: Governmentally Imposed Deflators  */
/*--------------------------------------------------------*/
insheet using "brazprod\deflate\ibge\otn-ufir.csv", clear
rename v1 data
drop if substr(data,5,2)=="85" | data==""
local otnfact=otnfina[38]
gen govativo=otn
gen govbaixa=otnbaix
replace govativo=`otnfact'*btn if govativo==.
replace govbaixa=`otnfact'*btn if govbaixa==.
replace govativo=`otnfact'*fap if govativo==.
replace govbaixa=`otnfact'*fap if govbaixa==.
replace govativo=`otnfact'*ufir if govativo==.
replace govbaixa=`otnfact'*ufir if govbaixa==.
gen int year=real(substr(data,5,2))+1900
egen byte month=fill(1(1)12 1(1)12)
gen date=ym(year,month)
format date %tm
drop month year
order data date
/* Transform deflators to base "Real" 1995 */
capture program drop nominal
program define nominal
  args varname
  replace `varname'=`varname'/(2.75*1000000000) if date<=ym(1986,2)
  replace `varname'=`varname'/(2.75*1000000) if date>ym(1986,2) & date<=ym(1993,7)
  replace `varname'=`varname'/(2.75*1000) if date>ym(1993,7) & date<=ym(1994,6)
end
nominal otn
nominal otnbaix
nominal otnfina
nominal fap
nominal ufir
nominal govativo
nominal govbaixa
keep data gov*
mkmat gov*, matrix(SER)
matrix SER=SER'
drop data gov*
svmat double SER
gen str13 defltype="govdefl-asset"
replace defltype="govdefl-decap" in 2
format defltype %-13s
label var defltype "Governmental Deflator"
local i 1
while `i'<=168 {
  local yr=85+int(`i'/12+(1-1/12))
  if (`i'+11)/12==int((`i'+11)/12) {rename SER`i' jan`yr'}
  capture label var jan`yr' "Jan-`yr'"
  if (`i'+10)/12==int((`i'+10)/12) {rename SER`i' feb`yr'}
  capture label var feb`yr' "Feb-`yr'"
  if (`i'+9)/12==int((`i'+9)/12)   {rename SER`i' mar`yr'}
  capture label var mar`yr' "Mar-`yr'"
  if (`i'+8)/12==int((`i'+8)/12)   {rename SER`i' apr`yr'}
  capture label var apr`yr' "Apr-`yr'"
  if (`i'+7)/12==int((`i'+7)/12)   {rename SER`i' may`yr'}
  capture label var may`yr' "May-`yr'"
  if (`i'+6)/12==int((`i'+6)/12)   {rename SER`i' jun`yr'}
  capture label var jun`yr' "Jun-`yr'"
  if (`i'+5)/12==int((`i'+5)/12)   {rename SER`i' jul`yr'}
  capture label var jul`yr' "Jul-`yr'"
  if (`i'+4)/12==int((`i'+4)/12)   {rename SER`i' aug`yr'}
  capture label var aug`yr' "Aug-`yr'"
  if (`i'+3)/12==int((`i'+3)/12)   {rename SER`i' sep`yr'}
  capture label var sep`yr' "Sep-`yr'"
  if (`i'+2)/12==int((`i'+2)/12)   {rename SER`i' oct`yr'}
  capture label var oct`yr' "Oct-`yr'"
  if (`i'+1)/12==int((`i'+1)/12)   {rename SER`i' nov`yr'}
  capture label var nov`yr' "Nov-`yr'"
  if (`i')/12==int((`i')/12)       {rename SER`i' dec`yr'}
  capture label var dec`yr' "Dec-`yr'"
  local i=`i'+1
}
order defltype
egen byte inddefl=group(defltype)
format inddefl %1.0f
label var inddefl "Number of Deflator"
order defltype inddefl
local yr 86
while `yr'<=99 {
    if `yr'~=90 {quietly replace jan`yr'=(jan`yr'/jan90)*100}
    quietly replace feb`yr'=(feb`yr'/jan90)*100
    quietly replace mar`yr'=(mar`yr'/jan90)*100
    quietly replace apr`yr'=(apr`yr'/jan90)*100
    quietly replace may`yr'=(may`yr'/jan90)*100
    quietly replace jun`yr'=(jun`yr'/jan90)*100
    quietly replace jul`yr'=(jul`yr'/jan90)*100
    quietly replace aug`yr'=(aug`yr'/jan90)*100
    quietly replace sep`yr'=(sep`yr'/jan90)*100
    quietly replace oct`yr'=(oct`yr'/jan90)*100
    quietly replace nov`yr'=(nov`yr'/jan90)*100
    quietly replace dec`yr'=(dec`yr'/jan90)*100
    local yr=`yr'+1
}
    quietly replace jan90=100
sort defltype
save "brazprod\deflate\gov-otn-ufir", replace


/* Marc & Adriana's Output Deflators */
/*-----------------------------------*/
local choice 1
while `choice'<=4 {
insheet using "brazprod\deflate\niv100-genero-comp.csv", clear
format niv100 %4.0f
format indtype %-4s
format descript %-80s
format genero %2.0f
format mesq validgen validlia %1.0f
format liaipacl %5.0g
label var indtype "Type of Industry"
label var niv100 "Sector of Firm (NIV100)"
label var genero "Industry (Genero) of Firm"
label var descript "Sector Description (NIV100)"
label var mesq "Mesquita Deflator Available"
label var validgen "Use of Genero Defl. (PIM) Valid"
label var liaipacl "Lia Haguenauer's IPA (Col FGV)"
label var validlia "Use of Lia's Defl. Valid"
sort genero
preserve
    insheet using "brazprod\deflate\genero-fgv-comp.csv", clear
    drop if genero==.
    rename generoib genero
    format genero %2.0f
    label var genero "Industry (Genero) of Firm"
    rename colunaco genipacl
    format genipacl %2.0f
    label var genipacl "Genero (PIM) Comp. IPA (Col FGV)"
    sort genero
    save `tmp2', replace
restore
merge genero using `tmp2', nokeep
drop _merge
order niv100 descript genero indtype mesq genipacl validgen liaipacl validlia
sort niv100
drop genipacl-validlia
save `master', replace
/* Read-in Mesquita Indices */
if `choice'==1 {
    use `mesq', clear
    sort niv100
    save `tmp3', replace
}
/* Read-in PIM Indices */
if `choice'==2 {
    sort genero
    save `tmp4', replace
    use `pim', clear
    local yr 86
    while `yr'<=99 {
    if `yr'~=90 {quietly replace jan`yr'=(jan`yr'/jan90)*100}
    quietly replace feb`yr'=(feb`yr'/jan90)*100
    quietly replace mar`yr'=(mar`yr'/jan90)*100
    quietly replace apr`yr'=(apr`yr'/jan90)*100
    quietly replace may`yr'=(may`yr'/jan90)*100
    quietly replace jun`yr'=(jun`yr'/jan90)*100
    quietly replace jul`yr'=(jul`yr'/jan90)*100
    quietly replace aug`yr'=(aug`yr'/jan90)*100
    quietly replace sep`yr'=(sep`yr'/jan90)*100
    quietly replace oct`yr'=(oct`yr'/jan90)*100
    quietly replace nov`yr'=(nov`yr'/jan90)*100
    quietly replace dec`yr'=(dec`yr'/jan90)*100
    format jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr' %10.0g  
    local yr=`yr'+1
    }
    quietly replace jan90=100
    sort genero
    merge genero using `tmp4'
    keep if _merge==3
    drop _merge genero descript indtype mesq
    sort niv100
    save `tmp3', replace
}
/* Read-in FGV-IPA Indices */
if `choice'==3 {
    use `fgvipa', clear
    local yr 86
    while `yr'<=99 {
    if `yr'~=90 {quietly replace jan`yr'=(jan`yr'/jan90)*100}
    quietly replace feb`yr'=(feb`yr'/jan90)*100
    quietly replace mar`yr'=(mar`yr'/jan90)*100
    quietly replace apr`yr'=(apr`yr'/jan90)*100
    quietly replace may`yr'=(may`yr'/jan90)*100
    quietly replace jun`yr'=(jun`yr'/jan90)*100
    quietly replace jul`yr'=(jul`yr'/jan90)*100
    quietly replace aug`yr'=(aug`yr'/jan90)*100
    quietly replace sep`yr'=(sep`yr'/jan90)*100
    quietly replace oct`yr'=(oct`yr'/jan90)*100
    quietly replace nov`yr'=(nov`yr'/jan90)*100
    quietly replace dec`yr'=(dec`yr'/jan90)*100
    format jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr' %10.0g  
    local yr=`yr'+1
    }
    quietly replace jan90=100
    sort niv100
    save `tmp3', replace
}
/* Read-in FGV-DI Indices */
if `choice'==4 {
    use `fgvdi', clear
    local yr 86
    while `yr'<=99 {
    if `yr'~=90 {quietly replace jan`yr'=(jan`yr'/jan90)*100}
    quietly replace feb`yr'=(feb`yr'/jan90)*100
    quietly replace mar`yr'=(mar`yr'/jan90)*100
    quietly replace apr`yr'=(apr`yr'/jan90)*100
    quietly replace may`yr'=(may`yr'/jan90)*100
    quietly replace jun`yr'=(jun`yr'/jan90)*100
    quietly replace jul`yr'=(jul`yr'/jan90)*100
    quietly replace aug`yr'=(aug`yr'/jan90)*100
    quietly replace sep`yr'=(sep`yr'/jan90)*100
    quietly replace oct`yr'=(oct`yr'/jan90)*100
    quietly replace nov`yr'=(nov`yr'/jan90)*100
    quietly replace dec`yr'=(dec`yr'/jan90)*100
    format jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr' %10.0g  
    local yr=`yr'+1
    }
    quietly replace jan90=100
    sort niv100
    save `tmp3', replace
}
use `master', clear
merge niv100 using `tmp3', update replace
drop _merge
/* Conclude sector-specific indices and append reporting file */
sort niv100
preserve
    capture drop jan86-dec89
    drop jan90-dec98
    capture drop jan99
    capture drop feb99-dec99
    merge niv100 using "brazprod\filters\niv10080"
    keep if _merge==3
    gen byte ativ80=int(niv80/100)
    drop _merge niv80
    rename nivmap niv80map
    label var niv80map "NIV80 Compatible Sector"
    label var ativ80 "Activity (NIV80 Ativ.)"
    order niv100 ativ80 niv80map
    sort niv100
    quietly by niv100: keep if _n==1
    sort niv100
    capture merge niv100 using "brazprod\deflate\comp-defl"  /* Add existing information beyond current information */
    capture drop _merge
    sort niv100
    compress
    save "brazprod\deflate\comp-defl", replace
restore
compress
if `choice'==1 {
    keep if mesq==1
    keep niv100 jan90-dec98
    local yr 86
    while `yr'<=89 {
    gen jan`yr'=.
    gen feb`yr'=.
    gen mar`yr'=.
    gen apr`yr'=.
    gen may`yr'=.
    gen jun`yr'=.
    gen jul`yr'=.
    gen aug`yr'=.
    gen sep`yr'=.
    gen oct`yr'=.
    gen nov`yr'=.
    gen dec`yr'=.
    local yr=`yr'+1
    }
    order niv100 jan86-dec89 jan90-dec98
    save "brazprod\deflate\output-defl-mesq", replace
}
if `choice'==2 {
    keep niv100 jan86-dec99
    save "brazprod\deflate\output-defl-pim", replace
}
if `choice'==3 {
    keep niv100 jan86-dec99
    save "brazprod\deflate\output-defl-ipa", replace
}
if `choice'==4 {
    keep niv100 jan86-dec99
    save "brazprod\deflate\output-defl-di", replace
}
local choice=`choice'+1
}

matrix drop SER
