version 7
set matsize 160
tempfile weights cmplwght conc nivlst usappd ppicompl ppioecd ppieu ppinam nomex

/* OECD-Niv100 concordance */
/*-------------------------*/

use "brazprod/filters/niv100-oecd-conc", clear
keep niv100 oecdsec
sort oecdsec
compress
save `conc'

/* Prepare import weights (1995) */
/*-------------------------------*/

insheet using "brazprod/addl/ivs/brazil-trade/aladi-origins.csv", clear
drop country
rename country_ppi country
keep if country~=""
keep country v4  /* 1995 */
rename v4 weight
qui egen _tot=sum(weight)
qui replace weight=weight/_tot
drop _tot
qui replace country = lower(subinstr(country," ","",.))
qui replace country = "uk" if country=="unitedkingdom"
qui replace country = "usa" if country=="unitedstates"
compress
sort country
save `weights'
insheet using "brazprod/addl/ivs/brazil-trade/aladi-origins.csv", clear
qui replace country = country_ppi if country==""
keep if country~=""
keep country v4  /* 1995 */
rename v4 weight
qui egen _tot=sum(weight)
qui replace weight=weight/_tot
drop _tot
qui replace country = lower(subinstr(country," ","",.))
qui replace country = "uk" if country=="unitedkingdom"
qui replace country = "usa" if country=="unitedstates"
compress
sort country
save `cmplwght'

/* Monthly nominal exchange rate */
/*-------------------------------*/

use "brazprod/deflate/realexch", clear
keep if defltype=="dolarmedio" | defltype=="ipa-og" | defltype=="realexch"
mkmat jan86-dec98 if defltype=="dolarmedio", matrix(dolar)
mkmat jan86-dec98 if defltype=="ipa-og", matrix(ipaog)
mkmat jan86-dec98 if defltype=="realexch", matrix(realx)
matrix dolar=dolar'
matrix ipaog=ipaog'
matrix realx=realx'
drop _all
svmat dolar, names("dollar")
svmat ipaog, names("ipaog")
svmat realx, names("realexch")
rename dollar1 dollar
rename ipaog1 ipaog
rename realexch1 realexch
local rnam : rownames dolar
gen str5 month=""
tokenize `rnam'
local j 1
while `j' <= rowsof(dolar) {
    quietly replace month = "``j''" in `j'
    local j=`j'+1
}
order month
matrix drop ipaog realx
gen int year=int(real(substr(month,-2,2)))+1900
gen nomexch_p=dollar/ipaog
label var dollar "Nom. Exch.Rate with US$"
label var nomexch_p "Nom.Exch.Rate: E/P"
label var realexch  "Real.Exch.Rate: E P*[$]/P"
gen _month = mod(_n,12)
qui replace _month = 12 if _month==0
drop month
rename _month month
qui replace year = year-1900
order year month dollar ipaog nomex realex
sort year month
compress
save `nomex'


/* PPI OECD */
/*----------*/

use "brazprod/addl/ivs/ppi-oecd/oecd-ppi", clear
* Rebase to 1995, all sectors in France and some in Denmark get lost
order country oecdsec year ppi
sort country oecdsec year ppi
gen _ppi95 = ppi if year==95
egen _ppibase = min(_ppi95), by(country oecdsec)
qui replace ppi = ppi/_ppibase
drop _*

qui replace country = lower(subinstr(country," ","",.))
qui replace country = "uk" if country=="unitedkingdom"
qui replace country = "usa" if country=="unitedstates"
sort country
joinby country using `weights', unmatched(both) _merge(_merge)
count if _merge~=3
if `r(N)' > 0 { 
    tab _merge
    STOP 
    }
drop _merge
label var weight "Weight: 1995 imports"
compress

qui replace oecdsec = 311.2 if oecdsec==3112
qui replace oecdsec = 351.2 if oecdsec==3512
sort oecdsec
joinby oecdsec using `conc', unmatched(both) _merge(_merge)
drop if _merge==1
drop _merge oecdsec
order niv100 year country
sort niv100 year country
order country niv100 year
sort  country niv100 year
compress
expand 12
sort country niv100 year
by country niv100 year: gen byte month = _n
sort country niv100 year
order country niv100 year month
gen _midyrppi = ppi
qui replace ppi = _midyrppi + (_midyrppi[_n+12]-_midyrppi)/12   if month== 7 & year<98
qui replace ppi = _midyrppi + (_midyrppi[_n+12]-_midyrppi)/12*2 if month== 8 & year<98
qui replace ppi = _midyrppi + (_midyrppi[_n+12]-_midyrppi)/12*3 if month== 9 & year<98
qui replace ppi = _midyrppi + (_midyrppi[_n+12]-_midyrppi)/12*4 if month==10 & year<98
qui replace ppi = _midyrppi + (_midyrppi[_n+12]-_midyrppi)/12*5 if month==11 & year<98
qui replace ppi = _midyrppi + (_midyrppi[_n+12]-_midyrppi)/12*6 if month==12 & year<98
qui replace ppi = _midyrppi - (_midyrppi-_midyrppi[_n-12])/12*5 if month== 1 & year>86
qui replace ppi = _midyrppi - (_midyrppi-_midyrppi[_n-12])/12*4 if month== 2 & year>86
qui replace ppi = _midyrppi - (_midyrppi-_midyrppi[_n-12])/12*3 if month== 3 & year>86
qui replace ppi = _midyrppi - (_midyrppi-_midyrppi[_n-12])/12*2 if month== 4 & year>86
qui replace ppi = _midyrppi - (_midyrppi-_midyrppi[_n-12])/12   if month== 5 & year>86
* qui replace ppi = _midyrppi                                   if month== 6 & year>86
qui replace ppi = _midyrppi - (ppi[_n+2]-_midyrppi)   if month== 5 & (year==86 | (ppi==. & _midyrppi~=.))
qui replace ppi = _midyrppi - (ppi[_n+3]-_midyrppi)*2 if month== 4 & (year==86 | (ppi==. & _midyrppi~=.))
qui replace ppi = _midyrppi - (ppi[_n+4]-_midyrppi)*3 if month== 3 & (year==86 | (ppi==. & _midyrppi~=.))
qui replace ppi = _midyrppi - (ppi[_n+5]-_midyrppi)*4 if month== 2 & (year==86 | (ppi==. & _midyrppi~=.))
qui replace ppi = _midyrppi - (ppi[_n+6]-_midyrppi)*5 if month== 1 & (year==86 | (ppi==. & _midyrppi~=.))
qui replace ppi = _midyrppi - (ppi[_n-2]-_midyrppi)   if month== 7 & (year==98 | (ppi==. & _midyrppi~=.))
qui replace ppi = _midyrppi - (ppi[_n-3]-_midyrppi)*2 if month== 8 & (year==98 | (ppi==. & _midyrppi~=.))
qui replace ppi = _midyrppi - (ppi[_n-4]-_midyrppi)*3 if month== 9 & (year==98 | (ppi==. & _midyrppi~=.))
qui replace ppi = _midyrppi - (ppi[_n-5]-_midyrppi)*4 if month==10 & (year==98 | (ppi==. & _midyrppi~=.))
qui replace ppi = _midyrppi - (ppi[_n-6]-_midyrppi)*5 if month==11 & (year==98 | (ppi==. & _midyrppi~=.))
qui replace ppi = _midyrppi - (ppi[_n-7]-_midyrppi)*6 if month==12 & (year==98 | (ppi==. & _midyrppi~=.))
* Rebase to June 1995
qui gen _ppi95 = ppi if year==95 & month==6
qui egen _ppibase = min(_ppi95), by(country niv100)
qui replace ppi = ppi/_ppibase
drop _*
order niv100 year country month
sort niv100 year country month
compress

preserve
  keep niv100 year
  sort niv100 year
  by niv100 year: keep if _n==1
  sort year niv100
  compress
  save `nivlst'
restore
preserve
  use "brazprod/addl/ivs/ppi-us/us-ppi", clear
  drop sic2d
  qui gen _month = real(substr(month,2,2))
  drop if _month == 13
  drop month
  rename _month month
  compress
  gen str13 country = "United States"
  order niv100 year country month
  qui replace year=year-1900
  drop if year<86 | year>98
  * Rebase to June 1995
  qui gen _ppi95 = ppi if year==95 & month==6
  qui egen _ppibase = min(_ppi95), by(niv100)
  qui replace ppi = ppi/_ppibase
  drop _*
  qui replace country = lower(subinstr(country," ","",.))
  qui replace country = "uk" if country=="unitedkingdom"
  qui replace country = "usa" if country=="unitedstates"
  sort country
  joinby country using `weights', unmatched(both) _merge(_merge)
  count if _merge==1
  if `r(N)' > 0 { 
      tab _merge
      STOP 
      }
  drop if _merge~=3
  drop _merge
  label var weight "Weight: 1995 imports"
  qui replace country = "usa_bls"
  compress
  order niv100 year month country
  sort niv100 year month country
  save `usappd'
restore

append using `usappd'
label var month "Month"
sort niv100 year month country
preserve
  drop weight
  rename ppi wpippi
  save `ppicompl'
restore

encode country, generate(cntry)
drop country

/* australia austria belgium canada denmark finland france germany greece ireland italy japan luxembourg netherlands newzealand norway spain sweden switzerland turkey uk usa usa_bls */
/*    1         2       3       4      5       6      7        8     9       10    11     12      13         14          15       16     17    18        19       20   21  22    23   */
foreach region in "oecd" "eu" "nam" {
  preserve
  if "`region'" == "eu"    {keep if c==2 | c==3 | c==5 | c==6 | c==7 | c==8 | c==9 | c==10 | c==11 | c==13 | c==14 | c==17 | c==18 | c==21}
  if "`region'" == "nam"   {keep if c==4 | c==23}
  collapse (mean) ppi [iw=weight], by(niv100 year month)
  rename ppi ppi`region'
  local titl = upper("`region'")
  label var ppi`region' "PPI Idx. `titl', import-weight 95"
  compress
  sort niv100 year
  save `ppi`region''
  restore
  }

use `ppioecd', clear
foreach region in "eu" "nam" {
  sort niv100 year
  merge niv100 year using `ppi`region''
  count if _merge~=3
  if `r(N)' > 0 { 
      tab _merge
      STOP 
      }
  drop _merge
  }

sort year month
merge year month using `nomex', nokeep
drop _merge
drop ipaog nomexch_p realexch
* Rebase dollar to June 1995
qui gen _dollar95 = dollar if year==95 & month==6
qui egen _dollarbase = min(_dollar95), by(niv100)
qui replace dollar = dollar/_dollarbase
drop _*

foreach region in "oecd" "eu" "nam" {
  qui gen _ppi`region'90 = ppi`region' if year==90 & month==1
  qui egen _ppi`region'base = min(_ppi`region'90), by(niv100)
  qui replace ppi`region' = (ppi`region'/_ppi`region'base)*100
  qui gen ppi`region'xusd = ppi`region' * dollar
  qui gen _ppi`region'xusd90 = ppi`region'xusd if year==90 & month==1
  qui egen _ppi`region'xusdbase = min(_ppi`region'xusd90), by(niv100)
  qui replace ppi`region'xusd = (ppi`region'xusd/_ppi`region'xusdbase)*100
  }
drop _* dollar

local i = 0
foreach name in "oecd" "eu" "nam" "oecdxusd" "euxusd" "namxusd" {
  local i = `i' + 1
  rename ppi`name' ppi_`i'
  }
reshape long ppi_, i(niv100 year month) j(series)
qui gen str8 _series = ""
local i = 0
foreach name in "oecd" "eu" "nam" "oecdxusd" "euxusd" "namxusd" {
  local i = `i' + 1
  qui replace _series = "`name'" if series==`i'
  }
drop series
rename _series series
qui replace series = subinstr(series,"xusd","*usdex",.)
qui replace series = subinstr(series,"nam","usacan",.)

reshape wide ppi_, i(niv100 year series) j(month)
reshape wide ppi_*, i(niv100 series) j(year)

local rnam : rownames dolar
tokenize `rnam'
local j = 0
forvalues yr = 86/98 {
 forvalues mo = 1/12 {
  local j = `j'+1
  rename ppi_`mo'`yr' ``j''
 }
 local lblyr = `yr'+1900
 label var jan`yr' "PPI Jan-`lblyr'"
 label var feb`yr' "PPI Feb-`lblyr'"
 label var mar`yr' "PPI Mar-`lblyr'"
 label var apr`yr' "PPI Apr-`lblyr'"
 label var may`yr' "PPI May-`lblyr'"
 label var jun`yr' "PPI Jun-`lblyr'"
 label var jul`yr' "PPI Jul-`lblyr'"
 label var aug`yr' "PPI Aug-`lblyr'"
 label var sep`yr' "PPI Sep-`lblyr'"
 label var oct`yr' "PPI Oct-`lblyr'"
 label var nov`yr' "PPI Nov-`lblyr'"
 label var dec`yr' "PPI Dec-`lblyr'"
}

sort niv100 series
compress
label var series "Index series"
save "brazprod/deflate/foreign-ppi", replace


/* Annual WPI, CPI, PPI World */
/*----------------------------*/

use "brazprod/addl/ivs/findata/world-wpi-cpi-ppi", clear
replace year = year-1900
drop if year<86 | year>98
local i 0
foreach country in "argentina" "belgium" "canada" "chile" "china" "france" "germany" "hongkong" "italy" "japan" "korea" "mexico" "netherlands" "panama" "paraguay" "saudiarabia" "singapur" "spain" "sweden" "switzerland" "taiwan" "uk" "uruguay" "usa" "venezuela" {
    local i = `i' + 1
    rename `country' wpi`i'
    }
reshape long wpi, i(year) j(_cntry)
sort _cntry year
qui gen str12 country = ""
local i 0
foreach country in "argentina" "belgium" "canada" "chile" "china" "france" "germany" "hongkong" "italy" "japan" "korea" "mexico" "netherlands" "panama" "paraguay" "saudiarabia" "singapur" "spain" "sweden" "switzerland" "taiwan" "uk" "uruguay" "usa" "venezuela" {
    local i = `i' + 1
    qui replace country = "`country'" if _cntry==`i'
    }
drop _cntry
order year country wpi
sort year country
gen _wpi95 = wpi if year==95
egen _wpibase = min(_wpi95), by(country)
qui replace wpi = wpi/_wpibase
drop _*
sort year
joinby year using `nivlst', unmatched(both) _merge(_merge)
drop _merge
sort country
joinby country using `weights', unmatched(both) _merge(_merge)
keep if _merge==1  /* Keep unmatched master data only; other countries have PPI */
drop _merge weight

order niv100 year country
sort niv100 year country
compress
expand 12
sort country niv100 year
by country niv100 year: gen byte month = _n
sort country niv100 year month
order country niv100 year month
gen _midyrwpi = wpi
qui replace wpi = _midyrwpi + (_midyrwpi[_n+12]-_midyrwpi)/12   if month== 7 & year<98
qui replace wpi = _midyrwpi + (_midyrwpi[_n+12]-_midyrwpi)/12*2 if month== 8 & year<98
qui replace wpi = _midyrwpi + (_midyrwpi[_n+12]-_midyrwpi)/12*3 if month== 9 & year<98
qui replace wpi = _midyrwpi + (_midyrwpi[_n+12]-_midyrwpi)/12*4 if month==10 & year<98
qui replace wpi = _midyrwpi + (_midyrwpi[_n+12]-_midyrwpi)/12*5 if month==11 & year<98
qui replace wpi = _midyrwpi + (_midyrwpi[_n+12]-_midyrwpi)/12*6 if month==12 & year<98
qui replace wpi = _midyrwpi - (_midyrwpi-_midyrwpi[_n-12])/12*5 if month== 1 & year>86
qui replace wpi = _midyrwpi - (_midyrwpi-_midyrwpi[_n-12])/12*4 if month== 2 & year>86
qui replace wpi = _midyrwpi - (_midyrwpi-_midyrwpi[_n-12])/12*3 if month== 3 & year>86
qui replace wpi = _midyrwpi - (_midyrwpi-_midyrwpi[_n-12])/12*2 if month== 4 & year>86
qui replace wpi = _midyrwpi - (_midyrwpi-_midyrwpi[_n-12])/12   if month== 5 & year>86
* qui replace wpi = _midyrwpi                                   if month== 6 & year>86
qui replace wpi = _midyrwpi - (wpi[_n+2]-_midyrwpi)   if month== 5 & (year==86 | (wpi==. & _midyrwpi~=.))
qui replace wpi = _midyrwpi - (wpi[_n+3]-_midyrwpi)*2 if month== 4 & (year==86 | (wpi==. & _midyrwpi~=.))
qui replace wpi = _midyrwpi - (wpi[_n+4]-_midyrwpi)*3 if month== 3 & (year==86 | (wpi==. & _midyrwpi~=.))
qui replace wpi = _midyrwpi - (wpi[_n+5]-_midyrwpi)*4 if month== 2 & (year==86 | (wpi==. & _midyrwpi~=.))
qui replace wpi = _midyrwpi - (wpi[_n+6]-_midyrwpi)*5 if month== 1 & (year==86 | (wpi==. & _midyrwpi~=.))
qui replace wpi = _midyrwpi - (wpi[_n-2]-_midyrwpi)   if month== 7 & (year==98 | (wpi==. & _midyrwpi~=.))
qui replace wpi = _midyrwpi - (wpi[_n-3]-_midyrwpi)*2 if month== 8 & (year==98 | (wpi==. & _midyrwpi~=.))
qui replace wpi = _midyrwpi - (wpi[_n-4]-_midyrwpi)*3 if month== 9 & (year==98 | (wpi==. & _midyrwpi~=.))
qui replace wpi = _midyrwpi - (wpi[_n-5]-_midyrwpi)*4 if month==10 & (year==98 | (wpi==. & _midyrwpi~=.))
qui replace wpi = _midyrwpi - (wpi[_n-6]-_midyrwpi)*5 if month==11 & (year==98 | (wpi==. & _midyrwpi~=.))
qui replace wpi = _midyrwpi - (wpi[_n-7]-_midyrwpi)*6 if month==12 & (year==98 | (wpi==. & _midyrwpi~=.))
* Rebase to June 1995
qui gen _wpi95 = wpi if year==95 & month==6
qui egen _wpibase = min(_wpi95), by(country niv100)
qui replace wpi = wpi/_wpibase
drop _*
order niv100 country year month
sort niv100 country year month
compress

rename wpi wpippi
append using `ppicompl'
tab country
drop if country=="usa"
replace country="usa" if country=="usa_bls"
sort country
joinby country using `cmplwght', unmatched(both) _merge(_merge)
count if _merge~=3
if `r(N)' > 0 { 
    tab _merge
    STOP 
    }
drop _merge
label var wpippi  "WPI and PPI indexes"
label var weight  "Weight: 1995 imports"
label var month   "Month"
label var country "Country"

compress
collapse (mean) wpippi [iw=weight], by(niv100 year month)
rename wpippi ppicpi
label var ppicpi "PPI-WPI-CPI World, imp.-wght 95"
compress
sort niv100 year month
save "brazprod/addl/ivs/world-wpi-cpi-ppi-sectoral", replace

sort year month
merge year month using `nomex', nokeep
drop _merge
drop ipaog nomexch_p realexch
* Rebase dollar to June 1995
qui gen _dollar95 = dollar if year==95 & month==6
qui egen _dollarbase = min(_dollar95), by(niv100)
qui replace dollar = dollar/_dollarbase
drop _*

qui gen _ppicpi90 = ppicpi if year==90 & month==1
qui egen _ppicpibase = min(_ppicpi90), by(niv100)
qui replace ppicpi = (ppicpi/_ppicpibase)*100
qui gen ppicpixusd = ppicpi * dollar
qui gen _ppicpixusd90 = ppicpixusd if year==90 & month==1
qui egen _ppicpixusdbase = min(_ppicpixusd90), by(niv100)
qui replace ppicpixusd = (ppicpixusd/_ppicpixusdbase)*100
drop _* dollar

local i = 0
foreach name in "cpi" "cpixusd" {
  local i = `i' + 1
  rename ppi`name' ppi_`i'
  }
reshape long ppi_, i(niv100 year month) j(series)
qui gen str8 _series = ""
local i = 0
foreach name in "cpi" "cpixusd" {
  local i = `i' + 1
  qui replace _series = "`name'" if series==`i'
  }
drop series
rename _series series
qui replace series = subinstr(series,"cpi","world",.)
qui replace series = subinstr(series,"xusd","*usdex",.)

reshape wide ppi_, i(niv100 year series) j(month)
reshape wide ppi_*, i(niv100 series) j(year)

local rnam : rownames dolar
tokenize `rnam'
local j = 0
forvalues yr = 86/98 {
 forvalues mo = 1/12 {
  local j = `j'+1
  rename ppi_`mo'`yr' ``j''
 }
 local lblyr = `yr'+1900
 label var jan`yr' "PPI-WPI-CPI Jan-`lblyr'"
 label var feb`yr' "PPI-WPI-CPI Feb-`lblyr'"
 label var mar`yr' "PPI-WPI-CPI Mar-`lblyr'"
 label var apr`yr' "PPI-WPI-CPI Apr-`lblyr'"
 label var may`yr' "PPI-WPI-CPI May-`lblyr'"
 label var jun`yr' "PPI-WPI-CPI Jun-`lblyr'"
 label var jul`yr' "PPI-WPI-CPI Jul-`lblyr'"
 label var aug`yr' "PPI-WPI-CPI Aug-`lblyr'"
 label var sep`yr' "PPI-WPI-CPI Sep-`lblyr'"
 label var oct`yr' "PPI-WPI-CPI Oct-`lblyr'"
 label var nov`yr' "PPI-WPI-CPI Nov-`lblyr'"
 label var dec`yr' "PPI-WPI-CPI Dec-`lblyr'"
}

label var series "Index series"
sort niv100 series
compress
save "brazprod/deflate/foreign-mix", replace

matrix drop dolar
