version 7.0
tempfile pidx nomex pbraz
set matsize 160

/* Brazil's price levels */

insheet using "brazprod/deflate/ibge/inpc-79-mtb-64.csv", clear
keep data inpc
keep if substr(data,1,3)=="Dec"
drop if int(real(substr(data,5,2)))<86
sort data
gen byte year=_n+85
gen pidxbraz=inpc/100
quietly gen _keyyr = pidxbraz[10]  /* 1995 */
replace pidxbraz=pidxbraz/_keyyr
drop _keyyr
label var pidxbraz "Pr.Idx. Brazil (INPC)"
drop data inpc
sort year
save `pbraz'


/* Trading partners' price levels */

use "brazprod/addl/ivs/findata/world-wpi-cpi-ppi", clear
drop if year<1986
mkmat argentina-venezuela, matrix(priceidx) 
local j 1
local rownames=""
while `j'<=_N {
    local add=year[`j']
    local rownames="`rownames'"+" "+"`add'"
    local j=`j'+1
}
local rownames=trim("`rownames'")
matrix rownames priceidx = `rownames'


/* Average foreign price levels */

insheet using "brazprod/addl/ivs/brazil-trade/aladi-origins.csv", clear
drop country_ppi
keep if country~=""
replace country=lower(country)
keep country v4  /* 1995 */
rename v4 weight
egen _tot=sum(weight)
replace weight=weight/_tot
drop _tot
mkmat weight, matrix(weights) 
local j 1
while `j'<=_N {
    local rnm=country[`j']
    matname weights "`rnm'", rows(`j') explicit
    local j=`j'+1
}
matrix pidxwrld=priceidx*weights
matrix colnames pidxwrld= pidxwrld
use "brazprod/addl/ivs/findata/world-wpi-cpi-ppi", clear
drop if year<1986
svmat pidxwrld, names(col)
label var pidxwrld "Pr.Idx. World, import-weight 95"
save `pidx'

/* panama china paraguay singapur sweden taiwan belgium spain netherlands mexico venezuela hongkong uk uruguay switzerland chile canada saudiarabia korea france japan italy germany argentina usa */
/*    1     2      3        4        5      6      7      8        9        10       11        12   13    14        15       16    17        18       19    20     21    22     23       24     25 */
foreach region in "asia" "mest" "eu" "sam" "nam" {
    if "`region'" == "asia"  {local list = "2 4 6 12 19 21"}
    if "`region'" == "mest"  {local list = "18"}
    if "`region'" == "eu"    {local list = "5 7 8 9 13 15 20 22 23"}
    if "`region'" == "sam"   {local list = "1 3 10 11 14 16 24"}
    if "`region'" == "nam"   {local list = "17 25"}
    matrix w`region' = J(25,1,0)
    foreach row of local list {
        matrix w`region'[`row',1]=weights[`row',1]
        matrix _tot=J(1,25,1)*w`region'
        local tot = _tot[1,1]
        forvalues i = 1/25 {matrix w`region'[`i',1]=w`region'[`i',1]/`tot'}
        matrix drop _tot
        }
    matrix pidx`region'=priceidx*w`region'
    matrix colnames pidx`region'= pidx`region'
    svmat pidx`region', names(col)
}
label var pidxasia "Pr.Idx. Asia, import-weight 95"
label var pidxmest "Pr.Idx. M.East, import-weight 95"
label var pidxeu  "Pr.Idx. EU, import-weight 95"
label var pidxsam "Pr.Idx. S.Amer., imprt-weight 95"
label var pidxnam "Pr.Idx. N.Amer., imprt-weight 95"

save `pidx', replace


/* Average annual nominal exchange rate */

use "brazprod/deflate/realexch", clear
keep if defltype=="dolarmedio" | defltype=="ipa-og" | defltype=="realexch"
mkmat jan86-dec98 if defltype=="dolarmedio", matrix(dolar)
mkmat jan86-dec98 if defltype=="ipa-og", matrix(ipaog)
mkmat jan86-dec98 if defltype=="realexch", matrix(realx)
matrix dolar=dolar'
matrix ipaog=ipaog'
matrix realx=realx'
drop _all
svmat dolar, names("dollar")
svmat ipaog, names("ipaog")
svmat realx, names("realexch")
rename dollar1 dollar
rename ipaog1 ipaog
rename realexch1 realexch
local rnam : rownames dolar
gen str5 month=""
tokenize `rnam'
local j 1
while `j' <= rowsof(dolar) {
    quietly replace month = "``j''" in `j'
    local j=`j'+1
}
order month
matrix drop dolar ipaog realx
gen int year=int(real(substr(month,-2,2)))+1900
gen _exch=dollar/ipaog
rename dollar _dollar
rename realexch _realexch
egen nomexch_p=mean(_exch), by(year)
egen dollar=mean(_dollar), by(year)
egen realexch=mean(_realexch), by(year)
sort year
keep year dollar nomexch_p realexch
order year dollar nomexch_p realexch
by year: keep if _n==1
sort year
label var dollar "Nom. Exch.Rate with US$"
label var nomexch_p "Nom.Exch.Rate: E/P"
label var realexch  "Real.Exch.Rate: E P*[$]/P"
save `nomex'

use `pidx', clear
sort year
merge year using `nomex'
drop _*
replace year=year-1900
sort year
merge year using `pbraz', nokeep
drop _*

order year dollar nomexch_p realexch pidxbraz pidx*
sort year
save "brazprod/addl/ivs-annual", replace

matrix drop priceidx weights pidxwrld
matrix drop pidxnam wnam pidxsam wsam pidxeu weu pidxmest wmest pidxasia wasia
