version 7
set matsize 160
tempfile weights conc indvcntr ppioecd ppieu ppinam usppi usappd wpibraz dollar world

/* OECD-Niv100 concordance */
/*-------------------------*/

use "brazprod/filters/niv100-oecd-conc", clear
keep niv100 oecdsec
sort oecdsec
compress
save `conc'

/* Prepare import weights (1995) */
/*-------------------------------*/

insheet using "brazprod/addl/ivs/brazil-trade/aladi-origins.csv", clear
drop country
rename country_ppi country
keep if country~=""
keep country v4  /* 1995 */
rename v4 weight
egen _tot=sum(weight)
replace weight=weight/_tot
drop _tot
compress
sort country
save `weights'

/* "World" PPI */
/*-------------*/

use "brazprod/addl/ivs/world-wpi-cpi-ppi-sectoral", clear
compress
collapse (mean) ppicpi, by(niv100 year)
label var ppicpi "PPI-WPI-CPI World, imp.-wght 95"
compress
sort niv100 year 
save `world'

/* PPI per country */
/*-----------------*/

use "brazprod/addl/ivs/ppi-oecd/oecd-ppi", clear
* Rebase to 1995, all sectors in France and some in Denmark get lost
order country oecdsec year ppi
sort country oecdsec year ppi
gen _ppi95 = ppi if year==95
egen _ppibase = min(_ppi95), by(country oecdsec)
replace ppi = ppi/_ppibase
drop _*

encode country, generate(cntry) label(oecdctry)
label save oecdctry using "brazprod/filters/oecdctry", replace
drop country
reshape wide ppi, i(oecdsec year) j(cntry)
local i 1
foreach cntry in "Australia" "Austria" "Belgium" "Canada" "Denmark" "Finland" "France" "Germany" "Greece" "Ireland" "Italy" "Japan" "Luxembourg" "Netherlands" "New Zealand" "Norway" "Spain" "Sweden" "Switzerland" "Turkey" "UK" "USA" {
  local name = lower(subinstr("`cntry'"," ","",.))
  rename ppi`i' `name'
  label var `name' "`cntry': OECD PPI"
  count if `name'~=.
  if `r(N)'==0 { drop `name' }
  local i = `i' + 1
  }

replace oecdsec = 311.2 if oecdsec==3112
replace oecdsec = 351.2 if oecdsec==3512
sort oecdsec
joinby oecdsec using `conc', unmatched(both) _merge(_merge)
drop if _merge==1
drop _merge oecdsec
compress
order niv100 
sort niv100 year
preserve
  use "brazprod/addl/ivs/ppi-us/us-ppi", clear
  keep if month=="M13"
  drop month
  drop sic2d
  replace year=year-1900
  drop if year<86 | year>98
  gen _ppi95 = ppi if year==95
  egen _ppibase = min(_ppi95), by(niv100)
  replace ppi = ppi/_ppibase
  drop _*
  rename ppi usa_bls
  label var usa_bls "USA: BLS PPI"
  compress
  sort niv100 year
  save `usppi'
restore
joinby niv100 year using `usppi', unmatched(both) _merge(_merge)
drop if _m==1
count if _merge~=3
if `r(N)' > 0 { 
    tab _merge
    STOP 
    }
drop _merge
sort niv100 year
compress
save `indvcntr'

/* PPI per region */
/*----------------*/

use "brazprod/addl/ivs/ppi-oecd/oecd-ppi", clear
* Rebase to 1995, all sectors in France and some in Denmark get lost
order country oecdsec year ppi
sort country oecdsec year ppi
gen _ppi95 = ppi if year==95
egen _ppibase = min(_ppi95), by(country oecdsec)
replace ppi = ppi/_ppibase
drop _*

sort country
joinby country using `weights', unmatched(both) _merge(_merge)
count if _merge~=3
if `r(N)' > 0 { 
    tab _merge
    STOP 
    }
drop _merge
label var weight "Weight: 1995 imports"
compress

replace oecdsec = 311.2 if oecdsec==3112
replace oecdsec = 351.2 if oecdsec==3512
sort oecdsec
joinby oecdsec using `conc', unmatched(both) _merge(_merge)
drop if _merge==1
drop _merge oecdsec
order niv100 year country
sort niv100 year country
replace country = lower(subinstr(country," ","",.))
replace country = "uk" if country=="unitedkingdom"
replace country = "usa" if country=="unitedstates"
compress
preserve
  use "brazprod/addl/ivs/ppi-us/us-ppi", clear
  keep if month=="M13"
  drop month
  drop sic2d
  gen str13 country = "United States"
  replace year=year-1900
  drop if year<86 | year>98
  gen _ppi95 = ppi if year==95
  egen _ppibase = min(_ppi95), by(niv100)
  replace ppi = ppi/_ppibase
  drop _*
  sort country
  joinby country using `weights', unmatched(both) _merge(_merge)
  count if _merge==1
  if `r(N)' > 0 { 
      tab _merge
      STOP 
      }
  drop if _merge~=3
  drop _merge
  label var weight "Weight: 1995 imports"
  replace country = "usa_bls"
  compress
  order niv100 year country
  sort niv100 year country
  save `usappd'
restore

append using `usappd'
sort niv100 year country
encode country, generate(cntry)
drop country

/* australia austria belgium canada denmark finland france germany greece ireland italy japan luxembourg netherlands newzealand norway spain sweden switzerland turkey uk usa usa_bls */
/*    1         2       3       4      5       6      7        8     9       10    11     12      13         14          15       16     17    18        19       20   21  22    23   */
foreach region in "oecd" "eu" "nam" {
  preserve
  if "`region'" == "eu"    {keep if c==2 | c==3 | c==5 | c==6 | c==7 | c==8 | c==9 | c==10 | c==11 | c==13 | c==14 | c==17 | c==18 | c==21}
  if "`region'" == "nam"   {keep if c==4 | c==23}
  collapse (mean) ppi [iw=weight], by(niv100 year)
  rename ppi ppi`region'
  local titl = upper("`region'")
  label var ppi`region' "PPI Idx. `titl', import-weight 95"
  compress
  sort niv100 year
  save `ppi`region''
  restore
  }

use `ppioecd', clear
foreach region in "eu" "nam" {
  sort niv100 year
  merge niv100 year using `ppi`region''
  count if _merge~=3
  if `r(N)' > 0 { 
      tab _merge
      STOP 
      }
  drop _merge
  }

sort niv100 year
merge niv100 year using `indvcntr', nokeep
keep if _merge==3
drop _merge

preserve
  use "brazprod/deflate/output-defl-di", clear
  reshape long jan feb mar apr may jun jul aug sep oct nov dec, i(niv100) j(year)
  drop if year<86 | year>98
  egen wpibradi = rmean(jan feb mar apr may jun jul aug sep oct nov dec)
  drop jan feb mar apr may jun jul aug sep oct nov dec
  label var year "Calendar Year"
  label var wpibradi "WPI Idx. Brazil, IPA Dsp Interna"
  * Rebase to 1995
  gen _wpi95 = wpi if year==95
  egen _wpibase = min(_wpi95), by(niv100)
  replace wpi = wpi/_wpibase
  drop _*
  compress
  sort niv100 year
  save `wpibraz'
restore
sort niv100 year
merge niv100 year using `wpibraz', nokeep
drop _merge
order niv100 year ppi* wpi

preserve 
  use "brazprod/addl/ivs-annual", clear
  keep year dollar nomex realex
  drop if year<86 | year>98
  compress
  sort year
  save `dollar'
restore  
sort year
joinby year using `dollar', unmatched(both) _merge(_merge)
count if _merge~=3
if `r(N)' > 0 { 
    tab _merge
    STOP 
    }
drop _m
order niv100 year dollar nomex realex wpi ppi*
compress
sort niv100 year
merge niv100 year using `world'
count if _m~=3
if `r(N)' >0 { STOP }
drop _m
rename ppicpi ppiworld
order niv100 year dollar nomex realex wpi ppi*
sort niv100 year
save "brazprod/addl/ivs-sectoral", replace
