version 6.0
/*----------------------------------*/
/* Careful: Set max size to /k64000 */
/*----------------------------------*/

tempfile master tmp
tempfile inpc86 inpc87 inpc88 inpc89 inpc90 inpc91 inpc92 inpc93 inpc94 inpc95 inpc96 inpc97 inpc98 inpc99
tempfile capf86 capf87 capf88 capf89 capf90 capf91 capf92 capf93 capf94 capf95 capf96 capf97 capf98 capf99
use "brazprod\data\pia-finl", clear
keep firm year born niv100 niv80map state change chmon chyr astot-aspdefer asltot-aslcomp deprec crtot
drop astot asliq aslr aspsum aspinv

/* Choose Settings */
/*-----------------*/

local corron 3
/* Corron 1: Correction Factors are Applied */
/*        2: Correction Factors are Not applied */
/*        3: Intermediate: Rebase capital stock before 90 to match 92 */

local choice 3
/* Choice 1: Mesquita (and general) Deflators 90-98 */
/*        2: PIM-IBGE (and general) Deflators 86-98 */
/*        3: FGV-IPA (and general) Deflators 86-98 */
/*        4: FGV-DI (and general) Deflators 86-98 */
/*        9: Apply INPC to all variables */

local type "ipa-indtot"  /* !! USED for buildings and total credit !! */
/* Type of General Deflator: Used for buildings sales, overrules choice 3 or 4 in case of buildings
                      only  "di" (for "ipa-di"), "ipa-indtot", "igp-di", "inpc"  permissible */

local minyr 86  /* Starting year */
local maxyr 98  /* Ending year */

local moncor 1
/* moncor 1: Month correction within year for flow variables */
/*        0: Do not execute month correction within year for flow variables */


if `choice'==1 {STOP /* Not available */}
if `choice'==2 {STOP /* Not available */}
if `choice'==3 {local ext "ipa"}
if `choice'==4 {local ext "di"}
if `choice'==9 {local ext="gen"}


/* The output will be "brazprod\data\deflated\pia-capstock-`ext'-`moncor'-`type'" */
/*--------------------------------------------------------------------------------*/


/* Transform monetary variables to base "Real" 1995 */
/*--------------------------------------------------*/
capture program drop nominal
program define nominal
  args varname
  replace `varname'=`varname'/2.75 if year==93
  replace `varname'=`varname'/(2.75*1000) if (year==92 | year==90 | year==89)
  replace `varname'=`varname'/(2.75*1000000) if (year==88 | year==87 | year==86)
end
/* Set inadmissible negative values to missing */
capture program drop corrneg
program define corrneg
  args varname
  replace `varname'=. if `varname'<0
end
nominal aspimmo
nominal aspmasum
nominal aspdefer
nominal asltot
nominal aslbl
nominal aslmasum
nominal aslveh
nominal aslother
nominal aslcomp
nominal deprec
corrneg aspimmo
corrneg aspmasum
corrneg aspdefer
corrneg asltot
corrneg aslbl
corrneg aslmasum
corrneg aslveh
corrneg aslother
corrneg aslcomp
corrneg deprec


/* Redefine & Drop Select Variables */
/*----------------------------------*/
rename aspimmo apimmo
rename aspmasum apmasum
rename aspdefer apdefer
sort firm year
save `master', replace


/* Rebase Deflators to Aug 1994 and Create Temp. Deflator Files */
/*--------------------------------------------------------------*/
capture program drop rebase
program define rebase
    args yr
    while `yr'<=99 {
    quietly replace jan`yr'=(jan`yr'/aug94)
    quietly replace feb`yr'=(feb`yr'/aug94)
    quietly replace mar`yr'=(mar`yr'/aug94)
    quietly replace apr`yr'=(apr`yr'/aug94)
    quietly replace may`yr'=(may`yr'/aug94)
    quietly replace jun`yr'=(jun`yr'/aug94)
    quietly replace jul`yr'=(jul`yr'/aug94)
    if `yr'~=94 {quietly replace aug`yr'=(aug`yr'/aug94)}
    quietly replace sep`yr'=(sep`yr'/aug94)
    quietly replace oct`yr'=(oct`yr'/aug94)
    quietly replace nov`yr'=(nov`yr'/aug94)
    quietly replace dec`yr'=(dec`yr'/aug94)
    local yr=`yr'+1
    }
    quietly replace aug94=1
end

if `choice'~=9 {
    use "brazprod\deflate\capform-defl-`ext'", clear
    rebase `minyr'
    local yr `minyr'
    preserve
    while `yr'<=99 {
        restore, preserve
        keep captype jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
        sort captype
        save `capf`yr'', replace
        local yr=`yr'+1
    }
    restore
}
else {
    use "brazprod\deflate\capform-defl-ipa", clear
    keep captype
        gen str10 defltype="`type'"
        sort defltype
        merge defltype using "brazprod\deflate\general-defl", nokeep
        rebase 86
        drop defltype _merge
        sort captype
    local yr 86
    preserve
    while `yr'<=99 {
        restore, preserve
        keep captype jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
        save `capf`yr'', replace
        local yr=`yr'+1
    }
    restore
}
use "brazprod\deflate\general-defl", clear
rebase 86
    local yr 86
    preserve
    while `yr'<=99 {
        restore, preserve
        keep defltype inddefl jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
        save `inpc`yr'', replace
        local yr=`yr'+1
    }
    restore


/* Deflation Routines */
/*--------------------*/
/* Correct all stock variables and asset sales for understated inflation */
capture program drop capcorr
program define capcorr
    args varname corname
    replace `varname'=`varname'*`corname'
end
/* Deflate all stock variables and asset sales to Aug-94 values */
capture program drop deflstk
program define deflstk
    args varname yr
    local nextyr=`yr'+1
    replace `varname'=`varname'/((dec`yr'+jan`nextyr')/2) if dec`yr'~=. & year==`yr'
end

/* Correction factors for 92- if Choice==3 */
if `corron'==3 {
    if `choice'~=9 {use "brazprod\deflate\capcorr-`ext'.dta", clear}
        else       {use "brazprod\deflate\capcorr-`type'.dta", clear}
    local cortot1= totalas[6]/( totalas[1]+ totalas[2]+ totalas[3])*3-1
    local corbld1=buildgas[6]/(buildgas[1]+buildgas[2]+buildgas[3])*3-1
    local cormac1=machinas[6]/(machinas[1]+machinas[2]+machinas[3])*3-1
    local corveh1=vehiclas[6]/(vehiclas[1]+vehiclas[2]+vehiclas[3])*3-1
    local corcom1=computas[6]/(computas[1]+computas[2]+computas[3])*3-1
    local coroth1= otheras[6]/( otheras[1]+ otheras[2]+ otheras[3])*3-1
    local cortot2= totalsl[6]/( totalsl[1]+ totalsl[2]+ totalsl[3])*3-1
    local corbld2=buildgsl[6]/(buildgsl[1]+buildgsl[2]+buildgsl[3])*3-1
    local cormac2=machinsl[6]/(machinsl[1]+machinsl[2]+machinsl[3])*3-1
    local corveh2=vehiclsl[6]/(vehiclsl[1]+vehiclsl[2]+vehiclsl[3])*3-1
    local corcom2=computsl[6]/(computsl[1]+computsl[2]+computsl[3])*3-1
    local coroth2= othersl[6]/( othersl[1]+ othersl[2]+ othersl[3])*3-1
}

use `master', clear

/* Deflate Assets and Liabilities, and Asset Sales */
/*-------------------------------------------------*/

/* Asset Group: TOTAL */
if `corron'==1 {
    sort year
    if `choice'~=9 {merge year using "brazprod\deflate\capcorr-`ext'.dta", nokeep}
        else       {merge year using "brazprod\deflate\capcorr-`type'.dta", nokeep}
    drop buildgas-othersl _merge
    capcorr apimmo  totalas
    capcorr apdefer totalas
    capcorr asltot  totalsl
    capcorr deprec  totalsl
    drop totalas totalsl
    }
gen str10 captype="total"
local yr 86
while `yr'<=`maxyr' {
    if `yr'==91 {local yr 92}
    sort captype
    local nextyr=`yr'+1
    merge captype using `capf`nextyr'', nokeep
    drop _merge
    sort captype
    merge captype using `capf`yr'', nokeep
    replace apimmo=.  if (_merge==1 & year==`yr') | dec`yr'==.
    replace apdefer=. if (_merge==1 & year==`yr') | dec`yr'==.
    replace asltot=.  if (_merge==1 & year==`yr') | dec`yr'==.
    replace deprec=.  if (_merge==1 & year==`yr') | jan`yr'==.
    drop _merge
    deflstk apimmo  `yr'
    deflstk apdefer `yr'
    deflstk asltot  `yr'
    deflstk deprec `yr'
    drop jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    drop jan`nextyr' feb`nextyr' mar`nextyr' apr`nextyr' may`nextyr' jun`nextyr' jul`nextyr' aug`nextyr' sep`nextyr' oct`nextyr' nov`nextyr' dec`nextyr'
    local yr=`yr'+1
    }
drop captype

/* Asset Group: BUILDINGS */
if `corron'==1 {
    sort year
    merge year using "brazprod\deflate\capcorr-`type'.dta", nokeep
    drop buildgas machinas-_merge
    capcorr aslbl buildgsl
    drop buildgsl
    }
gen str10 defltype="`type'"
local yr 86
while `yr'<=`maxyr' {
    if `yr'==91 {local yr 92}
    sort defltype
    local nextyr=`yr'+1
    merge defltype using `inpc`nextyr'', nokeep
    drop _merge
    sort defltype
    merge defltype using `inpc`yr'', nokeep
    replace aslbl=.    if (_merge==1 & year==`yr') | dec`yr'==.
    replace crtot=.    if (_merge==1 & year==`yr') | dec`yr'==.
    drop inddefl _merge
    deflstk aslbl `yr'
    deflstk crtot `yr'
    drop jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    drop jan`nextyr' feb`nextyr' mar`nextyr' apr`nextyr' may`nextyr' jun`nextyr' jul`nextyr' aug`nextyr' sep`nextyr' oct`nextyr' nov`nextyr' dec`nextyr'
    local yr=`yr'+1
    }
drop defltype

/* Asset Group: MACHINERY */
sort year
if `corron'==1 {
    if `choice'~=9 {merge year using "brazprod\deflate\capcorr-`ext'.dta", nokeep}
        else       {merge year using "brazprod\deflate\capcorr-`type'.dta", nokeep}
    drop buildgas buildgsl vehiclas-_merge
    capcorr apmasum machinas
    capcorr aslmasum machinsl
    drop machinas machinsl
    }
gen str10 captype="machinery"
local yr 86
while `yr'<=`maxyr' {
    if `yr'==91 {local yr 92}
    sort captype
    local nextyr=`yr'+1
    merge captype using `capf`nextyr'', nokeep
    drop _merge
    sort captype
    merge captype using `capf`yr'', nokeep
    replace apmasum=.  if (_merge==1 & year==`yr') | dec`yr'==.
    replace aslmasum=. if (_merge==1 & year==`yr') | dec`yr'==.
    drop _merge
    deflstk apmasum `yr'
    deflstk aslmasum `yr'
    drop jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    drop jan`nextyr' feb`nextyr' mar`nextyr' apr`nextyr' may`nextyr' jun`nextyr' jul`nextyr' aug`nextyr' sep`nextyr' oct`nextyr' nov`nextyr' dec`nextyr'
    local yr=`yr'+1
    }
drop captype

/* Asset Group: VEHICLES */
if `corron'==1 {
    sort year
    if `choice'~=9 {merge year using "brazprod\deflate\capcorr-`ext'.dta", nokeep}
        else       {merge year using "brazprod\deflate\capcorr-`type'.dta", nokeep}
    drop buildgas-machinsl computas-_merge
    capcorr aslveh vehiclsl
    drop vehiclas vehiclsl
    }
gen str10 captype="vehicles"
local yr 86
while `yr'<=`maxyr' {
    if `yr'==91 {local yr 92}
    sort captype
    local nextyr=`yr'+1
    merge captype using `capf`nextyr'', nokeep
    drop _merge
    sort captype
    merge captype using `capf`yr'', nokeep
    replace aslveh=.  if (_merge==1 & year==`yr') | dec`yr'==.
    drop _merge
    deflstk aslveh `yr'
    drop jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    drop jan`nextyr' feb`nextyr' mar`nextyr' apr`nextyr' may`nextyr' jun`nextyr' jul`nextyr' aug`nextyr' sep`nextyr' oct`nextyr' nov`nextyr' dec`nextyr'
    local yr=`yr'+1
    }
drop captype

/* Asset Group: COMPUTERS */
if `corron'==1 {
    sort year
    if `choice'~=9 {merge year using "brazprod\deflate\capcorr-`ext'.dta", nokeep}
        else       {merge year using "brazprod\deflate\capcorr-`type'.dta", nokeep}
    drop buildgas-vehiclsl otheras-_merge
    capcorr aslcomp computsl
    drop computas computsl
    }
gen str10 captype="computers"
local yr 86
while `yr'<=`maxyr' {
    if `yr'==91 {local yr 92}
    sort captype
    local nextyr=`yr'+1
    merge captype using `capf`nextyr'', nokeep
    drop _merge
    sort captype
    merge captype using `capf`yr'', nokeep
    replace aslcomp=.  if (_merge==1 & year==`yr') | dec`yr'==.
    drop _merge
    deflstk aslcomp `yr'
    drop jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    drop jan`nextyr' feb`nextyr' mar`nextyr' apr`nextyr' may`nextyr' jun`nextyr' jul`nextyr' aug`nextyr' sep`nextyr' oct`nextyr' nov`nextyr' dec`nextyr'
    local yr=`yr'+1
    }
drop captype

/* Asset Group: OTHER */
if `corron'==1 {
    sort year
    if `choice'~=9 {merge year using "brazprod\deflate\capcorr-`ext'.dta", nokeep}
        else       {merge year using "brazprod\deflate\capcorr-`type'.dta", nokeep}
    drop buildgas-computsl totalas-_merge
    capcorr aslother othersl
    drop otheras othersl
    }
gen str10 captype="other"
local yr 86
while `yr'<=`maxyr' {
    if `yr'==91 {local yr 92}
    sort captype
    local nextyr=`yr'+1
    merge captype using `capf`nextyr'', nokeep
    drop _merge
    sort captype
    merge captype using `capf`yr'', nokeep
    replace aslother=.  if (_merge==1 & year==`yr') | dec`yr'==.
    drop _merge
    deflstk aslother `yr'
    drop jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    drop jan`nextyr' feb`nextyr' mar`nextyr' apr`nextyr' may`nextyr' jun`nextyr' jul`nextyr' aug`nextyr' sep`nextyr' oct`nextyr' nov`nextyr' dec`nextyr'
    local yr=`yr'+1
    }
drop captype

replace apimmo=.  if year<86
replace apimmo=.  if year>`maxyr'  /* No deflator, no observation */
replace apmasum=. if year<86
replace apmasum=. if year>`maxyr'   /* No deflator, no observation */
replace apdefer=. if year<86
replace apdefer=. if year>`maxyr'   /* No deflator, no observation */
replace aslbl=.    if year<86
replace aslbl=.    if year>`maxyr'   /* No deflator, no observation */
replace asltot=.   if year<86
replace asltot=.   if year>`maxyr'   /* No deflator, no observation */
replace aslmasum=. if year<86
replace aslmasum=. if year>`maxyr'   /* No deflator, no observation */
replace aslveh=.   if year<86
replace aslveh=.   if year>`maxyr'   /* No deflator, no observation */
replace aslcomp=.  if year<86
replace aslcomp=.  if year>`maxyr'   /* No deflator, no observation */
replace aslother=. if year<86
replace aslother=. if year>`maxyr'   /* No deflator, no observation */
replace deprec=.   if year<86
replace deprec=.   if year>`maxyr'   /* No deflator, no observation */

if `corron'==3 {
    preserve
    keep if year<92
    egen avgapimm=mean(apimmo  ), by(firm) 
    egen avgapdef=mean(apdefer ), by(firm)
    egen avgaslto=mean(asltot  ), by(firm)    
    egen avgaslbl=mean(aslbl   ), by(firm)
    egen avgapmas=mean(apmasum ), by(firm)
    egen avgaslma=mean(aslmasum), by(firm)
    egen avgaslve=mean(aslveh  ), by(firm)
    egen avgaslco=mean(aslcomp ), by(firm)
    egen avgaslot=mean(aslother), by(firm)
    egen avgdepre=mean(deprec  ), by(firm)    
    replace apimmo  =apimmo  +avgapimm*`cortot1'
    replace apdefer =apdefer +avgapdef*`cortot1'
    replace asltot  =asltot  +avgaslto*`cortot2'
    replace aslbl   =aslbl   +avgaslbl*`corbld2'
    replace apmasum =apmasum +avgapmas*`cormac1'
    replace aslmasum=aslmasum+avgaslma*`cormac2'
    replace aslveh  =aslveh  +avgaslve*`corveh2'
    replace aslcomp =aslcomp +avgaslco*`corcom2'
    replace aslother=aslother+avgaslot*`coroth2'
    replace deprec  =deprec  +avgdepre*`cortot2'
    drop avg*
    save `tmp', replace
    restore
    drop if year<92
    append using `tmp'
}

keep  firm year apimmo apmasum apdefer asltot aslbl aslmasum aslveh aslother aslcomp deprec crtot
order firm year apimmo apmasum apdefer asltot aslbl aslmasum aslveh aslother aslcomp deprec crtot
sort firm year
save "brazprod\data\deflated\pia-capstock-`ext'-`type'-`corron'.dta", replace
