version 6
/*----------------------------------*/
/* Careful: Set max size to /k64000 */
/*----------------------------------*/

tempfile master tmp
tempfile outdf86 outdf87 outdf88 outdf89 outdf90 outdf91 outdf92 outdf93 outdf94 outdf95 outdf96 outdf97 outdf98
tempfile inpdf86 inpdf87 inpdf88 inpdf89 inpdf90 inpdf91 inpdf92 inpdf93 inpdf94 inpdf95 inpdf96 inpdf97 inpdf98
tempfile inpc86 inpc87 inpc88 inpc89 inpc90 inpc91 inpc92 inpc93 inpc94 inpc95 inpc96 inpc97 inpc98
use "brazprod\data\pia-finl", clear
keep firm year niv100 niv80map state change chmon chyr sales-resales asrtimmo aslsimmo fincost wagetot-wagebl intmacq intmdif profit

/* Choose Settings */
/*-----------------*/

local choice 3
/* Choice 1: Mesquita (and general) Deflators 90-98 */
/*        2: PIM-IBGE (and general) Deflators 86-98 */
/*        3: FGV-IPA (and general) Deflators 86-98 */
/*        4: FGV-DI (and general) Deflators 86-98 */
/*        9: Apply INPC to all variables */

local type "ipa-indtot"
/* Type of General Deflator: Used for stock variables or under choice 9
                              "igp-di", "inpc", "inpc-real", 
                              "ipa-indtot", "ipa-og", "ipa-transf"
        see "brazprod\deflate\general-defl.dta" */

local saltype "ipa-indtot"
/* Type of Wage Deflator: Used for wages, profit, and rental rates only (see types above) */

local minyr 86  /* Starting year */
local maxyr 98  /* Ending year */

local moncor 1
/* moncor 1: Month correction within year for flow variables */
/*        0: Do not execute month correction within year for flow variables */


if `choice'==1 {
    local ext "mesq"
    local minyr 90
    }
if `choice'==2 {local ext "pim"}
if `choice'==3 {local ext "ipa"}
if `choice'==4 {local ext "di"}
if `choice'==9 {
    local ext "gen"
    local saltype="`type'"
    }


/* The output will be "brazprod\data\deflated\pia-flows-`ext'-`moncor'-`type'" */
/*-----------------------------------------------------------------------------*/


/* Transform monetary variables to base "Real" 1995 */
/*--------------------------------------------------*/
capture program drop nominal
program define nominal
  args varname
  replace `varname'=`varname'/2.75 if year==93
  replace `varname'=`varname'/(2.75*1000) if (year==92 | year==90 | year==89)
  replace `varname'=`varname'/(2.75*1000000) if (year==88 | year==87 | year==86)
end
/* Set inadmissible negative values to missing */
capture program drop corrneg
program define corrneg
  args varname
  replace `varname'=. if `varname'<0
end
nominal sales
nominal difstock
nominal resales
nominal asrtimmo
nominal aslsimmo
nominal fincost
nominal wagetot
nominal wagetop
nominal wagewh
nominal wagebl
nominal intmacq
nominal intmdif
nominal profit
corrneg sales
corrneg resales
corrneg asrtimmo
corrneg aslsimmo
corrneg fincost
corrneg wagetot
corrneg wagetop
corrneg wagewh
corrneg wagebl
corrneg intmacq


/* Redefine & Drop Select Variables */
/*----------------------------------*/
drop wagetot
gen profoutd = profit
gen profinpd = profit
label var profoutd "Profit before tax (output defl.)"
label var profinpd "Profit before tax (input defl.)"
order firm year state change sales difstock resales asrtimmo aslsimmo fincost wagetop wagewh wagebl intmacq intmdif prof*
sort firm year
compress
save `master', replace

/* Rebase Deflators to Aug 1994 and Create Temp. Deflator Files */
/*--------------------------------------------------------------*/
capture program drop rebase
program define rebase
    args yr
    while `yr'<=98 {
    quietly replace jan`yr'=(jan`yr'/aug94)
    quietly replace feb`yr'=(feb`yr'/aug94)
    quietly replace mar`yr'=(mar`yr'/aug94)
    quietly replace apr`yr'=(apr`yr'/aug94)
    quietly replace may`yr'=(may`yr'/aug94)
    quietly replace jun`yr'=(jun`yr'/aug94)
    quietly replace jul`yr'=(jul`yr'/aug94)
    if `yr'~=94 {quietly replace aug`yr'=(aug`yr'/aug94)}
    quietly replace sep`yr'=(sep`yr'/aug94)
    quietly replace oct`yr'=(oct`yr'/aug94)
    quietly replace nov`yr'=(nov`yr'/aug94)
    quietly replace dec`yr'=(dec`yr'/aug94)
    local yr=`yr'+1
    }
    quietly replace aug94=1
end

if `choice'~=9 {
    use "brazprod\deflate\output-defl-`ext'", clear
    rebase `minyr'
    local yr `minyr'
    preserve
    while `yr'<=98 {
        restore, preserve
        keep niv100 jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
        sort niv100
        save `outdf`yr'', replace
        local yr=`yr'+1
    }
    restore
    use "brazprod\deflate\input-defl-`ext'", clear
    rebase `minyr'
    local yr `minyr'
    preserve
    while `yr'<=98 {
        restore, preserve
        keep ativ80 jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
        sort ativ80
        save `inpdf`yr'', replace
        local yr=`yr'+1
    }
    restore
}
else {
    use "brazprod\deflate\comp-defl", clear
    keep niv100
        gen str10 defltype="`type'"
        sort defltype
        merge defltype using "brazprod\deflate\general-defl", nokeep
        rebase 86
        drop defltype _merge
        sort niv100
    local yr 86
    preserve
    while `yr'<=98 {
        restore, preserve
        keep niv100 jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
        save `outdf`yr'', replace
        local yr=`yr'+1
    }
    restore
    use "brazprod\deflate\comp-defl", clear
    keep ativ80
        gen str10 defltype="`type'"
        sort defltype
        merge defltype using "brazprod\deflate\general-defl", nokeep
        rebase 86
        drop defltype _merge
        sort ativ80
    local yr 86
    preserve
    while `yr'<=98 {
        restore, preserve
        keep ativ80 jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
        save `inpdf`yr'', replace
        local yr=`yr'+1
    }
    restore
}
use "brazprod\deflate\general-defl", clear
rebase 86
    local yr 86
    preserve
    while `yr'<=98 {
        restore, preserve
        keep defltype inddefl jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
        save `inpc`yr'', replace
        local yr=`yr'+1
    }
    restore


/* Deflation Routines */
/*--------------------*/
/* Inflate flow variables to end-of-year values */
capture program drop monthcor
program define monthcor
    args varname yr
    gen byte _marker=1 if jan`yr'~=. & year==`yr'  /* No deflator, no change */
    replace _marker=2 if _marker==1 & (state==3 | state==4)
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr'+jul`yr'+aug`yr'+sep`yr'+oct`yr'+nov`yr'+dec`yr')) if _marker==1
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr'+jul`yr'+aug`yr'+sep`yr'+oct`yr'+nov`yr'+dec`yr')) if _marker==2 & chmon==12
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr'+jul`yr'+aug`yr'+sep`yr'+oct`yr'+nov`yr')) if _marker==2 & chmon==11
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr'+jul`yr'+aug`yr'+sep`yr'+oct`yr')) if _marker==2 & chmon==10
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr'+jul`yr'+aug`yr'+sep`yr')) if _marker==2 & chmon==9
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr'+jul`yr'+aug`yr')) if _marker==2 & chmon==8
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr'+jul`yr')) if _marker==2 & chmon==7
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr')) if _marker==2 & chmon==6
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr')) if _marker==2 & chmon==5
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr')) if _marker==2 & chmon==4
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr')) if _marker==2 & chmon==3
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr')) if _marker==2 & chmon==2
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr')) if _marker==2 & chmon==1
    drop _marker
end
/* Deflate all flow variables to Aug-94 values */
capture program drop deflate
program define deflate
    args varname yr
    replace `varname'=`varname'/dec`yr' if dec`yr'~=. & year==`yr'
end

use `master', clear


/* Deflate Output variables */
/*--------------------------*/
local yr `minyr'
while `yr'<=`maxyr' {
    if `yr'==91 {local yr 92}
    sort niv100
    merge niv100 using `outdf`yr'', nokeep
    replace sales=.    if (_merge==1 & year==`yr') | jan`yr'==.     /* No deflator, no observation */
    replace difstock=. if (_merge==1 & year==`yr') | jan`yr'==.
    replace resales=.  if (_merge==1 & year==`yr') | jan`yr'==.
    replace profoutd=. if (_merge==1 & year==`yr') | jan`yr'==.
    drop _merge
    if `moncor'==1 {
    monthcor sales `yr'
    monthcor difstock `yr'
    monthcor resales `yr'
    monthcor profoutd `yr'
    }
    deflate  sales `yr'
    deflate  difstock `yr'
    deflate  resales `yr'
    deflate  profoutd `yr'
    drop jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    local yr=`yr'+1
    }
replace sales=. if year<`minyr'   /* No deflator, no observation */
replace sales=. if year>`maxyr'
replace difstock=. if year<`minyr'
replace difstock=. if year>`maxyr'
replace resales=. if year<`minyr'
replace resales=. if year>`maxyr'
replace profoutd=. if year<`minyr'
replace profoutd=. if year>`maxyr'


/* Deflate Input variables */
/*-------------------------*/
gen byte ativ80=int(niv80map/100)
local yr `minyr'
while `yr'<=`maxyr' {
    if `yr'==91 {local yr 92}
    sort ativ80
    merge ativ80 using `inpdf`yr'', nokeep
    replace intmacq=.  if (_merge==1 & year==`yr') | jan`yr'==.     /* No deflator, no observation */
    replace intmdif=.  if (_merge==1 & year==`yr') | jan`yr'==.
    replace profinpd=. if (_merge==1 & year==`yr') | jan`yr'==.
    drop _merge
    if `moncor'==1 {
    monthcor intmacq `yr'
    monthcor intmdif `yr'
    monthcor profinpd `yr'
    }
    deflate  intmacq `yr'
    deflate  intmdif `yr'
    deflate  profinpd `yr'
    drop jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    local yr=`yr'+1
    }
replace intmacq=. if year<`minyr'    /* No deflator, no observation */
replace intmacq=. if year>`maxyr'
replace intmdif=. if year<`minyr'
replace intmdif=. if year>`maxyr'
replace profinpd=. if year<`minyr'
replace profinpd=. if year>`maxyr'
drop ativ80


/* Deflate Wages, Financial Expenditures and Rental/Leasing Rates */
/*----------------------------------------------------------------*/
gen str10 defltype="`saltype'"
local yr 86
while `yr'<=`maxyr' {
    if `yr'==91 {local yr 92}
    sort defltype
    merge defltype using `inpc`yr'', nokeep
    replace wagetop=.  if (_merge==1 & year==`yr') | jan`yr'==.     /* No deflator, no observation */
    replace wagewh=.   if (_merge==1 & year==`yr') | jan`yr'==.
    replace wagebl=.   if (_merge==1 & year==`yr') | jan`yr'==.
    replace profit=.   if (_merge==1 & year==`yr') | jan`yr'==.
    replace asrtimmo=. if (_merge==1 & year==`yr') | jan`yr'==.
    replace aslsimmo=. if (_merge==1 & year==`yr') | jan`yr'==.
    replace fincost=.  if (_merge==1 & year==`yr') | jan`yr'==.
    drop inddefl _merge
    if `moncor'==1 {
    monthcor wagetop `yr'
    monthcor wagewh `yr'
    monthcor wagebl `yr'
    monthcor profit `yr'
    monthcor asrtimmo `yr'
    monthcor aslsimmo `yr'
    monthcor fincost `yr'
    }
    deflate  wagetop `yr'
    deflate  wagewh `yr'
    deflate  wagebl `yr'
    deflate  profit `yr'
    deflate  asrtimmo `yr'
    deflate  aslsimmo `yr'
    deflate  fincost `yr'
    drop jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    local yr=`yr'+1
    }
replace wagetop=. if year<86
replace wagetop=. if year>`maxyr'    /* No deflator, no observation */
replace wagewh=. if year<86
replace wagewh=. if year>`maxyr'
replace wagebl=. if year<86
replace wagebl=. if year>`maxyr'
replace profit=. if year<86
replace profit=. if year>`maxyr'
replace asrtimmo=. if year<86
replace asrtimmo=. if year>`maxyr'
replace aslsimmo=. if year<86
replace aslsimmo=. if year>`maxyr'
replace fincost=. if year<86
replace fincost=. if year>`maxyr'
drop defltype

keep firm year sales-resales asrtimmo aslsimmo fincost wagetop-wagebl intmacq intmdif prof*
order firm year sales-resales asrtimmo aslsimmo fincost wagetop-wagebl intmacq intmdif prof*
compress
sort firm year
if `choice'~=9 {
    save "brazprod\data\deflated\pia-flows-`ext'-`moncor'-`saltype'.dta", replace
    }
else {
    save "brazprod\data\deflated\pia-flows-`ext'-`moncor'-`type'.dta", replace
    }
