version 7.0
tempfile tmp nil91 frmlnk tmp1 tmp2 irate

/* Choose Settings */
/*-----------------*/

local leftout="niv100==101 | niv100==310 | niv100==910 | niv100==1530 | niv100==3210"
/* Leave out the above industries */
/* Note: The following firms are left out in addition "catlife==float(9.1) | catlife==float(9.2) | catlife==float(9.3) | catlife==float(9.99)" */

local choice 3
/* Choice 1: Mesquita (and general) Deflators 90-98 */
/*        2: PIM-IBGE (and general) Deflators 86-98 */
/*        3: FGV-IPA (and general)  Deflators 86-98 */
/*        4: FGV-DI (and general)   Deflators 86-98 */
/*        9: Apply INPC to all variables */

local type "ipa-indtot"
/* Type of General Deflator: Used for stock variables
                              "igp-di", "inpc", "inpc-real", 
                              "ipa-indtot", "ipa-og", "ipa-transf"
        see "brazprod/deflate/general-defl.dta" 
        except for Cap Stock correction */

local saltype "ipa-indtot"
/* Type of Wage Deflator: Used for wages and rental rates only (see types above) */

local forpidx 2
/* Choice 0: Foreign inputs and investments deflated with domestic deflators */
/*        1: Foreign input and investment deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */

local corron 3
/* Corron 1: Correction Factors are Applied */
/*        2: Correction Factors are Not applied */
/*        3: Intermediate: Rebase capital stock before 90 to match 92 */

local minyr 86  /* Starting year */
/* Check: Computer Stock, Used Machinery Stock */

local maxyr 98  /* Ending year */

local moncor 1
/* moncor 1: Month correction within year for flow variables */
/*        0: Do not execute month correction within year for flow variables */

if `choice'==1 {STOP /* Not available */}
if `choice'==2 {STOP /* Not available */}
if `choice'==3 {local ext "ipa"}
if `choice'==4 {local ext "di"}
if `choice'==9 {
    local ext "gen"
    local saltype="`type'"
    }
local fdfl = `forpidx'
if `fdfl'==0 { local fdfl="" }

capture program drop updatx
program define updatx
    args sufx1 sufx2 depfact
    /* Update Inferences on "ap`sufx'1x" and "ap`sufx'0x" where possible */
    sort firm year
    quietly regress sdepclcr deprec
    predict _depclcr, xb
    replace _depclcr=_depclcr*`depfact'
    gen _dummy1=sdepclcr if year<=90                /* Average depreciation before 90 */
    egen _depclcx=mean(_dummy1), by(niv100 region)  /* If no predicted depreciation rate, use average of industry and region in 90s */
    replace _depclcx=_depclcx*`depfact'
    replace _dummy1=tdepclcr if year<=90
    egen _dummy2=mean(_dummy1)
    replace _depclcx=_dummy2*`depfact' if _depclcx==.
    drop _dummy*
    gen _dummy1=sdepclcr if year>=92                /* Average depreciation after 92 */
    egen _dummy3=mean(_dummy1), by(niv100 region)   /* If no predicted depreciation rate, use average of industry and region in 90s */
    replace _depclcx=_dummy3*`depfact' if year>=92 & _depclcx==.
    replace _dummy1=tdepclcr if year>=92
    egen _dummy4=mean(_dummy1)
    replace _depclcx=_dummy4*`depfact' if year>=92 & _depclcx==.
    drop _dummy*
    sort firm year
    quietly by firm: gen     _asl=acq`sufx1'*((asl`sufx1'[_n+1]/acq`sufx1'[_n+1])+(asl`sufx1'[_n-1]/acq`sufx1'[_n-1]))/2 if asl`sufx1'==.
    quietly by firm: replace _asl=acq`sufx1'*(asl`sufx1'[_n+1]/acq`sufx1'[_n+1])                                 if asl`sufx1'==. & _asl==.
    quietly by firm: replace _asl=acq`sufx1'*(asl`sufx1'[_n-1]/acq`sufx1'[_n-1])                                 if asl`sufx1'==. & _asl==.
    quietly by firm: replace _asl=acq`sufx1'*(asl`sufx1'[_n-2]/acq`sufx1'[_n-2])                                 if asl`sufx1'==. & _asl==. & year==92
    quietly by firm: replace _asl=0 if _asl==. & acq`sufx1'~=.
    quietly by firm: gen     _acq=asl`sufx1'*((acq`sufx1'[_n+1]/asl`sufx1'[_n+1])+(acq`sufx1'[_n-1]/asl`sufx1'[_n-1]))/2 if acq`sufx1'==.
    quietly by firm: replace _acq=asl`sufx1'*(acq`sufx1'[_n+1]/asl`sufx1'[_n+1])                                 if acq`sufx1'==. & _acq==.
    quietly by firm: replace _acq=asl`sufx1'*(acq`sufx1'[_n-1]/asl`sufx1'[_n-1])                                 if acq`sufx1'==. & _acq==.
    quietly by firm: replace _acq=asl`sufx1'*(acq`sufx1'[_n-2]/asl`sufx1'[_n-2])                                 if acq`sufx1'==. & _acq==. & year==92
    quietly by firm: replace _acq=0 if _acq==. & asl`sufx1'~=.
    gen _ntinv=acq`sufx1'-asl`sufx1'
    replace _ntinv=acq`sufx1'-_asl  if _ntinv==.
    replace _ntinv=_acq-asl`sufx1'  if _ntinv==.
    gen _dummy=ap`sufx2'0x+_ntinv-_depclcr*ap`sufx2'0x  if ap`sufx2'1x==.
    replace _dummy=ap`sufx2'0x+_ntinv-_depclcx*ap`sufx2'0x  if ap`sufx2'1x==. & _depclcx~=0
    sort firm year
    quietly by firm: replace _dummy=. if ap`sufx2'1x <  .85 *cond(ap`sufx2'1x[_n-1]<ap`sufx2'1x[_n+1],ap`sufx2'1x[_n-1],ap`sufx2'1x[_n+1])
    quietly by firm: replace _dummy=. if ap`sufx2'1x > 1.15 *cond(ap`sufx2'1x[_n-1]>ap`sufx2'1x[_n+1],ap`sufx2'1x[_n-1],ap`sufx2'1x[_n+1])
    replace ap`sufx2'1x=_dummy if ap`sufx2'1x==.
    replace ap`sufx2'1x=. if ap`sufx2'1x<0
    replace ap`sufx2'1x=. if "`sufx2'"~="immo" & ap`sufx2'1x>apimmo1x & apimmo1x~=. & ap`sufx2'1x~=.
    sort firm year
    quietly by firm: replace ap`sufx2'0x=ap`sufx2'1x[_n-1] if ap`sufx2'0x==.
    drop _dummy
    sort firm year
    gen _dummy=(ap`sufx2'1x-_ntinv)/(1-_depclcr)  if ap`sufx2'0x==.
    replace _dummy=(ap`sufx2'1x-_ntinv)/(1-_depclcx)  if ap`sufx2'0x==. & _depclcx~=0
    sort firm year
    quietly by firm: replace _dummy=. if ap`sufx2'1x <  .85 *cond(ap`sufx2'0x[_n-1]<ap`sufx2'0x[_n+1],ap`sufx2'0x[_n-1],ap`sufx2'0x[_n+1])
    quietly by firm: replace _dummy=. if ap`sufx2'1x > 1.15 *cond(ap`sufx2'0x[_n-1]>ap`sufx2'0x[_n+1],ap`sufx2'0x[_n-1],ap`sufx2'0x[_n+1])
    replace ap`sufx2'0x=_dummy if ap`sufx2'0x==.
    replace ap`sufx2'0x=. if ap`sufx2'0x<0
    replace ap`sufx2'0x=. if "`sufx2'"~="immo" & ap`sufx2'0x>apimmo0x & apimmo0x~=. & ap`sufx2'0x~=.
    sort firm year
    quietly by firm: replace ap`sufx2'1x=ap`sufx2'0x[_n+1] if ap`sufx2'1x==.
    drop _*
    replace ap`sufx2'1x=. if "`sufx2'"~="immo" & ap`sufx2'1x>apimmo1x & apimmo1x~=. & ap`sufx2'1x~=.
    replace ap`sufx2'1x=ap`sufx2'1 if ap`sufx2'1~=.
    replace ap`sufx2'0x=ap`sufx2'0 if ap`sufx2'0~=.
end

capture program drop masmadj
program define masmadj
    egen _chksum0=rsum(apmafor0 apmause0 apmadom0)
    gen _rtmafor0=apmafor0/_chksum0
    gen _rtmause0=apmause0/_chksum0
    gen _rtmadom0=apmadom0/_chksum0
    replace apmafor0 =_rtmafor0*apmasum0 if _chksum0 > apmasum0
    replace apmause0 =_rtmause0*apmasum0 if _chksum0 > apmasum0
    replace apmadom0 =_rtmadom0*apmasum0 if _chksum0 > apmasum0
    egen _chksum1=rsum(apmafor1 apmause1 apmadom1)
    gen _rtmafor1=apmafor1/_chksum1
    gen _rtmause1=apmause1/_chksum1
    gen _rtmadom1=apmadom1/_chksum1
    replace apmafor1 =_rtmafor1*apmasum1 if _chksum1 > apmasum1
    replace apmause1 =_rtmause1*apmasum1 if _chksum1 > apmasum1
    replace apmadom1 =_rtmadom1*apmasum1 if _chksum1 > apmasum1
    egen _chksum0x=rsum(apmafr0x apmaus0x apmadm0x)
    gen _rtmafr0x=apmafr0x/_chksum0x
    gen _rtmaus0x=apmaus0x/_chksum0x
    gen _rtmadm0x=apmadm0x/_chksum0x
    replace apmafr0x =_rtmafr0x*apmasm0x if _chksum0x > apmasm0x
    replace apmaus0x =_rtmaus0x*apmasm0x if _chksum0x > apmasm0x
    replace apmadm0x =_rtmadm0x*apmasm0x if _chksum0x > apmasm0x
    egen _chksum1x=rsum(apmafr1x apmaus1x apmadm1x)
    gen _rtmafr1x=apmafr1x/_chksum1x
    gen _rtmaus1x=apmaus1x/_chksum1x
    gen _rtmadm1x=apmadm1x/_chksum1x
    replace apmafr1x =_rtmafr1x*apmasm1x if _chksum1x > apmasm1x
    replace apmaus1x =_rtmaus1x*apmasm1x if _chksum1x > apmasm1x
    replace apmadm1x =_rtmadm1x*apmasm1x if _chksum1x > apmasm1x
    drop _chksum* _rtma*
end

/* Prepare Predecessor Links */
use "brazprod/cgc-lig/refer", clear
    keep if fnoshw~=1
    keep firm pr1cgc pr1absrb
    sort firm pr1cgc
    quietly by firm pr1cgc: keep if _n==1
    rename firm child
    rename pr1cgc firm
    gen byte year=pr1absrb-1900
    drop pr1absrb
    sort firm year
save `frmlnk', replace

/* Prepare Annual Real Interest Rate */
use "brazprod/addl/interest", clear
keep if date>=ym(1985,12) & date<=ym(1998,12)
keep date irate inpcrate igpdrate
gen rrate1=irate-inpcrate
gen rrate2=irate-igpdrate
gen rfactor1=1+rrate1
gen rfactor2=1+rrate2
gen rcum1=rfactor1[2] in 2
gen rcum2=rfactor2[2] in 2
replace rcum1=rcum1[_n-1]*rfactor1 if _n>2
replace rcum2=rcum2[_n-1]*rfactor2 if _n>2
replace rcum1=1 in 1
replace rcum2=1 in 1
sort date
gen rannu1=.
gen rannu2=.
local yr 1986
while `yr' <= 1998 {
    quietly replace rannu1=(rcum1/rcum1[_n-12])-1 if date==ym(`yr',12)
    quietly replace rannu2=(rcum2/rcum2[_n-12])-1 if date==ym(`yr',12)
    local yr = `yr'+1
}
sort date
keep if date==ym(1986,12) | date==ym(1987,12) | date==ym(1988,12) | date==ym(1989,12) | date==ym(1990,12) | date==ym(1992,12) | date==ym(1993,12) | date==ym(1994,12) | date==ym(1995,12) | date==ym(1996,12) | date==ym(1997,12) | date==ym(1998,12)
keep date rannu1 rannu2
egen _r90=mean(rannu1) if date<ym(1989,1)
egen _r95=mean(rannu1) if date>ym(1991,12) & date<ym(1996,1)
egen _r98=mean(rannu1) if date>ym(1995,12)
egen r90=min(_r90)
egen r95=min(_r95)
egen r98=min(_r98)
sort date
gen byte year=_n+85
replace year=year+1 if year>90
gen rrate=r90 if year<=90
replace rrate=r95 if year>90 & year<=95
replace rrate=r98 if year>95
keep year rrate
label var rrate "Real Annual Interest Rate"
order year rrate
sort year
save `irate', replace

/* 0: Prepare master dataset */
/*---------------------------*/
clear
input firm yr
    . 91
    end
    gen byte year=yr
    drop yr
    sort firm year
    save `nil91', replace  /* Needed for fillin to work in 91 */
use "brazprod/data/pia-finl", clear
    keep firm year niv100 region state catlife catentr effborn effextyr firstyr lastyr dpredcgc 
    sort firm year
    save `tmp', replace
if `choice'~=9 {
    use "brazprod/data/pia-use-`ext'`fdfl'-`moncor'-`type'-`saltype'-`corron'", clear
    }
else {
    use "brazprod/data/pia-use-`ext'`fdfl'-`moncor'-`type'-`corron'", clear
    }
keep  firm year niv100 sales apimmo apmasum acqtot acqbl acqmasum acqmadom acqmause acqmafor acqveh acqother acqcomp asltot aslbl aslmasum aslveh aslother aslcomp deprec aslsimmo asrtimmo state change
order firm year sales apimmo apmasum acqtot acqbl acqmasum acqmadom acqmause acqmafor acqveh acqother acqcomp asltot aslbl aslmasum aslveh aslother aslcomp deprec aslsimmo asrtimmo state change niv100
rename apmasum apmasum1
sort firm year
merge firm year using "brazprod/data/deflated/pia-cap8690-`ext'-`type'-`corron'", update replace
drop _merge
if `fdfl'~=0 {
gen _kappai = acqmafor/acqmasum
drop acqmafor 
sort firm year
merge firm year using "brazprod/data/deflated/pia-foracq-forppi`fdfl'-`moncor'"
replace acqmasum = acqmafor   + (1-_kappai) * acqmasum
drop _*
}
sort firm year
rename apimmo apimmo1
drop if `leftout'
label var apimmo1 "End Y. - Assets (Total)"
label var apmasum1 "End Y. - Machinery (Sum)"
sort firm year
merge firm year using `nil91'
drop _merge
fillin firm year
drop if firm==.
sort firm year
merge firm year using `tmp', nokeep
drop if catlife==float(9.1) | catlife==float(9.2) | catlife==float(9.3) | catlife==float(9.99)
replace apimmo1=aptot1 if apimmo1==.
gen apimmo0=aptot0
replace apimmo0=aptot0*(aptot1/apimmo1) if aptot1~=apimmo1 & aptot1~=. & apimmo1~=.
label var apimmo0 "Beg. Y. - Assets (Total)"
drop _merge aptot1 chmon chyr catlife
/* Get information to filled-in years */
preserve
    keep if year==firstyr | year==90
    sort firm year
    quietly by firm: keep if _n==1
    keep firm effborn firstyr catentry dpredcgc niv100 region
    sort firm
    save `tmp', replace  
restore
sort firm year
merge firm using `tmp', update
drop _merge
egen cntimmo=sum(apimmo1), by(firm)
drop if cntimmo==0
egen fst=min(firstyr), by(firm)
drop if year<fst
egen lst=max(effextyr), by(firm)
drop if year>lst
drop cntimmo fst lst

/* Correct too low or missing apimmo1 and apimmo0 values */
egen _test1=rsum(apbl1 apmasum1 apveh1 apother1 apcomp1)
replace apimmo1=_test1 if _test1>apimmo1 & _test1~=.
egen _test0=rsum(apbl0 apmasum0 apveh0 apother0 apcomp0)
replace apimmo0=_test0 if _test0>apimmo0 & _test0~=.
drop _test*

/* Create consistent ending and beginning values */
sort firm year
quietly by firm: replace apimmo0=apimmo1[_n-1] if year>86 & apimmo1[_n-1]~=.
sort firm year
quietly by firm: replace apbl0=apbl1[_n-1] if year>86
sort firm year
quietly by firm: replace apmasum0=apmasum1[_n-1] if year>86
sort firm year
quietly by firm: replace apveh0=apveh1[_n-1] if year>86
sort firm year
quietly by firm: replace apother0=apother1[_n-1] if year>86
sort firm year
quietly by firm: replace apcomp0=apcomp1[_n-1] if year>86
sort firm year
gen double apmafor0=.
label var apmafor0 "Beg. Y. - Machinery (Foreign)"
gen double apmafor1=.
label var apmafor1 "End Y. - Machinery (Foreign)"
gen double apmause0=.
label var apmause0 "Beg. Y. - Machinery (Used)"
gen double apmause1=.
label var apmause1 "End Y. - Machinery (Used)"
replace apimmo1=. if apimmo1<0
replace apimmo0=. if apimmo0<0
replace apbl1=. if apimmo1<0
replace apbl0=. if apimmo0<0
replace apmasum1=. if apimmo1<0
replace apmasum0=. if apimmo0<0
replace apveh1=. if apimmo1<0
replace apveh0=. if apimmo0<0
replace apother1=. if apimmo1<0
replace apother0=. if apimmo0<0
replace apcomp1=. if apimmo1<0
replace apcomp0=. if apimmo0<0
keep  firm year apimmo1 apbl1 apmasum1 apmafor1 apmause1 apveh1 apother1 apcomp1 apimmo0 apbl0 apmasum0 apmafor0 apmause0 apveh0 apother0 apcomp0 acqtot acqbl acqmasum acqmadom acqmause acqmafor acqveh acqother acqcomp asltot aslbl aslmasum aslveh aslother aslcomp deprec aslsimmo asrtimmo sales state change effborn firstyr catentry dpredcgc niv100 region
sort firm year
order firm year apimmo1 apbl1 apmasum1 apmafor1 apmause1 apveh1 apother1 apcomp1 apimmo0 apbl0 apmasum0 apmafor0 apmause0 apveh0 apother0 apcomp0 acqtot acqbl acqmasum acqmadom acqmause acqmafor acqveh acqother acqcomp asltot aslbl aslmasum aslveh aslother aslcomp deprec aslsimmo asrtimmo sales state change effborn firstyr catentry dpredcgc niv100 region

save master, replace
/* use master, clear */

/* 0: Inference of various depreciation rates */
/*--------------------------------------------*/
gen depcalcr=deprec/apimmo0
gen _marker=1 if deprec~=. & apimmo0~=.
egen _dummy1=sum(deprec), by(niv100 region year)
egen _dummy2=sum(apimmo0), by(niv100 region year)
gen float sdepclcr=_dummy1/_dummy2
drop _dummy1 _dummy2
egen _dummy1=sum(deprec), by(year)
egen _dummy2=sum(apimmo0), by(year)
gen float tdepclcr=_dummy1/_dummy2
drop _marker _dummy1 _dummy2

gen depimplr=1-(apimmo1-acqtot+asltot)/apimmo0
gen _marker=1 if apimmo1~=. & apimmo0~=. & acqtot~=. & asltot~=.
replace _marker=. if year==1992
gen _dummy0=depimplr*apimmo0 if _marker==1
egen _dummy1=sum(_dummy0), by(niv100 region year)
egen _dummy2=sum(apimmo0), by(niv100 region year)
gen float sdepimpr=_dummy1/_dummy2
drop _dummy1 _dummy2
egen _dummy1=sum(_dummy0), by(year)
egen _dummy2=sum(apimmo0), by(year)
gen float tdepimpr=_dummy1/_dummy2
drop _marker _dummy0 _dummy1 _dummy2

replace depimplr=. if year==92
replace sdepimpr=. if year==92
replace tdepimpr=. if year==92
replace depcalcr=. if year>95
replace sdepclcr=. if year>95
replace tdepclcr=. if year>95
label var depcalcr "Rel. Depreciation Cost Rate"
label var depimplr "Implicit Depreciation Rate"
label var sdepclcr "Rel. Deprec. Rate (N100, Region)"
label var sdepimpr "Implic. Deprec. R (N100, Region)"
label var tdepclcr "Rel. Deprec. Rate (overall)"
label var tdepimpr "Implic. Deprec. R (overall)"

keep  firm year apimmo1 apbl1 apmasum1 apmafor1 apmause1 apveh1 apother1 apcomp1 apimmo0 apbl0 apmasum0 apmafor0 apmause0 apveh0 apother0 apcomp0 acqtot acqbl acqmasum acqmadom acqmause acqmafor acqveh acqother acqcomp asltot aslbl aslmasum aslveh aslother aslcomp deprec aslsimmo asrtimmo depcalcr sdepclcr tdepclcr depimplr sdepimpr tdepimpr sales state change effborn firstyr catentry dpredcgc niv100 region
order firm year apimmo1 apbl1 apmasum1 apmafor1 apmause1 apveh1 apother1 apcomp1 apimmo0 apbl0 apmasum0 apmafor0 apmause0 apveh0 apother0 apcomp0 acqtot acqbl acqmasum acqmadom acqmause acqmafor acqveh acqother acqcomp asltot aslbl aslmasum aslveh aslother aslcomp deprec aslsimmo asrtimmo depcalcr tdepclcr sdepclcr depimplr tdepimpr sdepimpr sales state change effborn firstyr catentry dpredcgc niv100 region


/* Distinguish missing and zero */
/*------------------------------*/
egen _dummy1=rsum(acqbl acqmasum acqmadom acqmause acqmafor acqveh acqother acqcomp)
replace acqtot  =_dummy1 if acqtot==.   & _dummy1~=0
egen _dummy2=rsum(acqmadom acqmause acqmafor)
replace acqmasum=_dummy2 if acqmasum==. & _dummy2~=0
egen _dummy3=rsum(aslbl aslmasum aslveh aslother aslcomp)
replace asltot  =_dummy3 if asltot==.   & _dummy3~=0
replace aslmasum=. if asltot~=. & asltot>0 & aslmasum==0
gen byte _dummy=1 if (acqtot~=. | acqbl~=. | acqmasum~=. | acqmadom~=. | acqmause~=. | acqmafor~=. | acqveh~=. | acqother~=. | acqcomp~=. )
replace  _dummy=1 if (asltot~=. | aslbl~=. | aslmasum~=. | aslveh~=. | aslother~=. | aslcomp~=.)
replace acqtot  =0 if acqtot  ==. & _dummy==1
replace acqbl   =0 if acqbl   ==. & _dummy==1
replace acqmasum=0 if acqmasum==. & _dummy==1
replace acqmadom=0 if acqmadom==. & _dummy==1
replace acqmause=0 if acqmause==. & _dummy==1
replace acqmafor=0 if acqmafor==. & _dummy==1
replace acqveh  =0 if acqveh  ==. & _dummy==1
replace acqother=0 if acqother==. & _dummy==1
replace acqcomp =0 if acqcomp ==. & _dummy==1
replace asltot  =0 if asltot  ==. & _dummy==1
replace aslbl   =0 if aslbl   ==. & _dummy==1
replace aslmasum=0 if aslmasum==. & _dummy==1
replace aslveh  =0 if aslveh  ==. & _dummy==1
replace aslother=0 if aslother==. & _dummy==1
replace aslcomp =0 if aslcomp ==. & _dummy==1
drop _dummy*

replace acqmafor=0 if acqmafor==.
replace acqmause=0 if acqmause==.
replace acqmadom=acqmasum if acqmafor==0 & acqmause==0 & acqmadom==.


/* Impute missing capital stock "apimmo1x" where possible */
/*--------------------------------------------------------*/

/* Calculate net investment flow, impute missing values */
sort firm year
quietly by firm: gen     _asltot=acqtot*((asltot[_n+1]/acqtot[_n+1])+(asltot[_n-1]/acqtot[_n-1]))/2 if asltot==.
quietly by firm: replace _asltot=acqtot*(asltot[_n+1]/acqtot[_n+1])                                 if asltot==. & _asltot==.
quietly by firm: replace _asltot=acqtot*(asltot[_n-1]/acqtot[_n-1])                                 if asltot==. & _asltot==.
quietly by firm: replace _asltot=acqtot*(asltot[_n-2]/acqtot[_n-2])                                 if asltot==. & _asltot==. & year==92
quietly by firm: replace _asltot=0 if _asltot==. & acqtot~=.
quietly by firm: gen     _acqtot=asltot*((acqtot[_n+1]/asltot[_n+1])+(acqtot[_n-1]/asltot[_n-1]))/2 if acqtot==.
quietly by firm: replace _acqtot=asltot*(acqtot[_n+1]/asltot[_n+1])                                 if acqtot==. & _acqtot==.
quietly by firm: replace _acqtot=asltot*(acqtot[_n-1]/asltot[_n-1])                                 if acqtot==. & _acqtot==.
quietly by firm: replace _acqtot=asltot*(acqtot[_n-2]/asltot[_n-2])                                 if acqtot==. & _acqtot==. & year==92
quietly by firm: replace _acqtot=0 if _acqtot==. & asltot~=.
gen _ntinv=acqtot-asltot
replace _ntinv=acqtot-_asltot  if _ntinv==.
replace _ntinv=_acqtot-asltot  if _ntinv==.

/* Determine Depreciation */
sort firm year
quietly regress sdepclcr deprec
predict _depclcr, xb
gen _dummy1=sdepclcr if year<=90                /* Average depreciation before 90 */
egen _depclcx=mean(_dummy1), by(niv100 region)  /* If no predicted depreciation rate, use average of industry and region in 90s */
replace _dummy1=tdepclcr if year<=90
egen _dummy2=mean(_dummy1)
replace _depclcx=_dummy2 if _depclcx==.
drop _dummy*
gen _dummy1=sdepclcr if year>=92                /* Average depreciation after 92 */
egen _dummy3=mean(_dummy1), by(niv100 region)   /* If no predicted depreciation rate, use average of industry and region in 90s */
replace _depclcx=_dummy3 if year>=92 & _depclcx==.
replace _dummy1=tdepclcr if year>=92
egen _dummy4=mean(_dummy1)
replace _depclcx=_dummy4 if year>=92 & _depclcx==.
drop _dummy*

/* Infer Capital Stock where possible */
gen     apimmo1x=apimmo0+_ntinv-deprec   if apimmo1==.
replace apimmo1x=apimmo0+_ntinv-deprec   if apimmo1==. & apimmo1x==.
replace apimmo1x=apimmo0+_ntinv-_depclcr*apimmo0  if apimmo1==. & apimmo1x==.
replace apimmo1x=apimmo0+_ntinv-_depclcx*apimmo0  if apimmo1==. & apimmo1x==. & _depclcx~=0
replace apimmo1x=. if apimmo1x<0
sort firm year
quietly by firm: replace apimmo1x=. if apimmo1x <  .85 *cond(apimmo1[_n-1]<apimmo1[_n+1],apimmo1[_n-1],apimmo1[_n+1])
quietly by firm: replace apimmo1x=. if apimmo1x > 1.15 *cond(apimmo1[_n-1]>apimmo1[_n+1],apimmo1[_n-1],apimmo1[_n+1])
sort firm year
quietly by firm: gen apimmo0x=apimmo1x[_n-1]
gen     _dummy=apimmo0x+_ntinv-deprec   if apimmo1x==.
replace _dummy=apimmo0x+_ntinv-deprec   if apimmo1x==.
replace _dummy=apimmo0x+_ntinv-_depclcr*apimmo0 if apimmo1x==.
replace _dummy=apimmo0x+_ntinv-_depclcx*apimmo0 if apimmo1x==. & _depclcx~=0
replace apimmo0x=. if apimmo0x<0
sort firm year
quietly by firm: replace _dummy=. if apimmo1x <  .85 *cond(apimmo1[_n-1]<apimmo1[_n+1],apimmo1[_n-1],apimmo1[_n+1])
quietly by firm: replace _dummy=. if apimmo1x > 1.15 *cond(apimmo1[_n-1]>apimmo1[_n+1],apimmo1[_n-1],apimmo1[_n+1])
replace apimmo1x=_dummy if apimmo1x==.
sort firm year
quietly by firm: replace apimmo0x=apimmo1x[_n-1] if apimmo0x==.
drop _dummy
gen     _dummy=apimmo1x-_ntinv+deprec   if apimmo0x==.
replace _dummy=apimmo1x-_ntinv+deprec   if apimmo0x==.
replace _dummy=(apimmo1x-_ntinv)/(1-_depclcr)  if apimmo0x==.
replace _dummy=(apimmo1x-_ntinv)/(1-_depclcx)  if apimmo0x==. & _depclcx~=0
sort firm year
quietly by firm: replace _dummy=. if apimmo0x <  .85 *cond(apimmo0x[_n-1]<apimmo0x[_n+1],apimmo0x[_n-1],apimmo0x[_n+1])
quietly by firm: replace _dummy=. if apimmo0x > 1.15 *cond(apimmo0x[_n-1]>apimmo0x[_n+1],apimmo0x[_n-1],apimmo0x[_n+1])
replace apimmo0x=_dummy if apimmo0x==.
replace apimmo0x=. if apimmo0x<0
quietly by firm: replace apimmo1x=apimmo0x[_n+1] if apimmo1x==.
label var apimmo1x "Imputed: End Y. - Assets (Tot.)"
label var apimmo0x "Imputed: Beg. Y. - Assets (Tot.)"
drop _*
replace apimmo1x=apimmo1 if apimmo1~=.
replace apimmo0x=apimmo0 if apimmo0~=.

/* Infer Initial Capital Stock from Largest Immediate Predecessor */
sort firm year
preserve
    merge firm year using `frmlnk', nokeep
    keep if _merge==3
    keep firm year child apimmo0x sales
    sort firm year child apimmo0x
    quietly by firm year child apimmo0x: keep if _n==_N
    gen _ratcap =apimmo0x/sales
    keep child year _ratcap
    rename child firm
    sort firm year
    order firm year
    save `tmp1', replace
    replace year=year+1
    sort firm year
    save `tmp2', replace
restore
merge firm year using `tmp1', nokeep
replace apimmo0x=_ratcap*sales if apimmo0x==.
drop _merge
sort firm year
merge firm year using `tmp2', nokeep
replace apimmo0x=_ratcap*sales if apimmo0x==.
sort firm year
quietly by firm: replace apimmo1x=apimmo0x[_n+1]
drop _*

order firm year apimmo1 apbl1 apmasum1 apmafor1 apmause1 apveh1 apother1 apcomp1 apimmo0 apbl0 apmasum0 apmafor0 apmause0 apveh0 apother0 apcomp0 acqtot acqbl acqmasum acqmadom acqmause acqmafor acqveh acqother acqcomp asltot aslbl aslmasum aslveh aslother aslcomp deprec aslsimmo asrtimmo apimmo1x apimmo0x depcalcr tdepclcr sdepclcr depimplr tdepimpr sdepimpr sales state change effborn firstyr catentry dpredcgc niv100 region

save master1, replace
/* use master1, clear */

/* 1: Calculate Beginning Capstock 1992, for Total and Individual Capital Types */
/*------------------------------------------------------------------------------*/
sort firm year
quietly regress sdepclcr deprec
predict _depclcr if year==92, xb
gen _dummy1=sdepclcr if year>=92
egen _depclcx=mean(_dummy1), by(niv100 region)  /* If no predicted depreciation rate, use average of industry and region in 90s */
replace _dummy1=tdepclcr if year>=92
egen _dummy2=mean(_dummy1)
replace _depclcx=_dummy2 if _depclcx==.
sort firm year
quietly by firm: gen _asltot=acqtot*(asltot[_n+1]/acqtot[_n+1])          if year==92 & asltot==.
quietly by firm: gen _acqtot=asltot*(acqtot[_n+1]/asltot[_n+1])          if year==92 & acqtot==.
replace apimmo0=(apimmo1-(acqtot-asltot))/(1-_depclcr)   if year==92
replace apimmo0=(apimmo1-(acqtot-asltot))/(1-_depclcx)   if apimmo0==. & year==92  & _depclcx~=0 /* Do what industry in region & year does */
replace apimmo0=(apimmo1-(acqtot-_asltot))/ (1-_depclcr) if year==92 & apimmo0==. & sales~=.
replace apimmo0=(apimmo1-(_acqtot-asltot))/ (1-_depclcr) if year==92 & apimmo0==. & sales~=.
replace apimmo0=(apimmo1-(_acqtot-_asltot))/(1-_depclcr) if year==92 & apimmo0==. & sales~=.
replace apimmo0=(apimmo1-(acqtot-_asltot))/ (1-_depclcx) if year==92 & apimmo0==. & sales~=. & _depclcx~=0
replace apimmo0=(apimmo1-(_acqtot-asltot))/ (1-_depclcx) if year==92 & apimmo0==. & sales~=. & _depclcx~=0
replace apimmo0=(apimmo1-(_acqtot-_asltot))/(1-_depclcx) if year==92 & apimmo0==. & sales~=. & _depclcx~=0
replace apimmo0=. if apimmo0<0
sort firm year
quietly by firm: replace apimmo0=(apimmo1+apimmo1[_n-2])/2               if year==92 & apimmo0==. & sales~=. & apimmo1~=.
quietly by firm: replace apimmo0=(apimmo0[_n+1]+apimmo0[_n-1])/2         if year==92 & apimmo0==. & sales~=. & apimmo1~=.
quietly by firm: replace apimmo0=(apimmo1+apimmo1[_n-3])/2               if year==92 & apimmo0==. & sales~=. & apimmo1~=.
quietly by firm: replace apimmo0=(apimmo0[_n+1]+apimmo0[_n-2])/2         if year==92 & apimmo0==. & sales~=. & apimmo1~=.
quietly by firm: replace apimmo0=(apimmo1[_n+1]+apimmo1[_n-3])/2         if year==92 & apimmo0==. & sales~=. & apimmo1~=.
quietly by firm: replace apimmo0=(apimmo0[_n+2]+apimmo0[_n-2])/2         if year==92 & apimmo0==. & sales~=. & apimmo1~=.
quietly by firm: replace apimmo0=(apimmo1[_n+1]+apimmo1[_n-4])/2         if year==92 & apimmo0==. & sales~=. & apimmo1~=.
quietly by firm: replace apimmo0=(apimmo0[_n+2]+apimmo0[_n-3])/2         if year==92 & apimmo0==. & sales~=. & apimmo1~=.
replace apimmo0=. if apimmo0<0
replace _dummy1=apimmo0/apimmo1 if year>=92
egen _dummy4=mean(_dummy1), by(niv100 region)
replace apimmo0=_dummy4*apimmo1 if apimmo0==. & year==92

/* Repeat same procedure for imputed values */
sort firm year
replace apimmo0x=(apimmo1x-(acqtot-asltot))/(1-_depclcr)   if year==92
replace apimmo0x=(apimmo1x-(acqtot-asltot))/(1-_depclcx)   if apimmo0x==. & year==92 & _depclcx~=0 /* Do what industry in region & year does */
replace apimmo0x=(apimmo1x-(acqtot-_asltot))/ (1-_depclcr) if year==92 & apimmo0x==. & sales~=.
replace apimmo0x=(apimmo1x-(_acqtot-asltot))/ (1-_depclcr) if year==92 & apimmo0x==. & sales~=.
replace apimmo0x=(apimmo1x-(_acqtot-_asltot))/(1-_depclcr) if year==92 & apimmo0x==. & sales~=.
replace apimmo0x=(apimmo1x-(acqtot-_asltot))/ (1-_depclcx) if year==92 & apimmo0x==. & sales~=. & _depclcx~=0
replace apimmo0x=(apimmo1x-(_acqtot-asltot))/ (1-_depclcx) if year==92 & apimmo0x==. & sales~=. & _depclcx~=0
replace apimmo0x=(apimmo1x-(_acqtot-_asltot))/(1-_depclcx) if year==92 & apimmo0x==. & sales~=. & _depclcx~=0
quietly by firm: replace apimmo0x=(apimmo1x+apimmo1x[_n-2])/2               if year==92 & apimmo0x==. & sales~=. & apimmo1x~=.
quietly by firm: replace apimmo0x=(apimmo0x[_n+1]+apimmo0x[_n-1])/2         if year==92 & apimmo0x==. & sales~=. & apimmo1x~=.
quietly by firm: replace apimmo0x=(apimmo1x+apimmo1x[_n-3])/2               if year==92 & apimmo0x==. & sales~=. & apimmo1x~=.
quietly by firm: replace apimmo0x=(apimmo0x[_n+1]+apimmo0x[_n-2])/2         if year==92 & apimmo0x==. & sales~=. & apimmo1x~=.
quietly by firm: replace apimmo0x=(apimmo1x[_n+1]+apimmo1x[_n-3])/2         if year==92 & apimmo0x==. & sales~=. & apimmo1x~=.
quietly by firm: replace apimmo0x=(apimmo0x[_n+2]+apimmo0x[_n-2])/2         if year==92 & apimmo0x==. & sales~=. & apimmo1x~=.
quietly by firm: replace apimmo0x=(apimmo1x[_n+1]+apimmo1x[_n-4])/2         if year==92 & apimmo0x==. & sales~=. & apimmo1x~=.
quietly by firm: replace apimmo0x=(apimmo0x[_n+2]+apimmo0x[_n-3])/2         if year==92 & apimmo0x==. & sales~=. & apimmo1x~=.
replace apimmo0x=. if apimmo0x<0
replace _dummy1=apimmo0x/apimmo1x if year>=92
egen _dummy5=mean(_dummy1), by(niv100 region)
replace apimmo0x=_dummy5*apimmo1x if apimmo0x==. & year==92
drop _*
updatx tot immo 1

/* Infer 1992 Stock for Individual Capital Types */
local round =1
while `round'<=5 {
if `round'==1 {local sufx1="masum"
               local sufx2="masm"
               local fact="fact"
               }
if `round'==2 {local sufx1="comp"
               local sufx2="comp"
               local fact="comp"
               }
if `round'==3 {local sufx1="other"
               local sufx2="othr"
               local fact="othr"
               }
if `round'==4 {local sufx1="veh"
               local sufx2="veh"
               local fact="veh"
               }
if `round'==5 {local sufx1="bl"
               local sufx2="bl"
               local fact="bldg"
               }
/* Treat goods later that are more likely to be leased or written down to zero */

/* Stock ratio: Capital Good/Total */
egen _chksum1=rsum(apbl1 apmasum1 apveh1 apother1 apcomp1)
gen _chkrat1=ap`sufx1'1/_chksum1
replace ap`sufx1'1 =_chkrat1*apimmo1 if apimmo1<ap`sufx1'1 & apimmo1~=. & ap`sufx1'1~=.
egen _chksum0=rsum(apbl0 apmasum0 apveh0 apother0 apcomp0)
gen _chkrat0=ap`sufx1'0/_chksum0
replace ap`sufx1'0 =_chkrat0*apimmo0 if apimmo0<ap`sufx1'0 & apimmo0~=. & ap`sufx1'0~=.
sort firm year
gen _caprat=ap`sufx1'1/apimmo1 if year<=90
quietly by firm: gen _caprat0=_caprat[_n-1]
replace _caprat0=ap`sufx1'0/apimmo0 if year==86
gen _dummy1=_caprat0*(year-85)
gen _dummy2=year-85 if _caprat0~=. & _caprat0~=0
egen _numer=sum(_dummy1), by(firm)
egen _denom=sum(_dummy2), by(firm)
gen _ratto=_numer/_denom
drop _numer _denom
egen _numer=sum(_dummy1), by(niv100 region)
egen _denom=sum(_dummy2), by(niv100 region)
replace _ratto=_numer/_denom if _ratto==.
label var _ratto "Ratio `sufx1'/Total Cap. (by firm)"
drop _dummy* _denom _numer _capr*

/* Infer Stock for Capital Type */
sort firm year
replace ap`sufx1'0=_ratto*apimmo0 if year==92 & ap`sufx1'0==.
replace ap`sufx1'0=_ratto*apimmo0 if year==93 & ap`sufx1'0==. & ap`sufx1'0[_n-1]==.
replace ap`sufx1'0=_ratto*apimmo0 if year==94 & ap`sufx1'0==. & ap`sufx1'0[_n-1]==.
replace ap`sufx1'0=_ratto*apimmo0 if year==95 & ap`sufx1'0==. & ap`sufx1'0[_n-1]==.
replace ap`sufx1'0=. if ap`sufx1'0<0
gen ap`sufx2'0x=ap`sufx1'0
drop _*

/* Infer Initial Capital Stocks from Largest Immediate Predecessor */
sort firm year
preserve
    merge firm year using `frmlnk', nokeep
    keep if _merge==3
    keep firm year child apimmo0 apimmo0x ap`sufx1'0 ap`sufx2'0x
    sort firm year child apimmo0x
    quietly by firm year child apimmo0x: keep if _n==_N
    gen _rat =ap`sufx1'0/apimmo0
    gen     _ratx=ap`sufx2'0x/apimmo0x
    replace _ratx=_rat if _ratx==.
    keep child year _rat _ratx
    rename child firm
    sort firm year
    order firm year
    save `tmp1', replace
    replace year=year+1
    sort firm year
    save `tmp2', replace
restore
merge firm year using `tmp1', nokeep
replace ap`sufx1'0=_rat *apimmo0  if ap`sufx1'0==. & year==firstyr & year>=92
replace ap`sufx2'0x=_ratx*apimmo0x if ap`sufx2'0x==. & year==firstyr & year>=92
drop _merge
sort firm year
merge firm year using `tmp2', nokeep
replace ap`sufx1'0=_rat *apimmo0  if ap`sufx1'0==. & year==firstyr & year>=92
replace ap`sufx2'0x=_ratx*apimmo0x if ap`sufx2'0x==. & year==firstyr & year>=92
drop _*
local round=`round'+1
}
label var apbl0x   "Imputed: Beg. Y. - Premises"
label var apmasm0x "Imputed: Beg. Y. - Mach. (Sum)"
label var apveh0x  "Imputed: Beg. Y. - Vehicles"
label var apcomp0x "Imputed: Beg. Y. - Computers"
label var apothr0x "Imputed: Beg. Y. - Other"

egen _chksum1=rsum(apbl1 apmasum1 apveh1 apother1 apcomp1)
gen _rtmasm1=apmasum1/_chksum1
gen _rtcomp1=apcomp1 /_chksum1
gen _rtothr1=apother1/_chksum1
gen _rtveh1 =apveh1  /_chksum1
gen _rtbl1  =apbl1   /_chksum1
replace apmasum1 =_rtmasm1*apimmo1 if _chksum1 > apimmo1
replace apcomp1  =_rtcomp1*apimmo1 if _chksum1 > apimmo1
replace apother1 =_rtothr1*apimmo1 if _chksum1 > apimmo1
replace apveh1   =_rtveh1 *apimmo1 if _chksum1 > apimmo1
replace apbl1    =_rtbl1  *apimmo1 if _chksum1 > apimmo1
egen _chksum0=rsum(apbl0 apmasum0 apveh0 apother0 apcomp0)
gen _rtmasm0=apmasum0/_chksum0
gen _rtcomp0=apcomp0 /_chksum0
gen _rtothr0=apother0/_chksum0
gen _rtveh0 =apveh0  /_chksum0
gen _rtbl0  =apbl0   /_chksum0
replace apmasum0 =_rtmasm0*apimmo0 if _chksum0 > apimmo0
replace apcomp0  =_rtcomp0*apimmo0 if _chksum0 > apimmo0
replace apother0 =_rtothr0*apimmo0 if _chksum0 > apimmo0
replace apveh0   =_rtveh0 *apimmo0 if _chksum0 > apimmo0
replace apbl0    =_rtbl0  *apimmo0 if _chksum0 > apimmo0
drop _*

order firm year apimmo1 apbl1 apmasum1 apmafor1 apmause1 apveh1 apother1 apcomp1 apimmo0 apbl0 apmasum0 apmafor0 apmause0 apveh0 apother0 apcomp0 acqtot acqbl acqmasum acqmadom acqmause acqmafor acqveh acqother acqcomp asltot aslbl aslmasum aslveh aslother aslcomp deprec aslsimmo asrtimmo apimmo1x apimmo0x apbl0x apmasm0x apcomp0x apveh0x apothr0x depcalcr sdepclcr tdepclcr depimplr sdepimpr tdepimpr sales state change effborn firstyr catentry dpredcgc niv100 region
 
save master2, replace
/* use master2, clear */

/* 2: Total capital stock after 1995 */
/*-----------------------------------*/

/* Calculate net investment flow, impute missing values */
sort firm year
quietly by firm: gen     _asltot=acqtot*((asltot[_n+1]/acqtot[_n+1])+(asltot[_n-1]/acqtot[_n-1]))/2 if asltot==.
quietly by firm: replace _asltot=acqtot*(asltot[_n+1]/acqtot[_n+1])                                 if asltot==. & _asltot==.
quietly by firm: replace _asltot=acqtot*(asltot[_n-1]/acqtot[_n-1])                                 if asltot==. & _asltot==.
quietly by firm: replace _asltot=acqtot*(asltot[_n-2]/acqtot[_n-2])                                 if asltot==. & _asltot==. & year==92
quietly by firm: replace _asltot=0 if _asltot==. & acqtot~=.
quietly by firm: gen     _acqtot=asltot*((acqtot[_n+1]/asltot[_n+1])+(acqtot[_n-1]/asltot[_n-1]))/2 if acqtot==.
quietly by firm: replace _acqtot=asltot*(acqtot[_n+1]/asltot[_n+1])                                 if acqtot==. & _acqtot==.
quietly by firm: replace _acqtot=asltot*(acqtot[_n-1]/asltot[_n-1])                                 if acqtot==. & _acqtot==.
quietly by firm: replace _acqtot=asltot*(acqtot[_n-2]/asltot[_n-2])                                 if acqtot==. & _acqtot==. & year==92
quietly by firm: replace _acqtot=0 if _acqtot==. & asltot~=.
gen _ntinv=acqtot-asltot
replace _ntinv=acqtot-_asltot  if _ntinv==.
replace _ntinv=_acqtot-asltot  if _ntinv==.

/* Calculate depreciation, impute missing values */
gen _dummy1=sdepclcr if year>=92
egen    _depclcx=mean(_dummy1), by(niv100 region)  /* If no predicted depreciation rate, use average of industry and region in 90s */
replace  _dummy1=tdepclcr if year>=92
egen _dummy2=mean(_dummy1)
replace _depclcx=_dummy2 if _depclcx==.
gen     _capch=_ntinv-deprec
replace _capch=_ntinv-_depclcx*apimmo0 if _capch==. & _depclcx~=0
sort firm year
quietly by firm: replace _capch=(_capch[_n-1]+_capch[_n+1])/2 if _capch==.

/* Continue capital stock to 1998 */
sort firm year
quietly by firm: replace apimmo1=apimmo0       +_capch                           if year==96
replace apimmo1=. if apimmo1<0
quietly by firm: replace apimmo0=apimmo1[_n-1] if year==97 & apimmo0==.
replace _capch=_ntinv-_depclcx*apimmo0 if _capch==. & _depclcx~=0
sort firm year
quietly by firm: replace apimmo1=apimmo0[_n-1] +_capch[_n-1]+_capch              if year==97
replace apimmo1=. if apimmo1<0
quietly by firm: replace apimmo0=apimmo1[_n-1] if year==98 & apimmo0==.
replace _capch=_ntinv-_depclcx*apimmo0 if _capch==. & _depclcx~=0
sort firm year
quietly by firm: replace apimmo1=apimmo0[_n-2] +_capch[_n-2]+_capch[_n-1]+_capch if year==98
replace apimmo1=. if apimmo1<0

/* Repeat procedure for imputed capital stock */
replace _capch=_ntinv-_depclcx*apimmo0x if _capch==. & _depclcx~=0
sort firm year
quietly by firm: replace apimmo1x=apimmo1x[_n-1]+_capch                           if year==96
replace apimmo1x=. if apimmo1x<0
quietly by firm: replace apimmo0x=apimmo1x[_n-1] if year==97 & apimmo0x==.
replace _capch=_ntinv-_depclcx*apimmo0x if _capch==. & _depclcx~=0
sort firm year
quietly by firm: replace apimmo1x=apimmo1x[_n-2]+_capch[_n-1]+_capch              if year==97
replace apimmo1x=. if apimmo1x<0
quietly by firm: replace apimmo0x=apimmo1x[_n-1] if year==98 & apimmo0x==.
replace _capch=_ntinv-_depclcx*apimmo0x if _capch==. & _depclcx~=0
sort firm year
quietly by firm: replace apimmo1x=apimmo1x[_n-3]+_capch[_n-2]+_capch[_n-1]+_capch if year==98
replace apimmo1x=. if apimmo1x<0
drop _*
updatx tot immo 1
updatx tot immo 1

save master3, replace
/* use master3, clear */

/* 3: Stocks for Individual Capital Types before 1990, Impute where missing */
/*--------------------------------------------------------------------------*/
local round =1
while `round'<=5 {
if `round'==1 {local sufx1="masum"
               local sufx2="masm"
               local fact="fact"
               }
if `round'==2 {local sufx1="comp"
               local sufx2="comp"
               local fact="comp"
               }
if `round'==3 {local sufx1="other"
               local sufx2="othr"
               local fact="othr"
               }
if `round'==4 {local sufx1="veh"
               local sufx2="veh"
               local fact="veh"
               }
if `round'==5 {local sufx1="bl"
               local sufx2="bl"
               local fact="bldg"
               }
/* Treat goods later that are more likely to be leased or written down to zero */

/* Imputed values Machinery */
gen ap`sufx2'1x=ap`sufx1'1
sort firm year
quietly by firm: replace ap`sufx2'1x=ap`sufx2'0x[_n+1] if ap`sufx2'1x==. & year<=90

/* Infer Initial Machinery Stock from Largest Immediate Predecessor */
sort firm year
preserve
    merge firm year using `frmlnk', nokeep
    keep if _merge==3
    keep firm year child apimmo0 apimmo0x ap`sufx1'0 ap`sufx2'0x
    sort firm year child apimmo0x
    quietly by firm year child apimmo0x: keep if _n==_N
    gen _rat =ap`sufx1'0/apimmo0
    gen     _ratx=ap`sufx2'0x/apimmo0x
    replace _ratx=_rat if _ratx==.
    keep child year _rat _ratx
    rename child firm
    sort firm year
    order firm year
    save `tmp1', replace
    replace year=year+1
    sort firm year
    save `tmp2', replace
restore
merge firm year using `tmp1', nokeep
replace ap`sufx1'0=_rat *apimmo0  if ap`sufx1'0==.
replace ap`sufx2'0x=_ratx*apimmo0x if ap`sufx2'0x==.
drop _merge
sort firm year
merge firm year using `tmp2', nokeep
replace ap`sufx1'0=_rat *apimmo0  if ap`sufx1'0==.
replace ap`sufx2'0x=_ratx*apimmo0x if ap`sufx2'0x==.
drop _*

/* Net investment, all assets */
sort firm year
quietly by firm: gen     _asltot=acqtot*((asltot[_n+1]/acqtot[_n+1])+(asltot[_n-1]/acqtot[_n-1]))/2 if asltot==.
quietly by firm: replace _asltot=acqtot*(asltot[_n+1]/acqtot[_n+1])                                 if asltot==. & _asltot==.
quietly by firm: replace _asltot=acqtot*(asltot[_n-1]/acqtot[_n-1])                                 if asltot==. & _asltot==.
quietly by firm: replace _asltot=acqtot*(asltot[_n-2]/acqtot[_n-2])                                 if asltot==. & _asltot==. & year==92
quietly by firm: replace _asltot=0 if _asltot==. & acqtot~=.
quietly by firm: gen     _acqtot=asltot*((acqtot[_n+1]/asltot[_n+1])+(acqtot[_n-1]/asltot[_n-1]))/2 if acqtot==.
quietly by firm: replace _acqtot=asltot*(acqtot[_n+1]/asltot[_n+1])                                 if acqtot==. & _acqtot==.
quietly by firm: replace _acqtot=asltot*(acqtot[_n-1]/asltot[_n-1])                                 if acqtot==. & _acqtot==.
quietly by firm: replace _acqtot=asltot*(acqtot[_n-2]/asltot[_n-2])                                 if acqtot==. & _acqtot==. & year==92
quietly by firm: replace _acqtot=0 if _acqtot==. & asltot~=.
gen _ntinvto=acqtot-asltot
replace _ntinvto=acqtot-_asltot  if _ntinvto==.
replace _ntinvto=_acqtot-asltot  if _ntinvto==.

/* Calculate net investment flow machinery, impute missing values */
gen _dummy2=1 if asl`sufx1'==0
egen _dummy3=sum(_dummy2), by(firm)
sort firm year
quietly by firm: gen     _asl`sufx2'=acq`sufx1'*((asl`sufx1'[_n+1]/acq`sufx1'[_n+1])+(asl`sufx1'[_n-1]/acq`sufx1'[_n-1]))/2 if asl`sufx1'==.
quietly by firm: replace _asl`sufx2'=acq`sufx1'*(asl`sufx1'[_n+1]/acq`sufx1'[_n+1])                                 if asl`sufx1'==. & _asl`sufx2'==.
quietly by firm: replace _asl`sufx2'=acq`sufx1'*(asl`sufx1'[_n-1]/acq`sufx1'[_n-1])                                 if asl`sufx1'==. & _asl`sufx2'==.
quietly by firm: replace _asl`sufx2'=acq`sufx1'*(asl`sufx1'[_n-2]/acq`sufx1'[_n-2])                                 if asl`sufx1'==. & _asl`sufx2'==. & year==92
replace _asl`sufx2'=0 if _asl`sufx2'==. & acq`sufx1'~=.
replace _asl`sufx2'=0 if _asl`sufx2'==. & _dummy3>=1
quietly by firm: gen     _acq`sufx2'=asl`sufx1'*((acq`sufx1'[_n+1]/asl`sufx1'[_n+1])+(acq`sufx1'[_n-1]/asl`sufx1'[_n-1]))/2 if acq`sufx1'==.
quietly by firm: replace _acq`sufx2'=asl`sufx1'*(acq`sufx1'[_n+1]/asl`sufx1'[_n+1])                                 if acq`sufx1'==. & _acq`sufx2'==.
quietly by firm: replace _acq`sufx2'=asl`sufx1'*(acq`sufx1'[_n-1]/asl`sufx1'[_n-1])                                 if acq`sufx1'==. & _acq`sufx2'==.
quietly by firm: replace _acq`sufx2'=asl`sufx1'*(acq`sufx1'[_n-2]/asl`sufx1'[_n-2])                                 if acq`sufx1'==. & _acq`sufx2'==. & year==92
replace _acq`sufx2'=0 if _acq`sufx2'==. & asl`sufx1'~=.
gen _ntinv=acq`sufx1'-asl`sufx1'
replace _ntinv=acq`sufx1'-_asl`sufx2'  if _ntinv==.
replace _ntinv=_acq`sufx2'-asl`sufx1'  if _ntinv==.
drop _dummy*

/* Turnover ratios */
gen byte ativ80=int(niv100/100)
gen _turnma=2*_ntinv/(ap`sufx1'1+ap`sufx1'0)
gen _turnto=2*_ntinvto/( apimmo1+ apimmo0)
egen _ratlf=mean(_turnma/_turnto), by(ativ80) /* Highly erratic values when going by activity */
summ _ratlf, meanonly
local dep`fact'=int(r(mean)*100)/100
if "`sufx1'"=="masum"  {local altfact=1.4}
if "`sufx1'"=="comp"   {local altfact=3.5}
if "`sufx1'"=="bl"     {local altfact=.5}
if "`sufx1'"=="veh"    {local altfact=2.8}
if "`sufx1'"=="other"  {local altfact=2.3}
disp "  Average `sufx1'/Capital lifetime ratio in PIA is: `dep`fact''. Accounting ratio: `altfact'."
if "`sufx1'"=="comp" | "`sufx1'"=="other" | "`sufx1'"=="veh" | "`sufx1'"=="bl" {global dp`sufx1'=`altfact'
                                                                                local dep`fact'=`altfact'}
  else               {global dp`sufx1'=`dep`fact''}
disp "  Used lifetime ratio: `dep`fact''"

drop ativ80

/* Determine Depreciation */
sort firm year
quietly regress sdepclcr deprec
predict _depclcr, xb
replace _depclcr=_depclcr*`dep`fact''
gen _dummy1=sdepclcr if year<=90                /* Average depreciation before 90 */
egen _depclcx=mean(_dummy1), by(niv100 region)  /* If no predicted depreciation rate, use average of industry and region in 90s */
replace _depclcx=_depclcx*`dep`fact''
replace _dummy1=tdepclcr if year<=90
egen _dummy2=mean(_dummy1)
replace _depclcx=_dummy2*`dep`fact'' if _depclcx==.
drop _dummy*
gen _dummy1=sdepclcr if year>=92                /* Average depreciation after 92 */
egen _dummy3=mean(_dummy1), by(niv100 region)   /* If no predicted depreciation rate, use average of industry and region in 90s */
replace _depclcx=_dummy3*`dep`fact'' if year>=92 & _depclcx==.
replace _dummy1=tdepclcr if year>=92
egen _dummy4=mean(_dummy1)
replace _depclcx=_dummy4*`dep`fact'' if year>=92 & _depclcx==.
disp in yellow "Depreciation rates for `sufx1' (round `round')"
summ _depc*
drop _dummy*

/* Infer Stock from Flows where possible */
gen     _dummy=ap`sufx1'0+_ntinv-_depclcr*ap`sufx1'0  if ap`sufx1'1==. & ap`sufx2'1x==. & year<=90
replace _dummy=ap`sufx1'0+_ntinv-_depclcx*ap`sufx1'0  if ap`sufx1'1==. & ap`sufx2'1x==. & year<=90 & _depclcx~=0
sort firm year
quietly by firm: replace _dummy=. if ap`sufx2'1x <  .66 *cond(ap`sufx1'1[_n-1]<ap`sufx1'1[_n+1],ap`sufx1'1[_n-1],ap`sufx1'1[_n+1])
quietly by firm: replace _dummy=. if ap`sufx2'1x > 1.34 *cond(ap`sufx1'1[_n-1]>ap`sufx1'1[_n+1],ap`sufx1'1[_n-1],ap`sufx1'1[_n+1])
replace ap`sufx2'1x=_dummy if ap`sufx2'1x==. & year<=90
replace ap`sufx2'1x=. if ap`sufx2'1x<0
replace ap`sufx2'1x=. if ap`sufx2'1x > apimmo1x & ap`sufx2'1x~=. & apimmo1x~=.
sort firm year
quietly by firm: replace ap`sufx2'0x=ap`sufx2'1x[_n-1] if year<=91
drop _dummy
gen     _dummy=ap`sufx2'0x+_ntinv-_depclcr*ap`sufx1'0 if ap`sufx2'1x==. & year<=90
replace _dummy=ap`sufx2'0x+_ntinv-_depclcx*ap`sufx1'0 if ap`sufx2'1x==. & year<=90 & _depclcx~=0
sort firm year
quietly by firm: replace _dummy=. if ap`sufx2'1x <  .66 *cond(ap`sufx1'1[_n-1]<ap`sufx1'1[_n+1],ap`sufx1'1[_n-1],ap`sufx1'1[_n+1])
quietly by firm: replace _dummy=. if ap`sufx2'1x > 1.34 *cond(ap`sufx1'1[_n-1]>ap`sufx1'1[_n+1],ap`sufx1'1[_n-1],ap`sufx1'1[_n+1])
replace ap`sufx2'1x=_dummy if ap`sufx2'1x==. & year<=90
replace ap`sufx2'1x=. if ap`sufx2'1x<0
replace ap`sufx2'1x=. if ap`sufx2'1x > apimmo1x & ap`sufx2'1x~=. & apimmo1x~=.
quietly by firm: replace ap`sufx2'0x=ap`sufx2'1x[_n-1] if ap`sufx2'0x==. & year<=91
drop _dummy
sort firm year
gen     _dummy=(ap`sufx2'1x-_ntinv)/(1-_depclcr)  if ap`sufx2'0x==. & year<=90
replace _dummy=(ap`sufx2'1x-_ntinv)/(1-_depclcx)  if ap`sufx2'0x==. & year<=90 & _depclcx~=0
quietly by firm: replace _dummy=. if ap`sufx2'0x <  .66 *cond(ap`sufx2'0x[_n-1]<ap`sufx2'0x[_n+1],ap`sufx2'0x[_n-1],ap`sufx2'0x[_n+1])
quietly by firm: replace _dummy=. if ap`sufx2'0x > 1.34 *cond(ap`sufx2'0x[_n-1]>ap`sufx2'0x[_n+1],ap`sufx2'0x[_n-1],ap`sufx2'0x[_n+1])
replace ap`sufx2'0x=_dummy if ap`sufx2'0x==. & year<=90
replace ap`sufx2'0x=. if ap`sufx2'0x<0
replace ap`sufx2'0x=. if ap`sufx2'0x > apimmo0x & ap`sufx2'0x~=. & apimmo0x~=.
sort firm year
quietly by firm: replace ap`sufx2'1x=ap`sufx2'0x[_n+1] if ap`sufx2'1x==. & year<=90
drop _*
replace ap`sufx2'1x=ap`sufx1'1 if ap`sufx1'1~=.
replace ap`sufx2'0x=ap`sufx1'0 if ap`sufx1'0~=.
updatx `sufx1' `sufx2' `dep`fact''
replace ap`sufx2'1x=. if year>=92
/* Note: keep ap`sufx2'0x for later if not otherwise imputable */
local round=`round'+1
}
label var apbl1x   "Imputed: End Y. - Premises"
label var apmasm1x "Imputed: End Y. - Mach. (Sum)"
label var apveh1x  "Imputed: End Y. - Vehicles"
label var apcomp1x "Imputed: End Y. - Computers"
label var apothr1x "Imputed: End Y. - Other"

egen _chksum1x=rsum(apbl1x apmasm1x apveh1x apothr1x apcomp1x)
gen _rtmasm1x=apmasm1x/_chksum1x
gen _rtcomp1x=apcomp1x /_chksum1x
gen _rtothr1x=apothr1x/_chksum1x
gen _rtveh1x =apveh1x  /_chksum1x
gen _rtbl1x  =apbl1x   /_chksum1x
replace apmasm1x =_rtmasm1x*apimmo1x if _chksum1x > apimmo1x
replace apcomp1x  =_rtcomp1x*apimmo1x if _chksum1x > apimmo1x
replace apothr1x =_rtothr1x*apimmo1x if _chksum1x > apimmo1x
replace apveh1x   =_rtveh1x *apimmo1x if _chksum1x > apimmo1x
replace apbl1x    =_rtbl1x  *apimmo1x if _chksum1x > apimmo1x
egen _chksum0x=rsum(apbl0x apmasm0x apveh0x apothr0x apcomp0x)
gen _rtmasm0x=apmasm0x/_chksum0x
gen _rtcomp0x=apcomp0x /_chksum0x
gen _rtothr0x=apothr0x/_chksum0x
gen _rtveh0x =apveh0x  /_chksum0x
gen _rtbl0x  =apbl0x   /_chksum0x
replace apmasm0x =_rtmasm0x*apimmo0x if _chksum0x > apimmo0x
replace apcomp0x  =_rtcomp0x*apimmo0x if _chksum0x > apimmo0x
replace apothr0x =_rtothr0x*apimmo0x if _chksum0x > apimmo0x
replace apveh0x   =_rtveh0x *apimmo0x if _chksum0x > apimmo0x
replace apbl0x    =_rtbl0x  *apimmo0x if _chksum0x > apimmo0x
drop _*

order firm year apimmo1 apbl1 apmasum1 apmafor1 apmause1 apveh1 apother1 apcomp1 apimmo0 apbl0 apmasum0 apmafor0 apmause0 apveh0 apother0 apcomp0 acqtot acqbl acqmasum acqmadom acqmause acqmafor acqveh acqother acqcomp asltot aslbl aslmasum aslveh aslother aslcomp deprec aslsimmo asrtimmo apimmo1x apimmo0x apmasm1x apmasm0x apcomp1x apcomp0x apveh1x apveh0x apothr1x apothr0x apbl1x apbl0x depcalcr sdepclcr tdepclcr depimplr sdepimpr tdepimpr sales state change effborn firstyr catentry dpredcgc niv100 region

save master4, replace
/* use master4, clear
   local depfact=1.32
   local depcomp=3.5
   local depothr=2.3
   local depveh=2.8
   local depbldg=.5  */

/* 4: Stocks of Individual Capital Goods after 1992 */
/*--------------------------------------------------*/

egen _dummy1=rsum(acqmadom acqmause acqmafor)
replace acqmasum=_dummy1 if acqmasum==. & _dummy1~=0
drop _dummy*
replace apcomp1=. if year>95
replace apcomp0=. if year>95
replace apcomp1x=. if year>95
replace apcomp0x=. if year>95
replace acqcomp=. if year>95
replace aslcomp=. if year>95

/* Start Year Loops here */
local yr 92
while `yr'<=98 {  /* Begin Loops */

local round =1
while `round'<=5 {
if `round'==1 {local sufx1="masum"
               local sufx2="masm"
               local fact="fact"
               }
if `round'==2 {local sufx1="comp"
               local sufx2="comp"
               local fact="comp"
               if `yr'>95 {local yr=99}
               }
if `round'==3 {local sufx1="other"
               local sufx2="othr"
               local fact="othr"
               }
if `round'==4 {local sufx1="veh"
               local sufx2="veh"
               local fact="veh"
               }
if `round'==5 {local sufx1="bl"
               local sufx2="bl"
               local fact="bldg"
               }

gen _ratto=.

/* Calculate net investment flows, impute missing values */
sort firm year
quietly by firm: gen     _asl=(asl`sufx1'[_n-1]/asltot[_n-1]+asl`sufx1'[_n+1]/asltot[_n+1])*asltot/2 if asl`sufx1'==.
quietly by firm: replace _asl=(asl`sufx1'[_n-2]/asltot[_n-2]+asl`sufx1'[_n+1]/asltot[_n+1])*asltot/2 if asl`sufx1'==. & _asl==.
quietly by firm: replace _asl=(asl`sufx1'[_n-1]/asltot[_n-1]+asl`sufx1'[_n+2]/asltot[_n+2])*asltot/2 if asl`sufx1'==. & _asl==.
quietly by firm: replace _asl=(asl`sufx1'[_n-1]+asl`sufx1'[_n+1])/2                                  if asl`sufx1'==. & _asl==.
quietly by firm: gen     _acq=(acq`sufx1'[_n-1]/acqtot[_n-1]+acq`sufx1'[_n+1]/acqtot[_n+1])*acqtot/2 if acq`sufx1'==.
quietly by firm: replace _acq=(acq`sufx1'[_n-2]/acqtot[_n-2]+acq`sufx1'[_n+1]/acqtot[_n+1])*acqtot/2 if acq`sufx1'==. & _acq==.
quietly by firm: replace _acq=(acq`sufx1'[_n-1]/acqtot[_n-1]+acq`sufx1'[_n+2]/acqtot[_n+2])*acqtot/2 if acq`sufx1'==. & _acq==.
quietly by firm: replace _acq=(acq`sufx1'[_n-1]+acq`sufx1'[_n+1])/2                                  if acq`sufx1'==. & _acq==.
gen _ntinv=acq`sufx1'-asl`sufx1'
replace _ntinv=acq`sufx1'-_asl  if _ntinv==.
replace _ntinv=_acq-asl`sufx1'  if _ntinv==.

/* Calculate depreciation to forward-impute missing years (depreciation of total assets) */
sort firm year
quietly regress sdepclcr deprec
predict _depclcr, xb
replace _depclcr=_depclcr*`dep`fact''
gen _dummy1=sdepclcr if year>=92
egen    _depclcx=mean(_dummy1), by(niv100 region)  /* If no predicted depreciation rate, use average of industry and region in 90s */
replace _depclcx=_depclcx*`dep`fact''
replace  _dummy1=tdepclcr if year>=92
egen _dummy2=mean(_dummy1)
replace _depclcx=_dummy2*`dep`fact'' if _depclcx==.
replace _depclcx=. if _depclcx==0
drop _dummy*

/* Forward impute individual stock values from 1992 to 1998 */
sort firm year
quietly by firm: replace ap`sufx1'1=ap`sufx1'0*(1-_depclcr) +_ntinv  if year==`yr'
quietly by firm: replace ap`sufx1'1=ap`sufx1'0*(1-_depclcx) +_ntinv  if year==`yr' & ap`sufx1'1==. & _depclcx~=0
replace ap`sufx1'1=. if ap`sufx1'1<0

/* Repeat procedure for imputed stock values */
quietly by firm: replace ap`sufx2'1x=ap`sufx2'0x*(1-_depclcr) +_ntinv  if year==`yr'
quietly by firm: replace ap`sufx2'1x=ap`sufx2'0x*(1-_depclcx) +_ntinv  if year==`yr' & ap`sufx2'1x==. & _depclcx~=0
replace ap`sufx2'1x=. if ap`sufx2'1x<0
sort firm year
quietly by firm: replace ap`sufx1'0=ap`sufx1'1[_n-1] if year==`yr'+1 & year>firstyr
quietly by firm: replace ap`sufx2'0x=ap`sufx2'1x[_n-1] if year==`yr'+1 & year>firstyr

/* Machinery Stock ratio */
sort firm year
gen _caprat=ap`sufx1'0/apimmo0 if year<=`yr' & year~=91  /* current place in loop */
gen _dummy1=_caprat*(year-85)
gen _dummy2=year-85 if _caprat~=. & _caprat~=0
egen _numer=sum(_dummy1), by(firm)
egen _denom=sum(_dummy2), by(firm)
replace _ratto=_numer/_denom
drop _numer _denom
egen _numer=sum(_dummy1), by(niv100 region)
egen _denom=sum(_dummy2), by(niv100 region)
replace _ratto=_numer/_denom if _ratto==.
drop _dummy* _denom _numer _capr*

/* Infer Machinery Stock if not available yet */
sort firm year
gen _dummy1=apimmo0/apimmo1 if year>=92 /* not to vary */
egen _dummy2=mean(_dummy1), by(firm)
egen _dummy3=mean(_dummy1), by(niv100 region)
sort firm year
quietly by firm: replace ap`sufx1'0=_ratto*apimmo0         if year==`yr'+1 & ap`sufx1'0[_n-1]==.
quietly by firm: replace ap`sufx1'0=_ratto*apimmo1*_dummy2 if year==`yr'+1 & ap`sufx1'0[_n-1]==.
quietly by firm: replace ap`sufx1'0=_ratto*apimmo1*_dummy3 if year==`yr'+1 & ap`sufx1'0[_n-1]==.
replace ap`sufx1'0=. if ap`sufx1'0<0
drop _dummy*

/* Repeat procedure for imputed stock values */
sort firm year
gen _dummy1=apimmo0x/apimmo1x if year>=92 /* not to vary */
egen _dummy2=mean(_dummy1), by(firm)
egen _dummy3=mean(_dummy1), by(niv100 region)
sort firm year
quietly by firm: replace ap`sufx2'0x=_ratto*apimmo0x         if year==`yr'+1 & ap`sufx2'0x[_n-1]==.
quietly by firm: replace ap`sufx2'0x=_ratto*apimmo1x*_dummy2 if year==`yr'+1 & ap`sufx2'0x[_n-1]==.
quietly by firm: replace ap`sufx2'0x=_ratto*apimmo1x*_dummy3 if year==`yr'+1 & ap`sufx2'0x[_n-1]==.
replace ap`sufx2'0x=. if ap`sufx2'0x<0
drop _dummy*

sort firm year
quietly by firm: replace ap`sufx1'0=ap`sufx1'1[_n-1]
quietly by firm: replace ap`sufx2'0x=ap`sufx2'1x[_n-1]
drop _*
local round=`round'+1
}

egen _chksum1=rsum(apbl1 apmasum1 apveh1 apother1 apcomp1)
gen _rtmasm1=apmasum1/_chksum1
gen _rtcomp1=apcomp1 /_chksum1
gen _rtothr1=apother1/_chksum1
gen _rtveh1 =apveh1  /_chksum1
gen _rtbl1  =apbl1   /_chksum1
replace apmasum1 =_rtmasm1*apimmo1 if _chksum1 > apimmo1
replace apcomp1  =_rtcomp1*apimmo1 if _chksum1 > apimmo1
replace apother1 =_rtothr1*apimmo1 if _chksum1 > apimmo1
replace apveh1   =_rtveh1 *apimmo1 if _chksum1 > apimmo1
replace apbl1    =_rtbl1  *apimmo1 if _chksum1 > apimmo1
egen _chksum0=rsum(apbl0 apmasum0 apveh0 apother0 apcomp0)
gen _rtmasm0=apmasum0/_chksum0
gen _rtcomp0=apcomp0 /_chksum0
gen _rtothr0=apother0/_chksum0
gen _rtveh0 =apveh0  /_chksum0
gen _rtbl0  =apbl0   /_chksum0
replace apmasum0 =_rtmasm0*apimmo0 if _chksum0 > apimmo0
replace apcomp0  =_rtcomp0*apimmo0 if _chksum0 > apimmo0
replace apother0 =_rtothr0*apimmo0 if _chksum0 > apimmo0
replace apveh0   =_rtveh0 *apimmo0 if _chksum0 > apimmo0
replace apbl0    =_rtbl0  *apimmo0 if _chksum0 > apimmo0
drop _*

egen _chksum1x=rsum(apbl1x apmasm1x apveh1x apothr1x apcomp1x)
gen _rtmasm1x=apmasm1x/_chksum1x
gen _rtcomp1x=apcomp1x/_chksum1x
gen _rtothr1x=apothr1x/_chksum1x
gen _rtveh1x =apveh1x /_chksum1x
gen _rtbl1x  =apbl1x  /_chksum1x
replace apmasm1x =_rtmasm1x*apimmo1x if _chksum1x > apimmo1x
replace apcomp1x =_rtcomp1x*apimmo1x if _chksum1x > apimmo1x
replace apothr1x =_rtothr1x*apimmo1x if _chksum1x > apimmo1x
replace apveh1x  =_rtveh1x *apimmo1x if _chksum1x > apimmo1x
replace apbl1x   =_rtbl1x  *apimmo1x if _chksum1x > apimmo1x
egen _chksum0x=rsum(apbl0x apmasm0x apveh0x apothr0x apcomp0x)
gen _rtmasm0x=apmasm0x/_chksum0x
gen _rtcomp0x=apcomp0x/_chksum0x
gen _rtothr0x=apothr0x/_chksum0x
gen _rtveh0x =apveh0x /_chksum0x
gen _rtbl0x  =apbl0x  /_chksum0x
replace apmasm0x =_rtmasm0x*apimmo0x if _chksum0x > apimmo0x
replace apcomp0x =_rtcomp0x*apimmo0x if _chksum0x > apimmo0x
replace apothr0x =_rtothr0x*apimmo0x if _chksum0x > apimmo0x
replace apveh0x  =_rtveh0x *apimmo0x if _chksum0x > apimmo0x
replace apbl0x   =_rtbl0x  *apimmo0x if _chksum0x > apimmo0x
drop _*

replace ap`sufx1'1=. if year==`yr'+1
replace ap`sufx2'1x=. if year==`yr'+1
local yr=`yr'+1
}

updatx masum masm `depfact'
updatx other othr `depothr'
updatx veh   veh  `depveh'
updatx bl    bl   `depbldg'
updatx masum masm `depfact'
updatx other othr `depothr'
updatx veh   veh  `depveh'
updatx bl    bl   `depbldg'

updatx comp  comp `depcomp'
replace apcomp1=. if year>95
replace apcomp0=. if year>95
replace apcomp1x=. if year>95
replace apcomp0x=. if year>95
replace acqcomp=. if year>95
replace aslcomp=. if year>95
updatx comp  comp `depcomp'
replace apcomp1=. if year>95
replace apcomp0=. if year>95
replace apcomp1x=. if year>95
replace apcomp0x=. if year>95
replace acqcomp=. if year>95
replace aslcomp=. if year>95

egen _chksum1x=rsum(apbl1x apmasm1x apveh1x apothr1x apcomp1x)
gen _rtmasm1x=apmasm1x/_chksum1x
gen _rtcomp1x=apcomp1x/_chksum1x
gen _rtothr1x=apothr1x/_chksum1x
gen _rtveh1x =apveh1x /_chksum1x
gen _rtbl1x  =apbl1x  /_chksum1x
replace apmasm1x =_rtmasm1x*apimmo1x if _chksum1x > apimmo1x
replace apcomp1x =_rtcomp1x*apimmo1x if _chksum1x > apimmo1x
replace apothr1x =_rtothr1x*apimmo1x if _chksum1x > apimmo1x
replace apveh1x  =_rtveh1x *apimmo1x if _chksum1x > apimmo1x
replace apbl1x   =_rtbl1x  *apimmo1x if _chksum1x > apimmo1x
egen _chksum0x=rsum(apbl0x apmasm0x apveh0x apothr0x apcomp0x)
gen _rtmasm0x=apmasm0x/_chksum0x
gen _rtcomp0x=apcomp0x/_chksum0x
gen _rtothr0x=apothr0x/_chksum0x
gen _rtveh0x =apveh0x /_chksum0x
gen _rtbl0x  =apbl0x  /_chksum0x
replace apmasm0x =_rtmasm0x*apimmo0x if _chksum0x > apimmo0x
replace apcomp0x =_rtcomp0x*apimmo0x if _chksum0x > apimmo0x
replace apothr0x =_rtothr0x*apimmo0x if _chksum0x > apimmo0x
replace apveh0x  =_rtveh0x *apimmo0x if _chksum0x > apimmo0x
replace apbl0x   =_rtbl0x  *apimmo0x if _chksum0x > apimmo0x
drop _*

save master5, replace
/* use master5, clear
   local depfact=1.32
   local depcomp=3.5
   local depothr=2.3
   local depveh=2.8
   local depbl=.5    */

/* 5: Foreign and Used Machinery Stock 1986-1995 */
/*-----------------------------------------------*/

egen _test=rsum(acqmafor acqmadom acqmause)
replace acqmasum=_test if _test>acqmasum & _test~=. & year<=95
egen _del=rsum(acqmafor acqmause)
replace acqmadom=acqmasum-_del if acqmadom==. & year<=95
egen _delap1=rsum(apmafor1 apmause1)
gen apmadom1=apmasum1-_delap1 if year<=95
egen _delap0=rsum(apmafor0 apmause0)
gen apmadom0=apmasum0-_delap0 if year<=95
drop _*

/* Starting values in "firstyr" for 3 machinery types */
local round =1
while `round'<=3 {
if `round'==1 {local sufx1="mafor"
               local sufx2="mafr"}
if `round'==2 {local sufx1="mause"
               local sufx2="maus"}
if `round'==3 {local sufx1="madom"
               local sufx2="madm"}
sort firm year
gen     _dumrat=acq`sufx1'/acqmasum
replace _dumrat=0 if acqmasum==0
replace _dumrat=0 if _dumrat==.
replace _dumrat=. if (effborn-1900<firstyr | effborn==.) & year>=firstyr+3
replace _dumrat=. if (effborn-1900<firstyr | effborn==.) & year>=firstyr+2 & firstyr>86
replace _dumrat=. if effborn-1900>=firstyr
gen     _dumratx=acq`sufx1'/acqmasum
replace _dumratx=0 if acqmasum==0
replace _dumratx=0 if _dumratx==.
replace _dumratx=. if (effborn-1900<firstyr | effborn==.) & year>=firstyr+3
replace _dumratx=. if (effborn-1900<firstyr | effborn==.) & year>=firstyr+2 & firstyr>86
replace _dumratx=. if effborn-1900>=firstyr
egen _numer =sum(_dumrat),  by(firm)
egen _numerx=sum(_dumratx), by(firm)
gen byte _weight =1 if _dumrat~=.
gen byte _weightx=1 if _dumratx~=.
egen _denom =sum(_weight),  by(firm)
egen _denomx=sum(_weightx), by(firm)
replace ap`sufx1'0=apmasum0*(_numer/_denom)
gen     ap`sufx2'0x=apmasm0x*(_numerx/_denomx)
gen     _mark=1 if (catentr==float(2.1) | catentr==float(2.5) | catentr==float(8.5) | catentr==float(9.1))
replace _mark=1 if (catentr==float(4.11) | catentr==float(4.15) | catentr==float(4.21) | catentr==float(4.25) | catentr==float(4.31) | catentr==float(4.35))
replace ap`sufx1'0=0 if year==firstyr & _mark==1
replace ap`sufx1'0=. if year>firstyr  & _mark==1
replace ap`sufx2'0x=0 if year==firstyr & _mark==1
replace ap`sufx2'0x=. if year>firstyr  & _mark==1

/* Impute starting value if necessary, using machinery stock ratio */
sort firm year
gen _caprat=apmasum1/apimmo1 if year<=90
quietly by firm: gen _caprat0=_caprat[_n-1]
replace _caprat0=apmasum0/apimmo0 if year==86
gen _dummy1=_caprat0*(year-85)
gen _dummy2=year-85 if _caprat0~=. & _caprat0~=0
egen _numer9=sum(_dummy1), by(firm)
egen _denom9=sum(_dummy2), by(firm)
gen _ratmato=_numer9/_denom9
drop _numer9 _denom9
egen _numer9=sum(_dummy1), by(niv100 region)
egen _denom9=sum(_dummy2), by(niv100 region)
replace _ratmato=_numer9/_denom9 if _ratmato==.
label var _ratmato "Ratio Mach./Total Cap. (by firm)"
replace ap`sufx2'0x=apimmo0x*_ratmato*(_numerx/_denomx) if ap`sufx2'0x==.

gen ap`sufx2'1x=.
replace ap`sufx1'1=. if ap`sufx1'1<0
replace ap`sufx2'0x=0 if ap`sufx2'0x<0
replace ap`sufx2'0x=apmasm0x if ap`sufx2'0x>apmasm0x & ap`sufx2'0x~=.
drop _*
replace ap`sufx1'0=. if year>=96
replace ap`sufx2'0x=. if year>=96

/* Use earliest available year */
gen _fstyr=year  if ap`sufx1'0~=.
gen _fstyrx=year if ap`sufx2'0x~=.
egen _dummy =min(_fstyr),  by(firm)
egen _dummyx=min(_fstyrx), by(firm)
replace ap`sufx1'0=. if year>_dummy
replace ap`sufx2'0x=. if year>_dummyx
drop _*

local round=`round'+1
}

label var apmafr0x "Imputed: Beg. Y. - Mach. (For.)"
label var apmafr1x "Imputed: End Y. - Mach. (For.)"
label var apmaus0x "Imputed: Beg. Y. - Mach. (Used)"
label var apmaus1x "Imputed: End Y. - Mach. (Used)"
order firm year apimmo1 apbl1 apmasum1 apmafor1 apmause1 apveh1 apother1 apcomp1 apimmo0 apbl0 apmasum0 apmafor0 apmause0 apveh0 apother0 apcomp0 acqtot acqbl acqmasum acqmadom acqmause acqmafor acqveh acqother acqcomp asltot aslbl aslmasum aslveh aslother aslcomp deprec aslsimmo asrtimmo apimmo1x apimmo0x apmasm1x apmasm0x apmafr1x apmafr0x apmaus1x apmaus0x apmadm1x apmadm0x depcalcr sdepclcr tdepclcr depimplr sdepimpr tdepimpr sales state change effborn firstyr catentry dpredcgc niv100 region
masmadj

/* Depreciation rates: Delta */
sort firm year
quietly regress sdepclcr deprec
predict _depclcr, xb
replace _depclcr=_depclcr*`depfact'
gen _dummy1=sdepclcr if year>=92
egen    _depclcx=mean(_dummy1), by(niv100 region)  /* If no predicted depreciation rate, use average of industry and region in 90s */
replace _depclcx=_depclcx*`depfact'
replace _dummy1=tdepclcr if year>=92
egen _dummy2=mean(_dummy1)
replace _depclcx=_dummy2*`depfact' if _depclcx==.
replace _depclcx=. if _depclcx==0
rename _depclcr _delta
replace _delta=_depclcx if _delta==.
drop _dummy* _depclc*

/* Relative asset sales: Sigma */
gen     _sigma=aslmasum/apmasum0
replace _sigma=aslmasum/apmasm0x if _sigma==.
sort firm year
quietly by firm: replace _sigma=(_sigma[_n-1]+_sigma[_n+1])/2 if _sigma==.
quietly by firm: replace _sigma=_sigma[_n+1]                  if _sigma==. & year==firstyr
quietly by firm: replace _sigma=_sigma[_n-1]                  if _sigma==.

/* Forward-Impute Foreign Machinery Stock in all remaining years until 1995 */
local yr 86
while `yr'<=95 {
    sort firm year
    quietly by firm: replace apmafor1=apmafor0*(1-_sigma-_delta)+acqmafor if year==`yr'
    replace apmafor1=0 if apmafor1<0 & apmafor1~=.
    quietly by firm: replace apmafr1x=apmafr0x*(1-_sigma-_delta)+acqmafor if year==`yr'
    replace apmafr1x=0 if apmafr1x<0 & apmafr1x~=.
    quietly by firm: replace apmafor0=apmafor1[_n-1] if year==`yr'+1 & apmafor1[_n-1]~=.
    quietly by firm: replace apmafr0x=apmafr1x[_n-1] if year==`yr'+1 & apmafr1x[_n-1]~=.
    quietly by firm: replace apmause1=apmause0*(1-_sigma-_delta)+acqmause if year==`yr'
    replace apmause1=0 if apmause1<0 & apmause1~=.
    quietly by firm: replace apmaus1x=apmaus0x*(1-_sigma-_delta)+acqmause if year==`yr'
    replace apmaus1x=0 if apmaus1x<0 & apmaus1x~=.
    quietly by firm: replace apmause0=apmause1[_n-1] if year==`yr'+1 & apmause1[_n-1]~=.
    quietly by firm: replace apmaus0x=apmaus1x[_n-1] if year==`yr'+1 & apmaus1x[_n-1]~=.
    quietly by firm: replace apmadom1=apmadom0*(1-_sigma-_delta)+acqmadom if year==`yr'
    replace apmadom1=0 if apmadom1<0 & apmadom1~=.
    quietly by firm: replace apmadm1x=apmadm0x*(1-_sigma-_delta)+acqmadom if year==`yr'
    replace apmadm1x=0 if apmadm1x<0 & apmadm1x~=.
    quietly by firm: replace apmadom0=apmadom1[_n-1] if year==`yr'+1 & apmadom1[_n-1]~=.
    quietly by firm: replace apmadm0x=apmadm1x[_n-1] if year==`yr'+1 & apmadm1x[_n-1]~=.
    masmadj
    local yr=`yr'+1
}

/* Take care of potential year 1992 problem, using Machinery Stock ratio before 1990 */
local round =1
while `round'<=3 {
if `round'==1 {local sufx1="mafor"
               local sufx2="mafr"}
if `round'==2 {local sufx1="mause"
               local sufx2="maus"}
if `round'==3 {local sufx1="madom"
               local sufx2="madm"}
sort firm year
gen _caprat =ap`sufx1'1/apimmo1 if year<=90
gen _capratx=ap`sufx2'1x/apimmo1x if year<=90
gen _dummy1 = _caprat*(year-85)
gen _dummy1x=_capratx*(year-85)
gen _dummy2=year-85 if _caprat~=.
gen _dummy2x=year-85 if _capratx~=.
egen _numer =sum(_dummy1),  by(firm)
egen _numerx=sum(_dummy1x), by(firm)
egen _denom =sum(_dummy2),  by(firm)
egen _denomx=sum(_dummy2x), by(firm)
gen _rat=  _numer/ _denom
gen _ratx=_numerx/_denomx
drop _nume* _deno*
egen _numer =sum(_dummy1),  by(niv100 region)
egen _numerx=sum(_dummy1x), by(niv100 region)
egen _denom =sum(_dummy2),  by(niv100 region)
egen _denomx=sum(_dummy2x), by(niv100 region)
replace _rat = _numer/ _denom if _rat==.
replace _ratx=_numerx/_denomx if _ratx==.
drop _dummy* _deno* _nume* _capr*
/* Infer Machinery Stock */
replace ap`sufx1'0= _rat*apimmo0  if year==92 & ap`sufx1'0==.
replace ap`sufx2'0x=_ratx*apimmo0x if year==92 & ap`sufx2'0x==.
replace ap`sufx1'0=0 if ap`sufx1'0<0 & ap`sufx1'0~=.
replace ap`sufx2'0x=0 if ap`sufx2'0x<0 & ap`sufx2'0x~=.
drop _rat*
local round=`round'+1
}
masmadj

/* Forward-Impute Foreign Machinery Stock after 1992 */
local yr 92
while `yr'<=95 {
    sort firm year
    quietly by firm: replace apmafor1=apmafor0*(1-_sigma-_delta)+acqmafor if year==`yr'
    replace apmafor1=0 if apmafor1<0 & apmafor1~=.
    quietly by firm: replace apmafr1x=apmafr0x*(1-_sigma-_delta)+acqmafor if year==`yr'
    replace apmafr1x=0 if apmafr1x<0 & apmafr1x~=.
    quietly by firm: replace apmafor0=apmafor1[_n-1] if year==`yr'+1 & apmafor1[_n-1]~=.
    quietly by firm: replace apmafr0x=apmafr1x[_n-1] if year==`yr'+1 & apmafr1x[_n-1]~=.
    quietly by firm: replace apmause1=apmause0*(1-_sigma-_delta)+acqmause if year==`yr'
    replace apmause1=0 if apmause1<0 & apmause1~=.
    quietly by firm: replace apmaus1x=apmaus0x*(1-_sigma-_delta)+acqmause if year==`yr'
    replace apmaus1x=0 if apmaus1x<0 & apmaus1x~=.
    quietly by firm: replace apmause0=apmause1[_n-1] if year==`yr'+1 & apmause1[_n-1]~=.
    quietly by firm: replace apmaus0x=apmaus1x[_n-1] if year==`yr'+1 & apmaus1x[_n-1]~=.
    quietly by firm: replace apmadom1=apmadom0*(1-_sigma-_delta)+acqmadom if year==`yr'
    replace apmadom1=0 if apmadom1<0 & apmadom1~=.
    quietly by firm: replace apmadm1x=apmadm0x*(1-_sigma-_delta)+acqmadom if year==`yr'
    replace apmadm1x=0 if apmadm1x<0 & apmadm1x~=.
    quietly by firm: replace apmadom0=apmadom1[_n-1] if year==`yr'+1 & apmadom1[_n-1]~=.
    quietly by firm: replace apmadm0x=apmadm1x[_n-1] if year==`yr'+1 & apmadm1x[_n-1]~=.
    masmadj
    local yr=`yr'+1
}
drop _*

/* Infer Foreign Machinery Stock from Largest Immediate Predecessor */
local round =1
while `round'<=3 {
if `round'==1 {local sufx1="mafor"
               local sufx2="mafr"}
if `round'==2 {local sufx1="mause"
               local sufx2="maus"}
if `round'==3 {local sufx1="madom"
               local sufx2="madm"}
sort firm year
preserve
    merge firm year using `frmlnk', nokeep
    keep if _merge==3
    keep firm year child apmasum0 ap`sufx1'0 apmasm0x ap`sufx2'0x apimmo0x
    sort firm year child apimmo0x
    quietly by firm year child apimmo0x: keep if _n==_N
    egen _ratmtp =mean(ap`sufx1'0/apmasum0), by(firm)
    egen _ratmtpx=mean(ap`sufx2'0x/apmasm0x), by(firm)
    keep child year _ratmtp _ratmtpx
    rename child firm
    sort firm year
    order firm year
    save `tmp1', replace
    replace year=year+1
    sort firm year
    save `tmp2', replace    
restore
merge firm year using `tmp1', nokeep
gen _dummy1 =_ratmtp *apmasum0 if _merge==3
gen _dummy1x=_ratmtpx*apmasm0x if _merge==3
replace ap`sufx1'0=_dummy1  if _dummy1~=.  & year==firstyr
replace ap`sufx2'0x=_dummy1x if _dummy1x~=. & year==firstyr
drop _merge
sort firm year
merge firm year using `tmp2', nokeep
gen _dummy2 =_ratmtp *apmasum0 if _merge==3
gen _dummy2x=_ratmtpx*apmasm0x if _merge==3
replace ap`sufx1'0=_dummy2  if  _dummy2~=. & ap`sufx1'1~=. & year==firstyr
replace ap`sufx2'0x=_dummy2x if _dummy2x~=. & ap`sufx2'1x~=. & year==firstyr
drop _*
local round=`round'+1
}

/* Do loops all over again for firms with predecessors */
/* Depreciation rates: Delta */
sort firm year
quietly regress sdepclcr deprec
predict _depclcr, xb
replace _depclcr=_depclcr*`depfact'
gen _dummy1=sdepclcr if year>=92
egen    _depclcx=mean(_dummy1), by(niv100 region)  /* If no predicted depreciation rate, use average of industry and region in 90s */
replace _depclcx=_depclcx*`depfact'
replace _dummy1=tdepclcr if year>=92
egen _dummy2=mean(_dummy1)
replace _depclcx=_dummy2*`depfact' if _depclcx==.
replace _depclcx=. if _depclcx==0
rename _depclcr _delta
replace _delta=_depclcx if _delta==.
drop _dummy* _depclc*

/* Relative asset sales: Sigma */
gen     _sigma=aslmasum/apmasum0
replace _sigma=aslmasum/apmasm0x if _sigma==.
sort firm year
quietly by firm: replace _sigma=(_sigma[_n-1]+_sigma[_n+1])/2 if _sigma==.
quietly by firm: replace _sigma=_sigma[_n+1]                  if _sigma==. & year==firstyr
quietly by firm: replace _sigma=_sigma[_n-1]                  if _sigma==.

/* Forward-Impute Foreign Machinery Stock in all remaining years until 1995 */
local yr 86
while `yr'<=95 {
    sort firm year
    quietly by firm: replace apmafor1=apmafor0*(1-_sigma-_delta)+acqmafor if year==`yr'
    replace apmafor1=0 if apmafor1<0 & apmafor1~=.
    quietly by firm: replace apmafr1x=apmafr0x*(1-_sigma-_delta)+acqmafor if year==`yr'
    replace apmafr1x=0 if apmafr1x<0 & apmafr1x~=.
    quietly by firm: replace apmafor0=apmafor1[_n-1] if year==`yr'+1 & apmafor1[_n-1]~=.
    quietly by firm: replace apmafr0x=apmafr1x[_n-1] if year==`yr'+1 & apmafr1x[_n-1]~=.
    quietly by firm: replace apmause1=apmause0*(1-_sigma-_delta)+acqmause if year==`yr'
    replace apmause1=0 if apmause1<0 & apmause1~=.
    quietly by firm: replace apmaus1x=apmaus0x*(1-_sigma-_delta)+acqmause if year==`yr'
    replace apmaus1x=0 if apmaus1x<0 & apmaus1x~=.
    quietly by firm: replace apmause0=apmause1[_n-1] if year==`yr'+1 & apmause1[_n-1]~=.
    quietly by firm: replace apmaus0x=apmaus1x[_n-1] if year==`yr'+1 & apmaus1x[_n-1]~=.
    quietly by firm: replace apmadom1=apmadom0*(1-_sigma-_delta)+acqmadom if year==`yr'
    replace apmadom1=0 if apmadom1<0 & apmadom1~=.
    quietly by firm: replace apmadm1x=apmadm0x*(1-_sigma-_delta)+acqmadom if year==`yr'
    replace apmadm1x=0 if apmadm1x<0 & apmadm1x~=.
    quietly by firm: replace apmadom0=apmadom1[_n-1] if year==`yr'+1 & apmadom1[_n-1]~=.
    quietly by firm: replace apmadm0x=apmadm1x[_n-1] if year==`yr'+1 & apmadm1x[_n-1]~=.
    masmadj
    local yr=`yr'+1
}

/* Take care of potential year 1992 problem, using Machinery Stock ratio before 1990 */
local round =1
while `round'<=3 {
if `round'==1 {local sufx1="mafor"
               local sufx2="mafr"}
if `round'==2 {local sufx1="mause"
               local sufx2="maus"}
if `round'==3 {local sufx1="madom"
               local sufx2="madm"}
sort firm year
gen _caprat =ap`sufx1'1/apimmo1 if year<=90
gen _capratx=ap`sufx2'1x/apimmo1x if year<=90
gen _dummy1 = _caprat*(year-85)
gen _dummy1x=_capratx*(year-85)
gen _dummy2=year-85 if _caprat~=.
gen _dummy2x=year-85 if _capratx~=.
egen _numer =sum(_dummy1),  by(firm)
egen _numerx=sum(_dummy1x), by(firm)
egen _denom =sum(_dummy2),  by(firm)
egen _denomx=sum(_dummy2x), by(firm)
gen _rat=  _numer/ _denom
gen _ratx=_numerx/_denomx
drop _nume* _deno*
egen _numer =sum(_dummy1),  by(niv100 region)
egen _numerx=sum(_dummy1x), by(niv100 region)
egen _denom =sum(_dummy2),  by(niv100 region)
egen _denomx=sum(_dummy2x), by(niv100 region)
replace _rat = _numer/ _denom if _rat==.
replace _ratx=_numerx/_denomx if _ratx==.
drop _dummy* _deno* _nume* _capr*
/* Infer Machinery Stock */
replace ap`sufx1'0= _rat*apimmo0  if year==92 & ap`sufx1'0==.
replace ap`sufx2'0x=_ratx*apimmo0x if year==92 & ap`sufx2'0x==.
replace ap`sufx1'0=0 if ap`sufx1'0<0 & ap`sufx1'0~=.
replace ap`sufx2'0x=0 if ap`sufx2'0x<0 & ap`sufx2'0x~=.
drop _rat*
local round=`round'+1
}
masmadj

/* Forward-Impute Foreign Machinery Stock after 1992 */
local yr 92
while `yr'<=95 {
    sort firm year
    quietly by firm: replace apmafor1=apmafor0*(1-_sigma-_delta)+acqmafor if year==`yr'
    replace apmafor1=0 if apmafor1<0 & apmafor1~=.
    quietly by firm: replace apmafr1x=apmafr0x*(1-_sigma-_delta)+acqmafor if year==`yr'
    replace apmafr1x=0 if apmafr1x<0 & apmafr1x~=.
    quietly by firm: replace apmafor0=apmafor1[_n-1] if year==`yr'+1 & apmafor1[_n-1]~=.
    quietly by firm: replace apmafr0x=apmafr1x[_n-1] if year==`yr'+1 & apmafr1x[_n-1]~=.
    quietly by firm: replace apmause1=apmause0*(1-_sigma-_delta)+acqmause if year==`yr'
    replace apmause1=0 if apmause1<0 & apmause1~=.
    quietly by firm: replace apmaus1x=apmaus0x*(1-_sigma-_delta)+acqmause if year==`yr'
    replace apmaus1x=0 if apmaus1x<0 & apmaus1x~=.
    quietly by firm: replace apmause0=apmause1[_n-1] if year==`yr'+1 & apmause1[_n-1]~=.
    quietly by firm: replace apmaus0x=apmaus1x[_n-1] if year==`yr'+1 & apmaus1x[_n-1]~=.
    quietly by firm: replace apmadom1=apmadom0*(1-_sigma-_delta)+acqmadom if year==`yr'
    replace apmadom1=0 if apmadom1<0 & apmadom1~=.
    quietly by firm: replace apmadm1x=apmadm0x*(1-_sigma-_delta)+acqmadom if year==`yr'
    replace apmadm1x=0 if apmadm1x<0 & apmadm1x~=.
    quietly by firm: replace apmadom0=apmadom1[_n-1] if year==`yr'+1 & apmadom1[_n-1]~=.
    quietly by firm: replace apmadm0x=apmadm1x[_n-1] if year==`yr'+1 & apmadm1x[_n-1]~=.
    masmadj
    local yr=`yr'+1
}
/* Intertemporal Consistency */
sort firm year
quietly by firm: replace apmafor0=apmafor1[_n-1] if apmafor1[_n-1]~=.
quietly by firm: replace apmafr0x=apmafr1x[_n-1] if apmafr1x[_n-1]~=.

/* Backward-Impute Foreign Machinery Stock when missing year */
local yr 95
while `yr'>=86 {
    sort firm year
    quietly by firm: replace apmafor0=(apmafor1-acqmafor)/(1-_sigma-_delta) if year==`yr'
    replace apmafor0=0 if apmafor0<0 & apmafor0~=.
    quietly by firm: replace apmafr0x=(apmafr1x-acqmafor)/(1-_sigma-_delta) if year==`yr'
    replace apmafr0x=0 if apmafr0x<0 & apmafr0x~=.
    quietly by firm: replace apmafor1=apmafor0[_n+1] if year==`yr'-1 & apmafor1[_n+1]~=.
    quietly by firm: replace apmafr1x=apmafr0x[_n+1] if year==`yr'-1 & apmafr1x[_n+1]~=.
    quietly by firm: replace apmause0=(apmause1-acqmause)/(1-_sigma-_delta) if year==`yr'
    replace apmause0=0 if apmause0<0 & apmause0~=.
    quietly by firm: replace apmaus0x=(apmaus1x-acqmause)/(1-_sigma-_delta) if year==`yr'
    replace apmaus0x=0 if apmaus0x<0 & apmaus0x~=.
    quietly by firm: replace apmause1=apmause0[_n+1] if year==`yr'-1 & apmause1[_n+1]~=.
    quietly by firm: replace apmaus1x=apmaus0x[_n+1] if year==`yr'-1 & apmaus1x[_n+1]~=.
    quietly by firm: replace apmadom0=(apmadom1-acqmadom)/(1-_sigma-_delta) if year==`yr'
    replace apmadom0=0 if apmadom0<0 & apmadom0~=.
    quietly by firm: replace apmadm0x=(apmadm1x-acqmadom)/(1-_sigma-_delta) if year==`yr'
    replace apmadm0x=0 if apmadm0x<0 & apmadm0x~=.
    quietly by firm: replace apmadom1=apmadom0[_n+1] if year==`yr'-1 & apmadom1[_n+1]~=.
    quietly by firm: replace apmadm1x=apmadm0x[_n+1] if year==`yr'-1 & apmadm1x[_n+1]~=.
    masmadj
    local yr=`yr'-1
}
/* Intertemporal Consistency */
sort firm year
quietly by firm: replace apmafor0=apmafor1[_n-1] if apmafor1[_n-1]~=.
quietly by firm: replace apmafr0x=apmafr1x[_n-1] if apmafr1x[_n-1]~=.

drop apmadom* apmadm* _*

save master6, replace
/* use master6, clear
   local depfact=1.32
   local depcomp=3.5
   local depothr=2.3
   local depveh=2.8
   local depbldg=.5  */

/* 6: Rented Capital Stock */
/*-------------------------*/

/* Interest Rates */
sort year
merge year using `irate'
drop _merge
rename rrate _rrate

/* Depreciation rates: Delta */
sort firm year
quietly regress sdepclcr deprec
predict _depclcr, xb
gen     _dummy1=sdepclcr if year>=92
egen    _depclcx=mean(_dummy1), by(niv100 region)  /* If no predicted depreciation rate, use average of industry and region in 90s */
replace _dummy1=tdepclcr if year>=92
egen    _dummy2=mean(_dummy1)
replace _depclcx=_dummy2 if _depclcx==.
replace _depclcx=. if _depclcx==0
rename  _depclcr _delta
replace _delta=_depclcx if _delta==.
replace _delta=_depclcx if _delta<.02 & _depclcx>=.02
drop _dummy* _depclc*
egen _dd90=mean(_delta) if year<=88,            by(firm)
egen _dd95=mean(_delta) if year>=92 & year<=95, by(firm)
egen _dd98=mean(_delta) if year>=96,            by(firm)
egen _d90=min(_dd90), by(firm)
egen _d95=min(_dd95), by(firm)
egen _d98=min(_dd98), by(firm)
gen     _drate=_d90 if year<=90
replace _drate=_d95 if year>90 & year<=95
replace _drate=_d98 if year>95
replace _drate=.02 if _drate<.02

egen _rent=rsum(aslsimmo asrtimmo)
gen apimmo1r=_rent/(_rrate+_drate)
label var apimmo1r "End Y. - Rented Assets (Total)"

preserve
    keep niv100 year _rrate _drate deprec sdepclcr tdepclcr depimplr sdepimpr tdepimpr apimmo1x
    foreach var in rrate drate { rename _`var' `var' }
    label var drate "Depreciation Rate for User Cost"
    replace deprec = deprec/apimmo1x
    order niv100 year rrate drate
    collapse (mean) rrate drate deprec sdepclcr tdepclcr depimplr sdepimpr tdepimpr [weight=apimmo1x], by(niv100 year)
    compress
    keep niv100 year rrate drate deprec sdepclcr tdepclcr 
    drop if niv100==.
    foreach var in rrate drate deprec sdepclcr tdepclcr { replace `var'=. if `var'==0 }
    label var niv100 "Sector Nivel 100"
    label var year "Calendar Year"
    label var rrate "Real Interest Rate (Poupanca)"
    label var drate "Depreciation Rate for User Cost"
    label var deprec "Depreciation Cost / Asset Value"
    label var sdepclcr "Rel. Deprec. Rate (N100, Region)"
    label var tdepclcr "Rel. Deprec. Rate (overall)"
    save "brazprod/addl/deprec", replace
restore


/* 7: Finalize */
/*-------------*/
keep firm year apimmo1 apbl1 apmasum1 apmafor1 apmause1 apveh1 apother1 apcomp1 apimmo0 apbl0 apmasum0 apmafor0 apmause0 apveh0 apother0 apcomp0 acqtot acqbl acqmasum acqmadom acqmause acqmafor acqveh acqother acqcomp asltot aslbl aslmasum aslveh aslother aslcomp deprec aslsimmo asrtimmo apimmo1x apimmo1r apimmo0x apmasm1x apmasm0x apmafr1x apmafr0x apmaus1x apmaus0x apcomp1x apcomp0x
order firm year apimmo1 apimmo1r apimmo1x acqtot asltot deprec apimmo0 apimmo0x apmasum1 apmasm1x acqmasum aslmasum apmasum0 apmasm0x apmafor1 apmafr1x acqmafor apmafor0 apmafr0x apmause1 apmaus1x acqmause apmause0 apmaus0x acqmadom apcomp1 apcomp1x acqcomp aslcomp apcomp0 apcomp0x apbl1 acqbl aslbl apbl0 apveh1 acqveh aslveh apveh0 apother1 acqother aslother apother0 aslsimmo asrtimmo
format apimmo1 apbl1 apmasum1 apmafor1 apmause1 apveh1 apother1 apcomp1 apimmo0 apbl0 apmasum0 apmafor0 apmause0 apveh0 apother0 apcomp0 acqtot acqbl acqmasum acqmadom acqmause acqmafor acqveh acqother acqcomp asltot aslbl aslmasum aslveh aslother aslcomp deprec apimmo1x apimmo0x apmasm1x apmasm0x apmafr1x apmafr0x apmaus1x apmaus0x apcomp1x apcomp0x aslsimmo asrtimmo apimmo1r %12.0g
sort firm year
drop if year==91

if `choice'~=9 {
    save "brazprod/data/pia-capstruct-compl-`ext'`fdfl'-`moncor'-`type'-`saltype'-`corron'", replace
    }
else {
    save "brazprod/data/pia-capstruct-compl-`ext'`fdfl'-`moncor'-`type'-`corron'", replace
    }
disp "The program will now proceed to erase temporary files. Press ---break--- button to cancel."
more
erase master.dta
erase master1.dta
erase master2.dta
erase master3.dta
erase master4.dta
erase master5.dta
erase master6.dta
