version 7.0
set matsize 180
set logtype text
capture log close


/* Choose Settings */
/*-----------------*/

local yrmax=98

foreach esttype in $esttype {

* local esttype "op"
/* Choice "ols": OLS         */
/*        "fe" : Within Eff. */
/*        "op" : Olley-Pakes */

local subtract 0
/* Choice 1: Subtract b_K /gamma_K /kappa^f and b_M /gamma_M /mu^f */
/* Choice 0: Do not subtract */
global subtract = `subtract'

local choice 3
/* Choice 3: FGV-IPA (and general)  Deflators 86-98 */
/*        4: FGV-DI (and general)   Deflators 86-98 */
/*        9: Apply IGP-OG to all variables */
if `choice'==3 {local ext "ipa"}
if `choice'==4 {local ext "di"}
if `choice'==9 {local ext "gen"}

local fdfl 2
/* Choice 0: Foreign inputs and investments deflated with domestic deflators */
/*        1: Foreign input and investment deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
if `fdfl'==0 { local fdfl="" }

global out 2
/* Choice 1: "valadd" */
/* Choice 2: "output" */
if $out==1 {local outtype "valadd"}
if $out==2 {local outtype "output"}

global trd 0
/* Choice 3: Klette & Griliches 96 correction */
/* Choice 2: year dummies ON, trend variables OFF */
/* Choice 1: trend variables ON, time dummies OFF  */
/* Choice 0: trend variables and year dummies OFF */
if $trd==3 {local trdtype "kletgri"}
if $trd==2 {local trdtype "dyears"}
if $trd==1 {local trdtype "trend"}
if $trd==0 {local trdtype "notrend"}

global fe 2
/* Choice 2: fixed effects in OP estimation ON, AND KletGri96 inspired correction */
/* Choice 1: fixed effects in OP estimation ON  */
/* Choice 0: fixed effects in OP estimation OFF */
if $fe==2 & "`esttype'"~="op" {global fe 1}
if $fe~=0 {local fetype "fe"}
else      {local fetype "nofe"}
if $fe==2 {local feout="fecorr"}
else      {local feout="`fetype'"}

global polynl 3
/* Choice 2: Polynomial of 2nd order is used in Step 3 */
/* Choice 3: Polynomial of 3rd order is used in Step 3 */
/* Choice 4: Polynomial of 4th order is used in Step 3 */
/* Choice 5: Polynomial of 5th order is used in Step 3 */
/* Choice 6: Polynomial of 6th order is used in Step 3 */
local polynl=$polynl

global xeff 1
/* Choice 1: Approximate for X-efficiency choice by managers */
/* Choice 0: Approximate for X-efficiency choice by managers */
if $xeff {local xeff="x"}


local indir  "$indir"
local outdir "$outdir"
if "$simul"~="" { 
    local indir  "$simul" 
    local outdir "$simul"
    }


/* Load Data Set */
/*---------------*/

use "`indir'/data/prodlevel-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'", clear
drop niv100 indtype
sort firm year
merge firm year using "brazprod/use-compl-`ext'`fdfl'", nokeep update
drop operat indexp indexit age-_merge
sort firm year
merge firm using "brazprod/cgc-lig/firmhead", nokeep update
drop _merge
keep firm year niv50 region lntfp lnlp fsize profit lnvaladd lnoutput bgkap bgmu ind* effborn firstyr lastyr fstsusyr effextyr

sort firm year
by firm: replace indresum=1 if indresum[_n-1]==1 & indsusp[_n-1]==1 & year[_n-1]==fstsusyr
replace indresum=. if indsusp==1 & year==fstsusyr
gen byte indentry= 1 if year==effborn-1900
gen byte indexit = 1 if year==effextyr-1
keep firm-indmoth ind*
drop indmoth
order firm year niv50 region lntfp lnlp fsize profit lnvaladd lnoutput indentry indexit indresum ind*
label var indexit  "Indicator: Exiting    (new def.)"
label var indentry "Indicator: Entering   (new def.)"
label var indresum "Indicator: Resuming   (new def.)"

gen double _laglntfp=.
gen double _laglnlp=.
gen double _lagfsize=.
sort firm year
foreach yr in 87 88 89 90 93 94 95 96 97 98 {
    by firm: replace _laglntfp=lntfp[_n-1] if year==`yr' & year[_n-1]==`yr'-1
    by firm: replace _lagfsize=fsize[_n-1] if year==`yr' & year[_n-1]==`yr'-1
    }
foreach yr in 92 {
    by firm: replace _laglntfp=lntfp[_n-1] if year==`yr' & year[_n-1]==`yr'-2
    by firm: replace _lagfsize=fsize[_n-1] if year==`yr' & year[_n-1]==`yr'-2
    }
sort firm year
by firm: gen byte indstay = 1 if lntfp~=. & _laglntfp~=. & fsize~=. & _lagfsize~=. & region==region[_n-1] & niv50==niv50[_n-1]
drop _*
label var indstay  "Indicator: Stayer     (new def.)"
order firm year niv50 region lntfp lnlp fsize profit lnvaladd lnoutput indstay indentry indexit indresum ind* bgkap bgmu
/* browse firm year ind* if firm==2832418 | firm==3092509 */

/* Mutually exclusive grouping */
sort firm year
replace indstay=. if indresum==1 & indsusp==1
by firm: replace indresum=1 if indsusp[_n-1]==1
by firm: replace indresum=. if indsusp[_n-1]~=1 & (year[_n-1]==year-1 | (year[_n-1]==90 & year==92))
replace indresum=. if indentry==1
replace indstay=.  if indentry==1
replace indstay=.  if indresum==1
         replace indsusp=. if indexit==1
by firm: replace indstay=. if indexit[_n-1]==1
by firm: replace indstay=. if indsusp[_n-1]==1
label var indsusp  "Indicator: Suspending (new def.)"
/* browse firm year ind* if firm==9950940 | firm==49473531 | firm==83646620 */
/* browse firm year ind* if firm==50226455 | firm==50931211 */
sort firm year

qui summ, meanonly
local N = r(N)
egen double _chkt = rsum(indstay indentry indresum)
count if _chkt>1
if r(N)>0 { keep if _chkt>1
            disp in red "Classification in t not mutually exclusive " in yellow r(N) "/`N' " in red " cases" 
            exit }
count if _chkt<1
/*
if r(N)>0 { keep if _chkt<1
            disp in red "Classification in t not exhaustive or missing obs. " in yellow r(N) "/`N' " in red " cases" 
            exit }
*/
gen byte _indleadstay=.
sort firm year
foreach yr in 86 87 88 89 90 92 93 94 95 96 97 {
    by firm: replace _indleadstay=indstay[_n+1] if year==`yr' & year[_n+1]==`yr'+1
    }
foreach yr in 90 {
    by firm: replace _indleadstay=indstay[_n+1] if year==`yr' & year[_n+1]==`yr'+2
    }
egen double _chklag = rsum(_indleadstay indexit indsusp)
count if _chklag>1
if r(N)>0 { keep if _chklag>1
            disp in red "Classification in t-1 not mutually exclusive " in yellow r(N) "/`N' " in red " cases" 
            exit }
count if _chklag<1
/*
if r(N)>0 { keep if _chklag<1
            disp in red "Classification in t-1 not exhaustive or missing obs. " in yellow r(N) "/`N' " in red " cases" 
            exit }
*/
drop _*

compress
tsset firm year, yearly
format year %2.0f
sort firm year
save "`outdir'/use-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'", replace

}
