version 7.0
tempfile tmp1 tmp2
tempfile gomes11 gomes21 gomes12 gomes22 gomes31 gomes32

/* Choose Settings */
/*-----------------*/

foreach esttype in $esttype {
foreach rebase in 0 1 {

* local esttype "op"
/* Choice "ols": OLS         */
/*        "fe" : Within Eff. */
/*        "op" : Olley-Pakes */
/*        "gm" : Griliches-Mairesse */

* local rebase=1  /* 0: needed for tfp-prodlevel-annual-decomp.do, 1: recommended */
/* Choice 1: Rebase logtfp by sector (after sector aggregation) so that 1986==1 before aggregation */
/* Choice 0: Only rebase at aggregation */

local subtract 0
/* Choice 1: Subtract b_K /gamma_K /kappa^f and b_M /gamma_M /mu^f */
/* Choice 0: Do not subtract */
global subtract = `subtract'

local choice 3
/* Choice 3: FGV-IPA (and general)  Deflators 86-98 */
/*        4: FGV-DI (and general)   Deflators 86-98 */
/*        9: Apply IGP-OG to all variables */
if `choice'==3 {local ext "ipa"}
if `choice'==4 {local ext "di"}
if `choice'==9 {local ext "gen"}

local fdfl 2
/* Choice 0: Foreign inputs and investments deflated with domestic deflators */
/*        1: Foreign input and investment deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
if `fdfl'==0 { local fdfl="" }

global out 2
/* Choice 1: "valadd" */
/* Choice 2: "output" */
if $out==1 {local outtype "valadd"}
if $out==2 {local outtype "output"}

global trd 0
/* Choice 3: Klette & Griliches 96 correction */
/* Choice 2: year dummies ON, trend variables OFF */
/* Choice 1: trend variables ON, time dummies OFF  */
/* Choice 0: trend variables and year dummies OFF */
if $trd==3 {local trdtype "kletgri"}
if $trd==2 {local trdtype "dyears"}
if $trd==1 {local trdtype "trend"}
if $trd==0 {local trdtype "notrend"}

global fe 2
/* Choice 2: fixed effects in OP estimation ON, AND KletGri96 inspired correction */
/* Choice 1: fixed effects in OP estimation ON  */
/* Choice 0: fixed effects in OP estimation OFF */
if $fe==2 & "`esttype'"~="op" {global fe 1}
if $fe~=0 {local fetype "fe"}
else      {local fetype "nofe"}
if $fe==2 {local feout="fecorr"}
else      {local feout="`fetype'"}

global polynl 3
/* Choice 2: Polynomial of 2nd order is used in Step 3 */
/* Choice 3: Polynomial of 3rd order is used in Step 3 */
/* Choice 4: Polynomial of 4th order is used in Step 3 */
/* Choice 5: Polynomial of 5th order is used in Step 3 */
/* Choice 6: Polynomial of 6th order is used in Step 3 */
local polynl=$polynl

global xeff 1
/* Choice 1: Approximate for X-efficiency choice by managers */
/* Choice 0: Approximate for X-efficiency choice by managers */
if $xeff {local xeff="x"}


/* Data Read-In */
/*--------------*/

local outdir = "$outdir"
if "$simul"~="" { 
    local outdir = "$simul/$outdir"
    }

insheet using "brazprod/addl/vgomes-tfp.csv", clear
drop v4
rename years year
rename tfppim lntfppim
rename tfpfiesp lntfpfiesp
replace tfpellerygomes = ln(tfpellerygomes)
rename tfpellerygomes lntfpellgom
replace year=year-1900
drop if year<86
gen double _dummy1=lntfppim if year==86
egen double _pimstd=max(_dummy1)
replace lntfppim=lntfppim/_pimstd
gen double _dummy2=lntfpfiesp if year==86
egen double _fiespstd=max(_dummy2)
replace lntfpfiesp=lntfpfiesp/_fiespstd
gen double _dummy3=lntfpellgom if year==86
egen double _ellgomstd=max(_dummy3)
replace lntfpellgom=lntfpellgom/_ellgomstd
drop _*
sort year
gen byte aggtype=1
preserve
    gen byte region=9
    drop lntfpfiesp
    sort aggtype region year
    save `gomes11', replace
restore, preserve
    gen byte region=3
    drop lntfppim
    sort aggtype region year
    save `gomes21', replace
restore, preserve
    gen byte region=9
    drop lntfpellgom
    sort aggtype region year
    save `gomes31', replace
restore
replace aggtype=2
preserve
    gen byte region=9
    drop lntfpfiesp
    sort aggtype region year
    save `gomes12', replace
restore, preserve
    gen byte region=3
    drop lntfppim
    sort aggtype region year
    save `gomes22', replace
restore, preserve
    gen byte region=9
    drop lntfpellgom
    sort aggtype region year
    save `gomes32', replace
restore

use "`outdir'/prodlevel`rebase'-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'", clear
keep sample niv50 region year gmlntfp gmlnlp cellsize totsize
reshape wide gmlntfp gmlnlp cellsize totsize, i(niv50 region year) j(sample)

preserve

local round 1
while `round'<= 2 {
if `round'==2 {keep if niv50==4 | niv50==7 | niv50==8 | niv50==10 | niv50==12 | niv50==13 | niv50==14 | niv50==15 | niv50==21 | niv50==22  | niv50==23 | niv50==24 | niv50==26 | niv50==31 }
gen byte aggtype=`round'

/* Determine relative size of each SECTOR in total */
egen double totsec1=sum(totsize1), by(region year)
gen double _weight1=totsize1/totsec1
egen double totsec2=sum(totsize2), by(region year)
gen double _weight2=totsize2/totsec2

/* Determine CELLSIZES */
egen double totcells1=sum(cellsize1), by(region year)
egen double totcells2=sum(cellsize2), by(region year)

/* Obtain Means (weighted Sums) WITHIN GROUP */
gen double _wtfp1=_weight1*gmlntfp1
gen double _wlp1 =_weight1*gmlnlp1
egen double agglntfp1=sum(_wtfp1), by(region year)
egen double agglnlp1 =sum(_wlp1) , by(region year)
gen double _wtfp2=_weight2*gmlntfp2
gen double _wlp2 =_weight2*gmlnlp2
egen double agglntfp2=sum(_wtfp2), by(region year)
egen double agglnlp2 =sum(_wlp2) , by(region year)

if $out==1 {rename totsec1 totvaladd1
            rename totsec2 totvaladd2}
if $out==2 {rename totsec1 totoutput1
            rename totsec2 totoutput2}
sort aggtype region year
by aggtype region year: keep if _n==1

label var aggtype    "Aggregation. 1: all, 2: less sec's"
label var agglntfp1  "Aggregate Log TFP"
label var agglnlp1   "Aggregate Log LP"
label var totcells1  "Cellsize"
label var agglntfp2  "Aggregate Log TFP"
label var agglnlp2   "Aggregate Log LP"
label var totcells2  "Cellsize"
if $out==1 {label var totvaladd1 "Total ValAdd Region"
            label var totvaladd2 "Total ValAdd Region"
            keep  aggtype region year agglntfp1 agglnlp1 totvaladd1 totcells1 agglntfp2 agglnlp2 totvaladd2 totcells2
            order aggtype region year agglntfp1 agglnlp1 totvaladd1 totcells1 agglntfp2 agglnlp2 totvaladd2 totcells2}
if $out==2 {label var totoutput1 "Total Output Region"
            label var totoutput2 "Total Output Region"
            keep  aggtype region year agglntfp1 agglnlp1 totoutput1 totcells1 agglntfp2 agglnlp2 totoutput2 totcells2
            order aggtype region year agglntfp1 agglnlp1 totoutput1 totcells1 agglntfp2 agglnlp2 totoutput2 totcells2}

save `tmp`round'', replace
restore, preserve
local round=`round'+1
}

restore
use `tmp1', clear
append using `tmp2'

/* Finalize */
sort aggtype region year
compress
save "`outdir'/prodlevel`rebase'-annual-agg-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'", replace

if $out==1 {egen double _tottotsize1=sum(totvaladd1) if region~=9, by(aggtype year)
            gen double regshare1=totvaladd1/_tottotsize1
            replace regshare1=1 if region==9
            egen double _tottotsize2=sum(totvaladd2) if region~=9, by(aggtype year)
            gen double regshare2=totvaladd2/_tottotsize2
            replace regshare2=1 if region==9
            label var regshare1 "Share of Region in Val Add"
            label var regshare2 "Share of Region in Output"}
if $out==2 {egen double _tottotsize1=sum(totoutput1) if region~=9, by(aggtype year)
            gen double regshare1=totoutput1/_tottotsize1
            replace regshare1=1 if region==9
            egen double _tottotsize2=sum(totoutput2) if region~=9, by(aggtype year)
            gen double regshare2=totoutput2/_tottotsize2
            replace regshare2=1 if region==9
            label var regshare1 "Share of Region in Val Add"
            label var regshare2 "Share of Region in Output"}
drop _*

rename totcells1 cellsize1
rename totcells2 cellsize2
gen double _adjfac=agglntfp1 if year==86
egen double _spill=min(_adjfac), by(aggtype region)
replace _adjfac=_spill
drop _spill
gen double nmagglntfp1=agglntfp1/_adjfac
gen double nmagglnlp1=agglnlp1/_adjfac
gen double nmagglntfp2=agglntfp2/_adjfac
gen double nmagglnlp2=agglnlp2/_adjfac
drop _*
order aggtype region year nmagg* agg* tot*
label var nmagglntfp1  "Rebased Aggregate Log TFP"
label var nmagglnlp1   "Rebased Aggregate Log LP"
label var nmagglntfp2  "Rebased Aggregate Log TFP"
label var nmagglnlp2   "Rebased Aggregate Log LP"
drop if region==5
sort aggtype region year
compress
save "`outdir'/prodlevel`rebase'-annual-nmagg-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'", replace

keep if region==3 | region==9
keep aggtype region year nmagglntfp1 nmagglnlp1 nmagglntfp2 nmagglnlp2
sort aggtype region year
merge aggtype region year using `gomes11'
drop _merge
sort aggtype region year
merge aggtype region year using `gomes21'
drop _merge
sort aggtype region year
merge aggtype region year using `gomes31'
drop _merge
sort aggtype region year
merge aggtype region year using `gomes12', update
drop _merge
sort aggtype region year
merge aggtype region year using `gomes22', update
drop _merge
sort aggtype region year
merge aggtype region year using `gomes32', update
drop _merge
replace lntfppim=.    if region==3
replace lntfpellgom=. if region==3
replace lntfpfiesp=.  if region==9
sort aggtype region year
label var lntfppim     "Log TFP in PIM (V. Gomes 01)"
label var lntfpfiesp   "Log TFP in FIESP (V. Gomes 01)"
label var lntfpellgom  "Log TFP Brazil (Ellery/Gomes 03)"
label var nmagglntfp1  "Log TFP in PIA"
label var nmagglnlp1   "Log LP in PIA"
label var nmagglntfp2  "Log TFP: Stayers in PIA"
label var nmagglnlp2   "Log LP: Stayers in PIA"
keep aggtype region year nmagglntfp1 nmagglnlp1 nmagglntfp2 nmagglnlp2 lntfppim lntfpfiesp lntfpellgom
save "`outdir'/prodlevel`rebase'-annual-compagg-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'", replace 

}
}
