version 7.0
tempfile tmp1 tmp2

/* Choose Settings */
/*-----------------*/

local rebase=0  /* ONLY 0 permissible */
/* Choice 0: Only rebase at aggregation */

foreach esttype in $esttype {
/* Choice "ols": OLS         */
/*        "fe" : Within Eff. */
/*        "op" : Olley-Pakes */

local subtract 0
/* Choice 1: Subtract b_K /gamma_K /kappa^f and b_M /gamma_M /mu^f */
/* Choice 0: Do not subtract */
global subtract = `subtract'

local choice 3
/* Choice 3: FGV-IPA (and general)  Deflators 86-98 */
/*        4: FGV-DI (and general)   Deflators 86-98 */
/*        9: Apply IGP-OG to all variables */
if `choice'==3 {local ext "ipa"}
if `choice'==4 {local ext "di"}
if `choice'==9 {local ext "gen"}

local fdfl 2
/* Choice 0: Foreign inputs and investments deflated with domestic deflators */
/*        1: Foreign input and investment deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
if `fdfl'==0 { local fdfl="" }

global out 2
/* Choice 1: "valadd" */
/* Choice 2: "output" */
if $out==1 {local outtype "valadd"}
if $out==2 {local outtype "output"}

global trd 0
/* Choice 3: Klette & Griliches 96 correction */
/* Choice 2: year dummies ON, trend variables OFF */
/* Choice 1: trend variables ON, time dummies OFF  */
/* Choice 0: trend variables and year dummies OFF */
if $trd==3 {local trdtype "kletgri"}
if $trd==2 {local trdtype "dyears"}
if $trd==1 {local trdtype "trend"}
if $trd==0 {local trdtype "notrend"}

global fe 2
/* Choice 2: fixed effects in OP estimation ON, AND KletGri96 inspired correction */
/* Choice 1: fixed effects in OP estimation ON  */
/* Choice 0: fixed effects in OP estimation OFF */
if $fe==2 & "`esttype'"~="op" {global fe 1}
if $fe~=0 {local fetype "fe"}
else      {local fetype "nofe"}
if $fe==2 {local feout="fecorr"}
else      {local feout="`fetype'"}

global polynl 3
/* Choice 2: Polynomial of 2nd order is used in Step 3 */
/* Choice 3: Polynomial of 3rd order is used in Step 3 */
/* Choice 4: Polynomial of 4th order is used in Step 3 */
/* Choice 5: Polynomial of 5th order is used in Step 3 */
/* Choice 6: Polynomial of 6th order is used in Step 3 */
local polynl=$polynl

global xeff 1
/* Choice 1: Approximate for X-efficiency choice by managers */
/* Choice 0: Approximate for X-efficiency choice by managers */
if $xeff {local xeff="x"}


/* Data Read-In */
/*--------------*/

local outdir = "$outdir"
if "$simul"~="" { 
    local outdir = "$simul/$outdir"
    }

use "`outdir'/proddecomp`rebase'-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'", clear
keep sample niv50 year region gmlntfp gmlnlp gmlntfp_stay* laggmlntfp_stay gmlnlp_stay* laggmlnlp_stay gmlntfp_entry gmlnlp_entry gmlntfp_resum gmlnlp_resum laggmlntfp_exit laggmlnlp_exit laggmlntfp_susp laggmlnlp_susp gmlntfp_miss gmlnlp_miss laggmlntfp_miss laggmlnlp_miss totsize cellsize

qui summ, meanonly
local N = r(N)
sort sample niv50 region year
foreach prod in tfp lp {
    local prodout = upper("`prod'")
    by sample niv50 region: gen double d`prod'tot  = gmln`prod' - gmln`prod'[_n-1]
    by sample niv50 region: gen double d`prod'stay = gmln`prod'_stay - laggmln`prod'_stay[_n-1]
    by sample niv50 region: gen double d`prod'inex = gmln`prod'_entry - laggmln`prod'_exit[_n-1]
    by sample niv50 region: gen double d`prod'moth = gmln`prod'_resum - laggmln`prod'_susp[_n-1]
    by sample niv50 region: gen double d`prod'miss = gmln`prod'_miss - laggmln`prod'_miss[_n-1]
    drop gmln`prod' gmln`prod'_stay laggmln`prod'_stay gmln`prod'_entry laggmln`prod'_exit gmln`prod'_resum laggmln`prod'_susp gmln`prod'_miss laggmln`prod'_miss
    rename gmln`prod'_stay_`prod'chg d`prod'stay_frmchg 
    rename gmln`prod'_stay_sizchg d`prod'stay_sizchg
    label var d`prod'tot  "`prodout' change: Total"
    label var d`prod'stay "`prodout' change: Stayers"
    label var d`prod'inex "`prodout' change: Entry & Exit"
    label var d`prod'moth "`prodout' change: Suspend & Resume"
    label var d`prod'miss "`prodout' change: Missing obs."
    label var d`prod'stay_frmchg "`prodout' change: Stayers, firm change"
    label var d`prod'stay_sizchg "`prodout' change: Stayers, size change"
    egen double _chkd = rsum(d`prod'stay d`prod'inex d`prod'moth d`prod'miss)
    egen double _chks = rsum(d`prod'stay_frmchg d`prod'stay_sizchg)
    count if int(_chkd*10000) ~= int(d`prod'tot*10000) & d`prod'tot~=.
    if r(N)>0 { keep if int(_chkd*10000) ~= int(d`prod'tot*10000) & d`prod'tot~=.
                disp in red "`prodout' decomposition does not add up to total in " in yellow r(N) "/`N' " in red " cases" 
                browse sample niv50 region year d`prod'tot _chkd d`prod'stay d`prod'inex d`prod'moth d`prod'miss
                exit }
    count if int(_chks*10000) ~= int(d`prod'stay*10000) & d`prod'stay~=.
    if r(N)>0 { keep if int(_chks*10000) ~= int(d`prod'stay*10000) & d`prod'stay~=.
                disp in red "`prodout' decomposition for stayers does not add up to total in " in yellow r(N) "/`N' " in red " cases" 
                browse sample niv50 region year d`prod'stay _chks d`prod'stay_frmchg d`prod'stay_sizchg
                exit }
    /*
    count if (d`prod'stay==. | d`prod'tot==.) & year~=86
    if r(N)>0 { keep if (d`prod'stay==. | d`prod'tot==.) & year~=86
                disp in red "Missing `prodout' change after 1986 in " in yellow r(N) "/`N' " in red " cases" 
                exit }
    */
    drop _*
    foreach var in d`prod'tot d`prod'stay d`prod'inex d`prod'moth d`prod'miss d`prod'stay_frmchg d`prod'stay_sizchg { replace `var'=0 if `var'==. }
}

order sample niv50 year region totsize cellsize dtfptot dtfpstay dtfpstay_* dtfpinex dtfpmoth dtfpmiss dlptot dlpstay dlpstay_* dlpinex dlpmoth dlpmiss
reshape wide dtfp* dlp* cellsize totsize, i(niv50 region year) j(sample)

preserve

local round 1
while `round'<= 2 {
if `round'==2 { keep if niv50==4 | niv50==7 | niv50==8 | niv50==10 | niv50==12 | niv50==13 | niv50==14 | niv50==15 | niv50==21 | niv50==22  | niv50==23 | niv50==24 | niv50==26 | niv50==31 }
gen byte aggtype=`round'

/* Determine relative size of each SECTOR in total */
egen double totsec1=sum(totsize1), by(region year)
gen double _weight1=totsize1/totsec1
egen double totsec2=sum(totsize2), by(region year)
gen double _weight2=totsize2/totsec2

/* Determine CELLSIZES */
egen double totcells1=sum(cellsize1), by(region year)
egen double totcells2=sum(cellsize2), by(region year)

/* Obtain Means (weighted Sums) WITHIN GROUP */
foreach cat in tot stay stay_frmchg stay_sizchg inex moth miss {
    gen double _wtfp1=_weight1*dtfp`cat'1
    gen double _wlp1 =_weight1*dlp`cat'1
    egen double agdtfp`cat'1=sum(_wtfp1), by(region year)
    egen double agdlp`cat'1 =sum(_wlp1) , by(region year)
    gen double _wtfp2=_weight2*dtfp`cat'2
    gen double _wlp2 =_weight2*dlp`cat'2
    egen double agdtfp`cat'2=sum(_wtfp2), by(region year)
    egen double agdlp`cat'2 =sum(_wlp2) , by(region year)
    drop _wt* _wl*
}

if $out==1 {rename totsec1 totvaladd1
            rename totsec2 totvaladd2}
if $out==2 {rename totsec1 totoutput1
            rename totsec2 totoutput2}
sort aggtype region year
by aggtype region year: keep if _n==1


foreach smpl in 1 2 {
  foreach prod in tfp lp {
    label var agd`prod'tot`smpl'  "`prodout' change: Total"
    label var agd`prod'stay`smpl' "`prodout' change: Stayers"
    label var agd`prod'inex`smpl' "`prodout' change: Entry & Exit"
    label var agd`prod'moth`smpl' "`prodout' change: Suspend & Resume"
    label var agd`prod'miss`smpl' "`prodout' change: Missing obs."
    label var agd`prod'stay_frmchg`smpl' "`prodout' change: Stayers, firm change"
    label var agd`prod'stay_sizchg`smpl' "`prodout' change: Stayers, size change"
  }
}
label var aggtype    "Aggreg. 1: all, 2: less sec."
label var totcells1  "Cellsize"
label var totcells2  "Cellsize"
if $out==1 {label var totvaladd1 "Total ValAdd Region"
            label var totvaladd2 "Total ValAdd Region"
            keep  aggtype region year agdtfp*1 agdlp*1 totvaladd1 totcells1 agdtfp*2 agdlp*2 totvaladd2 totcells2
            order aggtype region year agdtfp*1 agdlp*1 totvaladd1 totcells1 agdtfp*2 agdlp*2 totvaladd2 totcells2}
if $out==2 {label var totoutput1 "Total Output Region"
            label var totoutput2 "Total Output Region"
            keep  aggtype region year agdtfp*1 agdlp*1 totoutput1 totcells1 agdtfp*2 agdlp*2 totoutput2 totcells2
            order aggtype region year agdtfp*1 agdlp*1 totoutput1 totcells1 agdtfp*2 agdlp*2 totoutput2 totcells2}

save `tmp`round'', replace
restore, preserve
local round=`round'+1
}

restore
use `tmp1', clear
append using `tmp2'
sort aggtype region year

/* Finalize */
save "`outdir'/proddecomp`rebase'-annual-agg-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'", replace

/* preserve */
    use "`outdir'/proddecomp`rebase'-annual-agg-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'", replace
    fillin aggtype region year
    sort aggtype region year
    merge aggtype region year using "`outdir'/prodlevel`rebase'-annual-agg-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'"
    sort aggtype region year
    by aggtype region: gen double dagglntfp1 = agglntfp1 - agglntfp1[_n-1]
    by aggtype region: gen double dagglntfp2 = agglntfp2 - agglntfp2[_n-1]
    by aggtype region: gen double dagglnlp1 = agglnlp1 - agglnlp1[_n-1]
    by aggtype region: gen double dagglnlp2 = agglnlp2 - agglnlp2[_n-1]
    /* browse aggtype region year agdtfptot1 dagglntfp1 agdtfptot2 dagglntfp2 agdlptot1 dagglnlp1 agdlptot2 dagglnlp2 */
    gen double _difaggdectfp1= agdtfptot1 - dagglntfp1 
    gen double _difaggdectfp2= agdtfptot2 - dagglntfp2 
    gen double _difaggdeclp1=  agdlptot1 - dagglnlp1 
    gen double _difaggdeclp2=  agdlptot2 - dagglnlp2
    summ _dif*
/* restore */

}
