set seed 499131601962

version 7
set matsize 180
set logtype text
tempfile tmp usedata top5 top1

set more off

/* Choose Settings */
/*-----------------*/

local strtgrp 0      /* Niv50 (group) to start with. Useful if interruption occured. 0: not set. */

local bsreps = 50    /* Number of repetitions in bootstrap */

local choice 3
/* Choice 3: FGV-IPA (and general)  Deflators 86-98 */
/*        4: FGV-DI (and general)   Deflators 86-98 */
/*        9: Apply IGP-OG to all variables */
if `choice'==3 {
    local ext "ipa"
    }
if `choice'==4 {
    local ext "di"
    }
if `choice'==9 {
    local ext "gen"
    }

local fdfl 2
/* Choice 0: Foreign inputs and investments deflated with domestic deflators */
/*        1: Foreign input and investment deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
if `fdfl'==0 { 
    local fdfl="" 
    }

global out 2
/* Choice 2: "output" */
if $out==2 {
    local outtype "output"
    }


/* Load Data */
/*-----------*/

use "brazprod/use-tfp-`ext'`fdfl'-`outtype'-notrend", clear
keep if niv50==08 | niv50==14 | niv50==22 | niv50==26 | niv50==31
/* keep if niv50==22 | niv50==26 */
/* keep if niv50==1 | niv50==6 | niv50==22 */
/* keep if niv50==3 | niv50==8 */
/* keep if niv50==12 */
/* keep if niv50==8 | niv50==11 | niv50==19 */
keep firm year niv50 lnvaladd lnoutput kappa* lnapk* lnapq* lnlabfbl lnlabfwh mu lnintmed nt* reffpen realexch tariff kletgril inflrate

/* Import policy and demand variables */
sort firm year
merge firm year using "tfpest/seclvl-`ext'`fdfl'", update
drop _merge
sort firm year
duplicates drop firm year, force
/* Import competitor variables */
sort firm year
merge firm year using "tfpest/varsothrs-`ext'`fdfl'", update
tab _m
drop _merge
sort firm year
duplicates drop firm year, force
keep if year>=86

gen lnapktot = log(exp(lnapk1) + exp(lnapq1))
gen lnlbftot = log(exp(lnlabfbl) + exp(lnlabfwh))
gen nttotinv = ntkinv + ntqinv
label var lnapktot "Log Total Capital Stock - End Y"
label var lnlbftot "Log Total Labor Force"
label var nttotinv "Net Total Investment"

tsset firm year
gen ntinv_mpen = nttotinv * L.reffpen
label var ntinv_mpen "Interact Net Tot. Inv. * Eff. Penetr."
gen ntinv_oapk = nttotinv * L.oth_lnapk1
label var ntinv_oapk "Interact Net Tot. Inv. * Othrs' Eqpm."
gen ntinv_olpprx = nttotinv * L.oth_lpprox
label var ntinv_olpprx "Interact Net Tot. Inv. * Othrs' LProd"

drop if lnlabfbl==. | lnlabfwh==. | lnintmed==. | lnapktot==.

local yrmax=98
egen byte group=group(niv50)
sort group
local maxgrp=group[_N]
label var group "Group Number of Niv50"
sort niv50
preserve 
    by niv50: egen obs = count(firm)
    keep niv50 group obs
    sort niv50 obs
    by niv50 obs: keep if _n==1
    gsort -obs niv50
    list
    forvalues i = 1/5 {
      egen _maxobs = max(obs)
      gen _top`i' = niv50 if obs==_maxobs
      replace obs=. if obs==_maxobs
      drop _maxobs
      }
    drop if _top1==. & _top2==. & _top3==.  & _top4==. & _top5==.
*   drop if _top1==.
    keep niv50 obs
    sort niv50
    compress
    save `top5'
*   save `top1'
restore

merge niv50 using `top5'
* merge niv50 using `top1'
keep if _m==3
tab niv50
drop group
egen byte group=group(niv50)
sort group
local maxgrp=group[_N]
label var group "Group Number of Niv50"
sort niv50

keep firm year group niv50 lnoutput lnlabfbl lnlabfwh lnintmed lnapktot nttotinv reffpen ntinv_mpen 

tsset firm year
sort firm year
compress
save `usedata'


/* Estimation by Niv50 */
/*---------------------*/

capture log close
local run = 0
local exit = 0
while ~`exit' {
    local run = `run' + 1
    capture confirm new file "tfpest/estimate/logs/lev-pet-bstrp-`ext'`fdfl'-`outtype'-run`run'.log"
    if _rc~=602 {
        local exit=1
        }
}
log using "tfpest/estimate/logs/lev-pet-bstrp-`ext'`fdfl'-`outtype'-run`run'.log" 
log on

local grp 1
if `strtgrp'~=0 {
    local grp `strtgrp'
    }
while `grp' <= `maxgrp' {

global grp=`grp'
if $grp>1 {
    use `usedata', clear
    }
keep if group==$grp
tsset firm year

quietly summ niv50 if group==$grp
local recniv = r(mean)
local obs = r(N)
if `recniv' < 10 {
    local nivdsp = "0`recniv'"
    }
    else {
        local nivdsp = "`recniv'"
        }
disp
disp
disp "Bootstrap Niv50 == `nivdsp'"
disp "---------------------"
disp "(Observations: `obs')"
disp

local run = 0
local exit = 0
while ~`exit' {
    local run = `run' + 1
    capture confirm new file "tfpest/estimate/bstrp/niv`nivdsp'-`ext'`fdfl'-`outtype'-run`run'.dta"
    if _rc~=602 {
        local exit=1
        }
    }

disp in blue "Bootstrapping (" in yellow "`bsreps'" in green " total repetitions), levpetmam command"
bstrap blevpet, reps(`bsreps') saving("tfpest/estimate/bstrp/niv`nivdsp'-`ext'`fdfl'-`outtype'-run`run'") every(10) dots cluster(firm) idcluster(_firm)
disp "Saved as:" in  yellow "  tfpest/estimate/bstrp/niv`nivdsp'-`ext'`fdfl'-`outtype'-run`run'.dta"

local grp =`grp'+1
}

log close
