version 8
set matsize 180
set logtype text
capture log close
tempfile top5


/* Choose Settings */
/*-----------------*/

local choice 3
/* Choice 3: FGV-IPA (and general)  Deflators 86-98 */
/*        4: FGV-DI (and general)   Deflators 86-98 */
/*        9: Apply IGP-OG to all variables */
if `choice'==3 {
    local ext "ipa"
    }
if `choice'==4 {
    local ext "di"
    }
if `choice'==9 {
    local ext "gen"
    }

local fdfl 2
/* Choice 0: Foreign inputs and investments deflated with domestic deflators */
/*        1: Foreign input and investment deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
if `fdfl'==0 { 
    local fdfl="" 
    }

global out 2
/* Choice 2: "output" */
if $out==2 {
    local outtype "output"
    }

confirm new file "tfpest/estimate/logs/lev-pet-`ext'`fdfl'-`outtype'.log"
confirm new file "tfpest/estimate/coeff-`ext'`fdfl'-`outtype'.dta"
capture mkdir "tfpest/estimate/estmat/mat-`ext'`fdfl'-`outtype'/"

capture log close
log using "tfpest/estimate/logs/lev-pet-`ext'`fdfl'-`outtype'.log", replace

use "brazprod/use-tfp-`ext'`fdfl'-`outtype'-notrend", clear
/* keep if niv50==1 | niv50==6 | niv50==22 */
/* keep if niv50==3 | niv50==8 */
/* keep if niv50==12 */
/* keep if niv50==8 | niv50==11 | niv50==19 */
keep firm year niv50 lnvaladd lnoutput kappa* lnapk* lnapq* lnlabfbl lnlabfwh mu lnintmed nt* reffpen realexch tariff kletgril inflrate

/* Import policy and demand variables */
sort firm year
merge firm year using "tfpest/seclvl-`ext'`fdfl'", update
drop _merge
sort firm year
duplicates drop firm year, force
/* Import competitor variables */
sort firm year
merge firm year using "tfpest/varsothrs-`ext'`fdfl'", update
tab _m
drop _merge
sort firm year
duplicates drop firm year, force

gen lnapktot = log(exp(lnapk1) + exp(lnapq1))
gen lnlbftot = log(exp(lnlabfbl) + exp(lnlabfwh))
gen nttotinv = ntkinv + ntqinv
label var lnapktot "Log Total Capital Stock - End Y"
label var lnlbftot "Log Total Labor Force"
label var nttotinv "Net Total Investment"

tsset firm year
gen ntinv_mpen = nttotinv * L.reffpen
label var ntinv_mpen "Interact Net Tot. Inv. * Eff. Penetr."
gen ntinv_oapk = nttotinv * L.oth_lnapk1
label var ntinv_oapk "Interact Net Tot. Inv. * Othrs' Eqpm."
gen ntinv_olpprx = nttotinv * L.oth_lpprox
label var ntinv_olpprx "Interact Net Tot. Inv. * Othrs' LProd"

drop if lnlabfbl==. | lnlabfwh==. | lnintmed==. | lnapktot==.

local yrmax=98
egen byte group=group(niv50)
sort group
local maxgrp=group[_N]
label var group "Group Number of Niv50"
sort niv50
preserve 
    by niv50: egen obs = count(firm)
    keep niv50 group obs
    sort niv50 obs
    by niv50 obs: keep if _n==1
    gsort -obs niv50
    list
    forvalues i = 1/5 {
      egen _maxobs = max(obs)
      gen _top`i' = niv50 if obs==_maxobs
      replace obs=. if obs==_maxobs
      drop _maxobs
      }
    drop if _top1==. & _top2==. & _top3==.  & _top4==. & _top5==.
    keep niv50 obs
    sort niv50
    compress
    save `top5'
restore

merge niv50 using `top5'
keep if _m==3
tab niv50
drop group
egen byte group=group(niv50)
sort group
local maxgrp=group[_N]
label var group "Group Number of Niv50"
sort niv50

gen _firm = firm
tsset _firm year


/* Estimation by Niv50 */
/*---------------------*/

keep firm _firm year group niv50 lnoutput lnlabfbl lnlabfwh lnintmed lnapktot nttotinv reffpen ntinv_mpen 

preserve

qui summ group, meanonly
local mingrp = `r(min)'
local grp = `mingrp'
while `grp' <= `maxgrp' {

quietly summ niv50 if group==`grp'
local recniv = r(mean)
local obs = r(N)
if `recniv' < 10 {
    local nivdsp = "0`recniv'"
    }
else         {
    local nivdsp = "`recniv'"
    }
disp
disp
disp "Niv50 == `nivdsp'"
disp "-----------"
disp "(Observations: `obs')"
disp

keep if group==`grp'  /* This line can be removed but makes program faster */

* qui regress lnoutput lnlbftot lnintmed lnapktot nttotinv reffpen realexch _tariff _kletgril inflrate, nocons
* qui gen expproxy = (_coef[nttotinv]*nttotinv + _coef[reffpen]*reffpen + _coef[realexch]*realexch + _coef[_tariff]*_tariff  + _coef[_kletgril]*_kletgril + _coef[inflrate]*inflrate) / (_coef[nttotinv] + _coef[reffpen] + _coef[realexch] + _coef[_tariff] + _coef[_kletgril] + _coef[inflrate])
* qui regress lnoutput reffpen _tariff
* qui gen expproxy = (_coef[reffpen]*reffpen + _coef[_tariff]*_tariff) / (_coef[reffpen] + _coef[_tariff])
* levpetmam lnoutput, free(lnlabfbl lnlabfwh lnintmed) proxy(expproxy) capital(lnapktot) revenue justid reps(0)
* capture noi levpetmam lnoutput, free(lnlabfbl lnlabfwh lnintmed) proxy(nttotinv) capital(lnapktot) revenue justid reps(0)
* est2vec _tmp, addto(levpet) nokeep replace name(niv`nivdsp'ollpak)
* capture noi levpetmam lnoutput, free(lnlabfbl lnlabfwh lnintmed) proxy(reffpen) capital(lnapktot) revenue justid reps(0)
* est2vec _tmp, addto(levpet) nokeep replace name(niv`nivdsp'eop)

global r_N = .
global r_df_m = .
global r_F = .
global r_r2 = .
global r_bprox = .
global r_seprox = .

capture noi reg lnoutput lnlabfbl lnlabfwh lnintmed lnapktot, nocons
    if `grp' == `mingrp' { 
        est2vec ols, v(lnlabfbl lnlabfwh lnintmed lnapktot) e(N r2 F) replace name(niv`nivdsp')
        mat ols_r = ( $r_N \ $r_df_m \ $r_F \ $r_r2 \ $r_bprox \ $r_seprox )
        matname ols_r r(N) r(df_m) r(F) r(r2) r(b_proxy) r(se_proxy), rows(1..6) explicit
        matname ols_r niv`nivdsp', columns(1) explicit
        }
    else {
        est2vec ols, addto(ols) nokeep replace name(niv`nivdsp')
        mat ols_r = ols_r , ( $r_N \ $r_df_m \ $r_F \ $r_r2 \ $r_bprox \ $r_seprox )
        local cols = colsof(ols_r)
        matname ols_r niv`nivdsp', columns(`cols') explicit
        }
capture noi levpetmam lnoutput, free(lnlabfbl lnlabfwh) proxy(lnintmed) capital(lnapktot) revenue justid reps(0) i(_firm) t(year)
    if `grp' == `mingrp' { 
        est2vec lp, v(lnlabfbl lnlabfwh lnintmed lnapktot) e(N r2 F) replace name(niv`nivdsp')
        mat lp_r = ( $r_N \ $r_df_m \ $r_F \ $r_r2 \ $r_bprox \ $r_seprox )
        matname lp_r r(N) r(df_m) r(F) r(r2) r(b_proxy) r(se_proxy), rows(1..6) explicit
        matname lp_r niv`nivdsp', columns(1) explicit
        }
    else {
        est2vec lp, addto(lp) nokeep replace name(niv`nivdsp')
        mat lp_r = lp_r , ( $r_N \ $r_df_m \ $r_F \ $r_r2 \ $r_bprox \ $r_seprox )
        local cols = colsof(lp_r)
        matname lp_r niv`nivdsp', columns(`cols') explicit
        }
capture noi levpetmam lnoutput, free(lnlabfbl lnlabfwh lnintmed) proxy(nttotinv) capital(lnapktot) revenue justid reps(0) i(_firm) t(year)
    if `grp' == `mingrp' { 
        est2vec op, v(lnlabfbl lnlabfwh lnintmed lnapktot nttotinv) e(N r2 F) replace name(niv`nivdsp')
        mat op_r = ( $r_N \ $r_df_m \ $r_F \ $r_r2 \ $r_bprox \ $r_seprox )
        matname op_r r(N) r(df_m) r(F) r(r2) r(b_proxy) r(se_proxy), rows(1..6) explicit
        matname op_r niv`nivdsp', columns(1) explicit
        }
    else {
        est2vec op, addto(op) nokeep replace name(niv`nivdsp')
        mat op_r = op_r , ( $r_N \ $r_df_m \ $r_F \ $r_r2 \ $r_bprox \ $r_seprox )
        local cols = colsof(op_r)
        matname op_r niv`nivdsp', columns(`cols') explicit
        }
capture noi levpetmam lnoutput, free(lnlabfbl lnlabfwh lnintmed) proxy(ntinv_mpen) capital(lnapktot) revenue justid reps(0) i(_firm) t(year)
    if `grp' == `mingrp' { 
        est2vec eop, v(lnlabfbl lnlabfwh lnintmed lnapktot ntinv_mpen) e(N r2 F) replace name(niv`nivdsp')
        mat eop_r = ( $r_N \ $r_df_m \ $r_F \ $r_r2 \ $r_bprox \ $r_seprox )
        matname eop_r r(N) r(df_m) r(F) r(r2) r(b_proxy) r(se_proxy), rows(1..6) explicit
        matname eop_r niv`nivdsp', columns(1) explicit
        }
    else {
        est2vec eop, addto(eop) nokeep replace name(niv`nivdsp')
        mat eop_r = eop_r , ( $r_N \ $r_df_m \ $r_F \ $r_r2 \ $r_bprox \ $r_seprox )
        local cols = colsof(eop_r)
        matname eop_r niv`nivdsp', columns(`cols') explicit
        }

restore, preserve
local grp =`grp'+1
}
restore

preserve
foreach type in b se e r {
    drop _all
    matsave ols_`type', path("tfpest/estimate/estmat/mat-`ext'`fdfl'-`outtype'/") replace
    drop _all
    matsave lp_`type', path("tfpest/estimate/estmat/mat-`ext'`fdfl'-`outtype'/") replace
    drop _all
    matsave op_`type', path("tfpest/estimate/estmat/mat-`ext'`fdfl'-`outtype'/") replace
    drop _all
    matsave eop_`type', path("tfpest/estimate/estmat/mat-`ext'`fdfl'-`outtype'/") replace
}
restore

log close
