version 7.0
set matsize 180
set logtype text
capture log close


/* Choose Settings */
/*-----------------*/

global compvar "lnapk1 lnapq1 lpprox"

local choice 3
/* Choice 3: FGV-IPA (and general)  Deflators 86-98 */
/*        4: FGV-DI (and general)   Deflators 86-98 */
/*        9: Apply IGP-OG to all variables */
if `choice'==3 {local ext "ipa"}
if `choice'==4 {local ext "di"}
if `choice'==9 {local ext "gen"}

local fdfl 2
/* Choice 0: Foreign inputs and investments deflated with domestic deflators */
/*        1: Foreign input and investment deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
if `fdfl'==0 { local fdfl="" }

global out 2
/* Choice 1: "valadd" */
/* Choice 2: "output" */
if $out==1 {local outtype "valadd"}
if $out==2 {local outtype "output"}

global trd 0
/* Choice 3: Klette & Grilliches 96 correction */
/* Choice 2: year dummies ON, trend variables OFF */
/* Choice 1: trend variables ON, time dummies OFF  */
/* Choice 0: trend variables and year dummies OFF */
if $trd==3 {local trdtype "kletgri"}
if $trd==2 {local trdtype "dyears"}
if $trd==1 {local trdtype "trend"}
if $trd==0 {local trdtype "notrend"}


tempfile compdata
use "brazprod/use-tfp-`ext'`fdfl'-`outtype'-`trdtype'", clear
if "$posinv"~="" { drop if ntqinv<=0 | ntkinv<=0 }
gen lpprox = exp(lnoutput)/(exp(lnlabfbl)+exp(lnlabfwh))
label var lpprox "Labor Prod (Output/Empl)"
keep firm year niv50 $compvar
sort firm year
save `compdata'

use `compdata'
local j 0
foreach var in $compvar {
  local j = `j' + 1
  local lbl`j' : variable label `var'
  local lbl`j' = subinstr("`lbl`j''"," - End Y.","",.)
  local lbl`j' = subinstr("`lbl`j''"," - Beg Y.","",.)
  local lbl`j' = subinstr("`lbl`j''"," - End Y","",.)
  local lbl`j' = subinstr("`lbl`j''"," - Beg Y","",.)
  }

foreach yr in 86 87 88 89 90 92 93 94 95 96 97 98 {
  use `compdata', clear
  keep if year==`yr'
  sort firm
  count
  local totnum = `r(N)'
  gen _no = _n
  order _n
  qui compress
  preserve
  forvalues i = 1/`totnum' {
    tempfile othrs`yr'`i'
    restore, preserve
    summ firm if _no == `i', meanonly
    local firmid = r(mean)
    summ niv50 if _no == `i', meanonly
    local sector = r(mean)
    qui drop if _no == `i'
    qui drop if niv50 ~= `sector'
    * mean unweighted competitor variables
    collapse (mean) $compvar, fast
    qui gen double firm = `firmid'
    order firm
    qui save `othrs`yr'`i''
    }
  restore, preserve

  tempfile othrs`yr'
  qui use `othrs`yr'1', clear
  forvalues i = 2/`totnum' {
    qui append using `othrs`yr'`i''
    }
  sort firm
  save `othrs`yr''
  restore
  }


/* Finalize */
/*----------*/

use `othrs86', clear
gen byte year = 86
foreach yr in 87 88 89 90 92 93 94 95 96 97 98 {
  append using `othrs`yr''
  replace year = `yr' if year==.
  }

order firm year $compvar
label var firm "Tax Number (CGC)"
label var year "Calendar Year"
format firm %8.0f
format year %2.0f
local j 0
foreach var in $compvar {
  local j = `j' + 1
  rename `var' oth_`var'
  local lbl = substr("`lbl`j''",1,24)
  label var oth_`var' "Others: `lbl'"
  }

/* Year 91 */

expand 2 if year==92
sort firm year
by firm: replace year=91 if year==92 & year[_n+1]==92
foreach var in oth_lnapk1 oth_lnapq1 oth_lpprox {
  sort firm year
  by firm: replace `var' = (`var'[_n-1] + `var'[_n+1])/2 if year==91
  } 

/* Year 86 */

expand 2 if year==86
sort firm year
by firm: replace year=85 if year==86 & year[_n+1]==86

compress year
sort firm year
order firm year
save "tfpest/varsothrs-`ext'`fdfl'", replace
