set seed 499131601962

version 7
set matsize 180
set logtype text
tempfile tmp usedata

set more off

/* Choose Settings */
/*-----------------*/

local strtgrp 1       /* Niv50 (group) to start with. Useful if interruption occured. 0: not set. */

local bsreps  = 200   /* Number of repetitions in bootstrap */
global maxiter= 250   /* Maximum number of iterations in nlls routine on step 3 */

local choice 3
/* Choice 3: FGV-IPA (and general)  Deflators 86-98 */
/*        4: FGV-DI (and general)   Deflators 86-98 */
/*        9: Apply IGP-OG to all variables */
if `choice'==3 { local ext "ipa" }
if `choice'==4 { local ext "di" }
if `choice'==9 { local ext "gen" }

local fdfl 2
/* Choice 0: Foreign inputs and investments deflated with domestic deflators */
/*        1: Foreign input and investment deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
if `fdfl'==0 { local fdfl="" }

global out 2
/* Choice 1: "valadd" */
/* Choice 2: "output" */
if $out==1 {local outtype "valadd"}
if $out==2 {local outtype "output"}

global trd 0
/* Choice 3: Klette & Grilliches 96 correction */
/* Choice 2: year dummies ON, trend variables OFF */
/* Choice 1: trend variables ON, time dummies OFF */
/* Choice 0: trend variables and year dummies OFF */
if $trd==3 {local trdtype "kletgri"}
if $trd==2 {local trdtype "dyears"}
if $trd==1 {local trdtype "trend"}
if $trd==0 {local trdtype "notrend"}

global fe 1
/* Choice 1: fixed effects in OP estimation ON  */
/* Choice 0: fixed effects in OP estimation OFF */
if $fe {local fetype "fe"}
else   {local fetype "nofe"}

global iniols 2
/* Choice 0: Set initial values to FE estimates  */
/* Choice 1: Set initial values to OLS estimates */
/* Choice 2: Set initial values to FE estimates and terms from linear regression */
/* Choice 3: Set initial values to following values */
if $iniols==3 {
    global inikap=.1
    global inik=.2
    global iniq=.2
    }

global polynl 3
/* Choice 2: Polynomial of 2nd order is used in Step 1 and 3 */
/* Choice 3: Polynomial of 3rd order is used in Step 3 */
/* Choice 4: Polynomial of 4th order is used in Step 3 */
/* Choice 5: Polynomial of 5th order is used in Step 3 */
/* Choice 6: Polynomial of 6th order is used in Step 3 */
local polynl=$polynl

global xeff 1
/* Choice 1: Approximate for X-efficiency choice by managers */
/* Choice 0: Approximate for X-efficiency choice by managers */
if "$posinv"=="-nomkt" { 
  global xeff 0
  }
if $xeff {local xeff="x"}

local  eps=1e-5     /* Convergence criterion in NLLS */


/* Load Estimate Matrices */
/*------------------------*/
tempname chk
foreach estmat in "1bet" "3bet" "1sdv" "3sdv" {
    if _N >0 {drop _all}
    capture local `chk' = colsof(stp`estmat')
    if _rc~=0 {matload stp`estmat', path("tfpest\estimate\estmat\mat-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'\")}
}


/* Macro Preparation */
/*-------------------*/

/* Prepare OP step 1 regression vars */
if $trd==3 {
    if $out==1 {global s1vars "lnvaladd lnlabfbl lnlabfwh kap1s1 lnk1s1 lnq1s1 ntkinv ntqinv lnage"}
    if $out==2 {global s1vars "lnout lnlabfbl lnlabfwh mu lnint kap1s1 lnk1s1 lnq1s1 ntk ntq lnage"}
    }
if $trd==2 {
    if $out==1 {global s1vars "lnval lnlabfbl lnlabfwh kap1s1 lnk1s1 lnq1s1 ntkinv ntqinv lnage dyr87-dyr98"}
    if $out==2 {global s1vars "lnout lnlabfbl lnlabfwh mu lnint kap1s lnk1s lnq1s ntk ntq lnage dyr87-dyr98"}
    }
if $trd==1 {
    if $out==1 {global s1vars "lnvaladd lnlabfbl lnlabfwh kap1s1 lnk1s1 lnq1s1 ntkinv ntqinv lnage trend*"}
    if $out==2 {global s1vars "lnout lnlabfbl lnlabfwh mu lnint kap1s1 lnk1s1 lnq1s1 ntk ntq lnage trend*"}
    }
if $trd==0 {
    if $out==1 {global s1vars "lnvaladd lnlabfbl lnlabfwh kap1s1 lnk1s1 lnq1s1 ntkinv ntqinv lnage"}
    if $out==2 {global s1vars "lnout lnlabfbl lnlabfwh mu lnintm kap1s1 lnk1s1 lnq1s1 ntkinv ntqinv lnage"}
    }
local bsvars "$s1vars"
local bsvars = subinword("`bsvars'","lnvaladd","",.)
local bsvars = subinword("`bsvars'","lnoutput","",.)
local bsvars = subinstr("`bsvars'","dyr87-dyr98","",.)
local bsvars = subinword("`bsvars'","dyr","",.)
local bsvars = subinword("`bsvars'","trend*","",.)
local bsvars = subinword("`bsvars'","tre","",.)
local bsvars = trim("`bsvars'")
if $trd==1 {local bsextra = " trend1 trend2 trend3"}
if $trd==2 {local bsextra = " dyr87 dyr88 dyr89 dyr90 dyr92 dyr93 dyr94 dyr95 dyr96 dyr97 dyr98"}
global bs1all "`bsvars'`bsextra'"
local rvars "$s1vars"
local rvars = subinword("`rvars'","ntkinv","",.)
local rvars = subinword("`rvars'","ntqinv","",.)
local rvars = subinword("`rvars'","lnage","",.)
local rvars = subinword("`rvars'","kletgril","",.)
global rvars = "`rvars'"

/* Prepare regression vars to be posted in bootstrap, step 1 */
/*
local i 1
while `i' <= 23 {
    global rpst`i' = ""
    local i = `i' + 1
    }
*/

/* Prepare OP NLS regression vars, step 3 */
if $trd==1 {
     /* Up to 2nd order polynomials. Also correct code below. */
     if $polynl==2 {global nlvars "bkappa bk bq b00 b01 b02 b10 b11 b12 b20 b21 b22 btrd1 btrd2 btrd3"}
     /* Up to 3rd order polynomials. Also correct code below. */
     if $polynl==3 {global nlvars "bkappa bk bq b00 b01 b02 b03 b10 b11 b12 b13 b20 b21 b22 b23 b30 b31 b32 b33 btrd1 btrd2 btrd3"}
     /* Up to 4th order polynomials. Also correct code below. */
     if $polynl==4 {global nlvars "bkappa bk bq b00 b01 b02 b03 b04 b10 b11 b12 b13 b14 b20 b21 b22 b23 b24 b30 b31 b32 b33 b34 b40 b41 b42 b43 b44 btrd1 btrd2 btrd3"}
     /* Up to 5th order polynomials. Also correct code below. */
     if $polynl==5 {global nlvars "bkappa bk bq b00 b01 b02 b03 b04 b05 b10 b11 b12 b13 b14 b15 b20 b21 b22 b23 b24 b25 b30 b31 b32 b33 b34 b35 b40 b41 b42 b43 b44 b45 b50 b51 b52 b53 b54 b55 btrd1 btrd2 btrd3"}
     /* Up to 6th order polynomials. Also correct code below. */
     if $polynl==6 {global nlvars "bkappa bk bq b00 b01 b02 b03 b04 b05 b06 b10 b11 b12 b13 b14 b15 b16 b20 b21 b22 b23 b24 b25 b26 b30 b31 b32 b33 b34 b35 b36 b40 b41 b42 b43 b44 b45 b46 b50 b51 b52 b53 b54 b55 b56 b60 b61 b62 b63 b64 b65 b66 btrd1 btrd2 btrd3"}
     }
else {
     /* Up to 2nd order polynomials. Also correct code below. */
     if $polynl==2 {global nlvars "bkappa bk bq b00 b01 b02 b10 b11 b12 b20 b21 b22"}
     /* Up to 3rd order polynomials. Also correct code below. */
     if $polynl==3 {global nlvars "bkappa bk bq b00 b01 b02 b03 b10 b11 b12 b13 b20 b21 b22 b23 b30 b31 b32 b33"}
     /* Up to 4th order polynomials. Also correct code below. */
     if $polynl==4 {global nlvars "bkappa bk bq b00 b01 b02 b03 b04 b10 b11 b12 b13 b14 b20 b21 b22 b23 b24 b30 b31 b32 b33 b34 b40 b41 b42 b43 b44"}
     /* Up to 5th order polynomials. Also correct code below. */
     if $polynl==5 {global nlvars "bkappa bk bq b00 b01 b02 b03 b04 b05 b10 b11 b12 b13 b14 b15 b20 b21 b22 b23 b24 b25 b30 b31 b32 b33 b34 b35 b40 b41 b42 b43 b44 b45 b50 b51 b52 b53 b54 b55"}
     /* Up to 6th order polynomials. Also correct code below. */
     if $polynl==6 {global nlvars "bkappa bk bq b00 b01 b02 b03 b04 b05 b06 b10 b11 b12 b13 b14 b15 b16 b20 b21 b22 b23 b24 b25 b26 b30 b31 b32 b33 b34 b35 b36 b40 b41 b42 b43 b44 b45 b46 b50 b51 b52 b53 b54 b55 b56 b60 b61 b62 b63 b64 b65 b66"}
     }


/* Load Data */
/*-----------*/

use "tfpest\use-tfp-`ext'`fdfl'-`outtype'-`trdtype'", clear
drop ols* wi* beta* bsd* bcov* obsnum*
gen betafe = .

if "$posinv"=="-posinv" { 
  drop if ntqinv<=0 | ntkinv<=0 
  keep if niv50==8 | niv50==14 | niv50==22 | niv50==26 | niv50==31
  }
if "$posinv"=="-nomkt" { 
  keep if niv50==8 | niv50==14 | niv50==22 | niv50==26 | niv50==31
  }

drop if niv50==.
if ~ $xeff {drop reffpen-realexch}
local yrmax=98
egen byte group=group(niv50)
sort group
local maxgrp=group[_N]
label var group "Group Number of Niv50"
/* Import policy and demand variables */
sort firm year
merge firm year using "tfpest/seclvl-`ext'`fdfl'", update
drop _merge
sort firm year
by firm year: keep if _n==1
/* Import competitor variables */
sort firm year
merge firm year using "tfpest/varsothrs-`ext'`fdfl'", update
tab _m
drop _merge
sort firm year
by firm year: keep if _n==1
/* Import externally estimated Step 2 probability predictions */
sort firm year
merge firm year using "tfpest\estimate\coeff-survvprob-`ext'`fdfl'", update
drop _merge
sort firm year
by firm year: keep if _n==1

/* logit based exit probabilities */
gen _prhat1=phatlogt
gen _prhat2=phatlogt^2
gen _prhat3=phatlogt^3
gen _prhat4=phatlogt^4
gen _prhat5=phatlogt^5
gen _prhat6=phatlogt^6

/* Duplicate variables that are used in step 1 and step 3 */
gen kap1s1 = kappa1
label var kap1s1 "kappa1 for step 1"
gen lnk1s1 = lnapk1
label var lnk1s1 "lnapk1 for step 1"
gen lnq1s1 = lnapq1
label var lnq1s1 "lnapq1 for step 1"
order firm year lnvaladd lnoutput kappa1 kap1s1 kappa0 lnapk1 lnk1s1 lnapk0 lnapq1 lnq1s1 lnapq0

sort firm year
qui compress
save `usedata'


/* Estimation by Niv50 */
/*---------------------*/

capture log close
local run = 0
local exit = 0
while ~`exit' {
    local run = `run' + 1
    capture confirm new file "tfpest\estimate\logs\olley-pakes$posinv-bstrp-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-run`run'.log"
    if _rc~=602 {local exit=1}
}

log using "tfpest\estimate\logs\olley-pakes$posinv-bstrp-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-run`run'.log" 

local grp 1
if `strtgrp'~=0 { local grp `strtgrp' }
while `grp' <= `maxgrp' {

global grp=`grp'
if $grp>1 { use `usedata', clear }
keep if group==$grp

quietly summ niv50 if group==$grp
local recniv = r(mean)
local obs = r(N)
if `recniv' < 10 {local nivdsp = "0`recniv'"}
    else         {local nivdsp = "`recniv'"}
disp
disp
disp "Bootstrap Niv50 == `nivdsp'"
disp "---------------------"
disp "(Observations: `obs')"
disp

local run = 0
local exit = 0
while ~`exit' {
    local run = `run' + 1
    capture confirm new file "tfpest\estimate\bstrp\niv`nivdsp'$posinv-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-run`run'.dta"
    if _rc~=602 {local exit=1}
}

/* Prepare dataset */
disp in blue "Bootstrapping, data preparation..."
if $xeff==1 {
    quietly poly2 L.kletgril L.reffpen L.tariff L.oth_lpprox L.oth_lnapk1
    foreach i in 01 02 03 04 05 06 07 08 09 10 11 12 13 14 15 {rename _p`i' _p9`i'}
    gen _p701 = ntkinv * L.kletgril
    gen _p702 = ntkinv * L.reffpen
    gen _p703 = ntkinv * L.tariff
    gen _p704 = ntkinv * L.oth_lpprox
    gen _p705 = ntkinv * L.oth_lnapk1
    gen _p706 = ntqinv * L.kletgril
    gen _p707 = ntqinv * L.reffpen
    gen _p708 = ntqinv * L.tariff
    gen _p709 = ntqinv * L.oth_lpprox
    gen _p710 = ntqinv * L.oth_lnapk1
    gen _p890 = L.kletgril
    gen _p891 = L.reffpen 
    gen _p892 = L.tariff
    gen _p893 = L.oth_lpprox 
    gen _p894 = L.oth_lnapk1
    }
quietly poly2 ntkinv ntqinv lnage lnapk1 lnapq1
quietly poly3 ntkinv ntqinv lnage lnapk1 lnapq1
quietly poly4 ntkinv ntqinv lnage lnapk1 lnapq1

/* OP Steps 1 and 3 */
/*------------------*/

disp in blue "Bootstrapping (" in yellow "`bsreps'" in green " total repetitions), estimation steps 1 and 3..."
bstrap bsop13, reps(`bsreps') saving("tfpest\estimate\bstrp\niv`nivdsp'$posinv-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-run`run'") every(10) dots
disp "Saved as:" in  yellow "  tfpest\estimate\bstrp\niv`nivdsp'$posinv-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-run`run'.dta"

local grp =`grp'+1
}

log close
