version 7.0
set matsize 180
set logtype text
capture log close


/* Choose Settings */
/*-----------------*/

local choice 3
/* Choice 3: FGV-IPA (and general)  Deflators 86-98 */
/*        4: FGV-DI (and general)   Deflators 86-98 */
/*        9: Apply IGP-OG to all variables */
if `choice'==3 {local ext "ipa"}
if `choice'==4 {local ext "di"}
if `choice'==9 {local ext "gen"}

local fdfl 2
/* Choice 0: Foreign inputs and investments deflated with domestic deflators */
/*        1: Foreign input and investment deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
if `fdfl'==0 { local fdfl="" }

global out 2
/* Choice 1: "valadd" */
/* Choice 2: "output" */
if $out==1 {local outtype "valadd"}
if $out==2 {local outtype "output"}

global trd 0
/* Choice 3: Klette & Grilliches 96 correction */
/* Choice 2: year dummies ON, trend variables OFF */
/* Choice 1: trend variables ON, time dummies OFF  */
/* Choice 0: trend variables and year dummies OFF */
if $trd==3 {local trdtype "kletgri"}
if $trd==2 {local trdtype "dyears"}
if $trd==1 {local trdtype "trend"}
if $trd==0 {local trdtype "notrend"}

global fe 1
/* Choice 1: fixed effects in OP estimation ON  */
/* Choice 0: fixed effects in OP estimation OFF */
if $fe {local fetype "fe"}
else   {local fetype "nofe"}

global iniols 2
/* Choice 0: Set initial values to FE estimates  */
/* Choice 1: Set initial values to OLS estimates */
/* Choice 2: Set initial values to FE estimates and terms from linear regression */
/* Choice 3: Set initial values to following values */
if $iniols==3 {
    global inikap=.1
    global inik=.2
    global iniq=.2
    }

global polynl 3
/* Choice 2: Polynomial of 2nd order is used in Step 3 */
/* Choice 3: Polynomial of 3rd order is used in Step 3 */
/* Choice 4: Polynomial of 4th order is used in Step 3 */
/* Choice 5: Polynomial of 5th order is used in Step 3 */
/* Choice 6: Polynomial of 6th order is used in Step 3 */
local polynl=$polynl

global xeff 1
/* Choice 1: Approximate for X-efficiency choice by managers */
/* Choice 0: Approximate for X-efficiency choice by managers */
if "$posinv"=="-nomkt" { 
  global xeff 0
  }
if $xeff {local xeff="x"}

global maxiter=250  /* Maximum number of iterations in mle routines */
local  eps=1e-5     /* Convergence criterion in NLLS */

confirm new file "tfpest/estimate/logs/olley-pakes$posinv-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'.log"
confirm new file "tfpest/estimate/coeff$posinv-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'.dta"
capture mkdir "tfpest/estimate/estmat/mat$posinv-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'/"

use "tfpest/use-tfp-`ext'`fdfl'-`outtype'-`trdtype'", clear

if "$posinv"=="-posinv" { 
  drop if ntqinv<=0 | ntkinv<=0 
  keep if niv50==8 | niv50==14 | niv50==22 | niv50==26 | niv50==31
  }
if "$posinv"=="-nomkt" { 
  keep if niv50==8 | niv50==14 | niv50==22 | niv50==26 | niv50==31
  }

drop if niv50==.
if ~ $xeff {drop reffpen-realexch}
local yrmax=98
egen byte group=group(niv50)
sort group
local maxgrp=group[_N]
label var group "Group Number of Niv50"


/* Estimation by Niv50 */
/*---------------------*/

/* Import policy and demand variables */
sort firm year
merge firm year using "tfpest/seclvl-`ext'`fdfl'", update
drop _merge
sort firm year
by firm year: keep if _n==1
/* Import competitor variables */
sort firm year
merge firm year using "tfpest/varsothrs-`ext'`fdfl'", update
tab _m
drop _merge
sort firm year
by firm year: keep if _n==1
/* Import externally estimated Step 2 probability predictions */
sort firm year
merge firm year using "tfpest/estimate/coeff-survvprob-`ext'`fdfl'", update
drop _merge
sort firm year
by firm year: keep if _n==1

capture matrix drop stp1bet
capture matrix drop stp1sdv
capture matrix drop stp3bet
capture matrix drop stp3sdv

capture log close
log using "tfpest/estimate/logs/olley-pakes$posinv-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'.log"

preserve

local grp 1
while `grp' <= `maxgrp' {

quietly summ niv50 if group==`grp'
local recniv = r(mean)
local obs = r(N)
if `recniv' < 10 {local nivdsp = "0`recniv'"}
    else         {local nivdsp = "`recniv'"}
disp
disp
disp "Niv50 == `nivdsp'"
disp "-----------"
disp "(Observations: `obs')"
disp

keep if group==`grp'  /* This line can be removed but makes program faster */


/* OLS Regressions */
/*-----------------*/
if $trd==3 {
    if $out==1 {local rvars "lnvaladd kappa1 lnapk1 lnapq1 lnlabfbl lnlabfwh kletgril"
                local tstvars "lnapk1 + lnapq1 + lnlabfbl + lnlabfwh = 1"}
    if $out==2 {local rvars "lnoutput kappa1 lnapk1 lnapq1 lnlabfbl lnlabfwh mu lnintmed kletgri"
                local tstvars "lnapk1 + lnapq1 + lnlabfbl + lnlabfwh + lnintmed = 1"}
}
if $trd==2 {
    if $out==1 {local rvars "lnvaladd kappa1 lnapk1 lnapq1 lnlabfbl lnlabfwh dyr87-dyr98"
                local tstvars "lnapk1 + lnapq1 + lnlabfbl + lnlabfwh = 1"}
    if $out==2 {local rvars "lnoutput kappa1 lnapk1 lnapq1 lnlabfbl lnlabfwh mu lnintmed dyr87-dyr98"
                local tstvars "lnapk1 + lnapq1 + lnlabfbl + lnlabfwh + lnintmed = 1"}
}
if $trd==1 {
    if $out==1 {local rvars "lnvaladd kappa1 lnapk1 lnapq1 lnlabfbl lnlabfwh trend*"
                local tstvars "lnapk1 + lnapq1 + lnlabfbl + lnlabfwh = 1"}
    if $out==2 {local rvars "lnoutput kappa1 lnapk1 lnapq1 lnlabfbl lnlabfwh mu lnintmed trend*"
                local tstvars "lnapk1 + lnapq1 + lnlabfbl + lnlabfwh + lnintmed = 1"}
}
if $trd==0 {
    if $out==1 {local rvars "lnvaladd kappa1 lnapk1 lnapq1 lnlabfbl lnlabfwh"
                local tstvars "lnapk1 + lnapq1 + lnlabfbl + lnlabfwh = 1"}
    if $out==2 {local rvars "lnoutput kappa1 lnapk1 lnapq1 lnlabfbl lnlabfwh mu lnintmed"
                local tstvars "lnapk1 + lnapq1 + lnlabfbl + lnlabfwh + lnintmed = 1"}
}
excreg1 "`rvars'" "group==`grp'" "`tstvars'"



/* Olley-Pakes Regressions */
/*-------------------------*/

/* OP Step 2: estimates (probability of survival) already imported above */

/* OP Steps 1 and 3 */
/*------------------*/

    /* OP Step 1. Phi: Contribution of capital to value added or output */
    if $xeff==1 {
        quietly poly2 L.kletgril L.reffpen L.tariff L.oth_lpprox L.oth_lnapk1
        foreach i in 01 02 03 04 05 06 07 08 09 10 11 12 13 14 15 {rename _p`i' _p9`i'}
        gen _p701 = ntkinv * L.kletgril
        gen _p702 = ntkinv * L.reffpen
        gen _p703 = ntkinv * L.tariff
        gen _p704 = ntkinv * L.oth_lpprox
        gen _p705 = ntkinv * L.oth_lnapk1
        gen _p706 = ntqinv * L.kletgril
        gen _p707 = ntqinv * L.reffpen
        gen _p708 = ntqinv * L.tariff
        gen _p709 = ntqinv * L.oth_lpprox
        gen _p710 = ntqinv * L.oth_lnapk1
        gen _p890 = L.kletgril
        gen _p891 = L.reffpen 
        gen _p892 = L.tariff
        gen _p893 = L.oth_lpprox 
        gen _p894 = L.oth_lnapk1
        }
    quietly poly2 ntkinv ntqinv lnage lnapk1 lnapq1
    quietly poly3 ntkinv ntqinv lnage lnapk1 lnapq1
    quietly poly4 ntkinv ntqinv lnage lnapk1 lnapq1
    if $trd==3 {
        if $out==1 {local rvars "lnvaladd lnlabfbl lnlabfwh kappa1 lnapk1 lnapq1 ntkinv ntqinv lnage kletgril _p*"}
        if $out==2 {local rvars "lnoutput lnlabfbl lnlabfwh mu lnintm kappa1 lnapk1 lnapq1 ntkinv ntqinv lnage kletgril _p*"}
        }
    if $trd==2 {
        if $out==1 {local rvars "lnvaladd lnlabfbl lnlabfwh kappa1 lnapk1 lnapq1 ntkinv ntqinv lnage dyr87-dyr98 _p*"}
        if $out==2 {local rvars "lnoutput lnlabfbl lnlabfwh mu lnintm kappa1 lnapk1 lnapq1 ntkinv ntqinv lnage dyr87-dyr98 _p*"}
        }
    if $trd==1 {
        if $out==1 {local rvars "lnvaladd lnlabfbl lnlabfwh kappa1 lnapk1 lnapq1 ntkinv ntqinv lnage trend* _p*"}
        if $out==2 {local rvars "lnoutput lnlabfbl lnlabfwh mu lnintm kappa1 lnapk1 lnapq1 ntkinv ntqinv lnage trend* _p*"}
        }
    if $trd==0 {
        if $out==1 {local rvars "lnvaladd lnlabfbl lnlabfwh kappa1 lnapk1 lnapq1 ntkinv ntqinv lnage _p*"}
        if $out==2 {local rvars "lnoutput lnlabfbl lnlabfwh mu lnintm kappa1 lnapk1 lnapq1 ntkinv ntqinv lnage _p*"}
        }
    if $fe==1 {ollpak1x "`rvars'" "group==`grp'"}
    else      {ollpak1 "`rvars'" "group==`grp'"}
    matrix beta=e(b)
    matrix var=e(V)
    if `grp'==1 { est2vec vecstp1, v(lnlabfbl lnlabfwh mu lnintm kappa1 lnapk1 lnapq1 ntkinv ntqinv lnage _p701 _p702 _p703 _p704 _p705 _p706 _p707 _p708 _p709 _p710 _p890 _p891 _p892 _p893 _p894) e(N r2 F) replace name(niv`nivdsp') }
    else        { est2vec _tmp, addto(vecstp1) nokeep replace name(niv`nivdsp') }
    outstp1 `grp' `nivdsp'
    if $out==1 {replace phihat1 = lnvaladd - _b[lnlabfbl]*lnlabfbl - _b[lnlabfwh]*lnlabfwh if group==`grp'}
    if $out==2 {global betaintm = _b[lnintm]
                local dof=e(df_r)
                replace phihat1 = lnoutput - _b[lnlabfbl]*lnlabfbl - _b[lnlabfwh]*lnlabfwh - _b[lnintm]*lnintmed if group==`grp'
                if ttail(`dof',abs(_b[mu]/_se[mu]))*2 <= .05 {replace phihat1 = phihat1 - beta[1,3]*mu if group==`grp'}
                }
    if $fe==1  {replace phihat1 = phihat1 - betafe if group==`grp'}
    matrix drop beta var
    sort firm year
    quietly by firm: replace phihat0=phihat1[_n-1] if year~=92 & group==`grp'
    egen _dummy=mean(phihat1) if year>=89 & year<=92 & group==`grp', by(firm)
    replace phihat0=_dummy if year==92 & group==`grp'
    drop _dum* _p*
      
    /* OP Step 3. Production Function */
    gen _lefths = phihat1 if group==`grp'
    foreach i in 0 1 2 3 4 5 6 7 {gen _dpart`i'=0}
    /* logit based exit probabilities */
    gen _prhat1=phatlogt
    gen _prhat2=phatlogt^2
    gen _prhat3=phatlogt^3
    gen _prhat4=phatlogt^4
    gen _prhat5=phatlogt^5
    gen _prhat6=phatlogt^6
    if e(N)~=. {  /* First stage must have worked */
        if $trd==1 {nl step3 _lefths kappa1 kappa0 lnapk1 lnapk0 lnapq1 lnapq0 phihat0 _prhat1 _prhat2 _prhat3 _prhat4 _prhat5 _prhat6 trend1 trend2 trend3 if group==`grp', iterate($maxiter) eps(`eps')}
        else       {nl step3 _lefths kappa1 kappa0 lnapk1 lnapk0 lnapq1 lnapq0 phihat0 _prhat1 _prhat2 _prhat3 _prhat4 _prhat5 _prhat6 if group==`grp', iterate($maxiter) eps(`eps')}
        if `grp'==1 { est2vec vecstp3, e(N r2 F) replace name(niv`nivdsp') }
        else        { est2vec _tmp, addto(vecstp3) nokeep replace name(niv`nivdsp') }
        outstp3 `grp' `nivdsp'
        }
    drop _*

corr indsurvv phat* if group==`grp'

sort firm year
save tmp`grp', replace
restore, preserve
local grp =`grp'+1
}

log off
if `choice'==3 {local ext "ipa"}
if `choice'==4 {local ext "di"}
if `choice'==9 {local ext "gen"}
use tmp1, clear
local grp 2
while `grp' <= `maxgrp' {
    append using tmp`grp'
    local grp = `grp' +1    
    }
if $trd==3 {
    keep  firm year lnvaladd lnoutput kappa* lnapk* lnapq* lnlabfbl lnlabfwh mu lnintmed kletgril niv50 ols* wi* beta* bsdv* bcov* bklegri obsnum phi* phat* indsurvv
    order firm year lnvaladd lnoutput kappa* lnapk* lnapq* lnlabfbl lnlabfwh mu lnintmed kletgril niv50 ols* wi* beta* bsdv* bcov* bklegri obsnum phi* phat* indsurvv
    }
if $trd==2 {
    keep  firm year lnvaladd lnoutput kappa* lnapk* lnapq* lnlabfbl lnlabfwh mu lnintmed niv50 ols* wi* beta* bsdv* bcov* byr* obsnum phi* phat* indsurvv
    order firm year lnvaladd lnoutput kappa* lnapk* lnapq* lnlabfbl lnlabfwh mu lnintmed niv50 ols* wi* beta* bsdv* bcov* byr* obsnum phi* phat* indsurvv
    }
if $trd==1 {
    keep  firm year lnvaladd lnoutput kappa* lnapk* lnapq* lnlabfbl lnlabfwh mu lnintmed niv50 ols* wi* beta* bsdv* bcov* btrd* obsnum phi* phat* indsurvv
    order firm year lnvaladd lnoutput kappa* lnapk* lnapq* lnlabfbl lnlabfwh mu lnintmed niv50 ols* wi* beta* bsdv* bcov* btrd* obsnum phi* phat* indsurvv
    }
if $trd==0 {
    keep  firm year lnvaladd lnoutput kappa* lnapk* lnapq* lnlabfbl lnlabfwh mu lnintmed niv50 ols* wi* beta* bsdv* bcov* obsnum phi* phat* indsurvv
    order firm year lnvaladd lnoutput kappa* lnapk* lnapq* lnlabfbl lnlabfwh mu lnintmed niv50 ols* wi* beta* bsdv* bcov* obsnum phi* phat* indsurvv
    }
sort firm year
save "tfpest/estimate/coeff$posinv-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'", replace

log on
disp
disp
disp "Overall correlation between Logit and Probit"
disp
corr indsurvv phat*
log close

foreach estmat in "1bet" "3bet" "1sdv" "3sdv" {
    drop _all
    matsave stp`estmat', replace path("tfpest/estimate/estmat/mat$posinv-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'/")
}
foreach type in b se e {
    drop _all
    matsave vecstp1_`type', replace path("tfpest/estimate/estmat/mat$posinv-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'/")
    drop _all
    matsave vecstp3_`type', replace path("tfpest/estimate/estmat/mat$posinv-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'/")
}
restore

* STOP
disp "The program will now proceed to erase temporary files. Press ---break--- button to cancel."
more
local grp 1
while `grp' <= `maxgrp' {
    erase tmp`grp'.dta
    local grp = `grp' +1    
    }
