version 7
set matsize 180
set more off

gprefs set window scheme monochrome
gprefs set window displaythick off
translator set gph2eps scheme monochrome

/* Choose Settings */
/*-----------------*/

local choice 3
/* Choice 3: FGV-IPA (and general) Deflators 86-98 */
/*        4: FGV-DI (and general)  Deflators 86-98 */
/*        9: Apply IGP-OG to all variables */
if `choice'==3 {local ext "ipa"}
if `choice'==4 {local ext "di"}
if `choice'==9 {local ext "gen"}

local fdfl 2
/* Choice 0: Foreign inputs and investments deflated with domestic deflators */
/*        1: Foreign input and investment deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
if `fdfl'==0 { local fdfl="" }

global out 2
/* Choice 1: "valadd" */
/* Choice 2: "output" */
if $out==1 {local outtype "valadd"}
if $out==2 {local outtype "output"}


/* Load bootstrap data */

foreach niv in 08 14 22 26 31 { 
    local run = 1
    use "tfpest/estimate/bstrp/niv`niv'-`ext'`fdfl'-`outtype'-run`run'", clear
    local exit = 0
    while ~`exit' {
        local run = `run' + 1
        capture confirm file "tfpest/estimate/bstrp/niv`niv'-`ext'`fdfl'-`outtype'-run`run'.dta"
        if _rc==601 {local exit=1}
        else        {append using "tfpest/estimate/bstrp/niv`niv'-`ext'`fdfl'-`outtype'-run`run'"}
    }
    drop eopmpen

    foreach pair in "eop ols" "eop lp" "lp ols" {
    tokenize `pair'
        foreach est in lbl lwh m k {
            gen dif_`1'`2'_`est' = `1'`est' - `2'`est'
            }
        local lbl1 = upper("`1'")
        local lbl2 = upper("`2'")
        label var dif_`1'`2'_lbl "`lbl1'-`lbl2': Blue-collar labor"
        label var dif_`1'`2'_lwh "`lbl1'-`lbl2': White-collar labor"
        label var dif_`1'`2'_m   "`lbl1'-`lbl2': Intermediate goods"
        label var dif_`1'`2'_k   "`lbl1'-`lbl2': Capital"
        foreach est in lbl lwh m k {
            qui summ dif_`1'`2'_`est'
            * local maxdev = int((max(abs(`r(min)'),abs(`r(max)'))+.15)*10)/10
            * if `maxdev' <=.5 { local stp = .05 }
            * if `maxdev' >.5 & `maxdev' <=1 { local stp = .1 }
            * if `maxdev' >1 & `maxdev' <=2 { local stp = .2 }
            * if `maxdev' >2 & `maxdev' <=5 { local stp = .5 }
            local maxdev .5
            if "`est'"=="k" | "`est'"=="m" { local maxdev .7 }
            local stp .1
            graph dif_`1'`2'_`est', histogram bin(12) ylab(0(.1)1) xlab(0,-`maxdev'(`stp')`maxdev') xline(0) saving("c:/texdocs/tfpest/fig/graphs/hist-niv`niv'-dif_`1'`2'_`est'", replace)
            translate "c:/texdocs/tfpest/fig/graphs/hist-niv`niv'-dif_`1'`2'_`est'.gph" "c:/texdocs/tfpest/fig/graphs/hist-niv`niv'-dif_`1'`2'_`est'.eps", translator(gph2eps) replace
            more
        }
    }
}

set more off
