version 7
set matsize 180
clear
tempfile wages labtcrat

adopath + "tfpest/%stata/ado"
local niv50lst "niv08 niv14 niv22 niv26 niv31"
local niv50no "8 14 22 26 31"

* Note: Code uses point estimates from 0-draw in bootstrap

* Load variable names and save for est2tex
est2extlbl, addto(eoplong) intex(tfpest/%stata/rowlbl-tfpest) p(c:/texdocs/tfpest/stata-origs) replace
est2extlbl, addto(eopfeols) retain p(c:/texdocs/tfpest/stata-origs) replace
est2extlbl, addto(estcomplg) retain p(c:/texdocs/tfpest/stata-origs) replace
est2extlbl, addto(estcompsh) retain p(c:/texdocs/tfpest/stata-origs) replace
est2extlbl, addto(eopproc) retain p(c:/texdocs/tfpest/stata-origs) replace
est2extlbl, addto(eopetal) retain p(c:/texdocs/tfpest/stata-origs) replace
clear


/* Choose Settings */
/*-----------------*/

local choice 3
/* Choice 3: FGV-IPA (and general) Deflators 86-98 */
/*        4: FGV-DI (and general)  Deflators 86-98 */
/*        9: Apply IGP-OG to all variables */
if `choice'==3 {
    local ext "ipa"
    }
if `choice'==4 {
    local ext "di"
    }
if `choice'==9 {
    local ext "gen"
    }

local fdfl 2
/* Choice 0: Foreign inputs and investments deflated with domestic deflators */
/*        1: Foreign input and investment deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
if `fdfl'==0 {
    local fdfl=""
    }

global out 2
/* Choice 1: "valadd" */
/* Choice 2: "output" */
if $out==1 {
    local outtype "valadd"
    }
if $out==2 {
    local outtype "output"
    }

global trd 0
/* Choice 3: Klette & Griliches 96 correction */
/* Choice 2: year dummies ON, trend variables OFF */
/* Choice 1: trend variables ON, time dummies OFF  */
/* Choice 0: trend variables and year dummies OFF */
if $trd==3 {
    local trdtype "kletgri"
    }
if $trd==2 {
    local trdtype "dyears"
    }
if $trd==1 {
    local trdtype "trend"
    }
if $trd==0 {
    local trdtype "notrend"
    }

global fe 2
/* Choice 2: fixed effects in OP estimation ON, AND KletGri96 inspired correction */
/* Choice 1: fixed effects in OP estimation ON  */
/* Choice 0: fixed effects in OP estimation OFF */
if $fe==2 & "`esttype'"~="op" {
    global fe 1
    }
if $fe~=0 {
    local fetype "fe"
    }
else      {
    local fetype "nofe"
    }
if $fe==2 {
    local feout="fecorr"
    }
else      {
    local feout="`fetype'"
    }

global polynl 3
/* Choice 2: Polynomial of 2nd order is used in Step 3 */
/* Choice 3: Polynomial of 3rd order is used in Step 3 */
/* Choice 4: Polynomial of 4th order is used in Step 3 */
/* Choice 5: Polynomial of 5th order is used in Step 3 */
/* Choice 6: Polynomial of 6th order is used in Step 3 */
local polynl=$polynl

global xeff 1
/* Choice 1: Approximate for X-efficiency choice by managers */
/* Choice 0: Approximate for X-efficiency choice by managers */
if $xeff {
    local xeff="x"
    }


/* Load long estimate matrices from tfpest */

foreach type in e {
  foreach stp in 1 3 {
    drop _all
    matload vecstp`stp'_`type', path(tfpest/estimate/estmat/mat-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff') over
  }
  matrix vecstp_`type' = vecstp1_`type' \ vecstp3_`type'
}


/* Load short estimate matrices and bootstraps from tfpest */

foreach type in b se1 se2 e {
    drop _all
    matload pfct${trd}${fe}${polynl}_`type', path(tfpest/estimate/estmat/pfct) over
}
foreach type in b se1 se2 {
    matorder pfct013_`type', matrix(eopc_`type') ifcol(`niv50lst') over
    matorder eopc_`type', matrix(eopc_`type') ifrow(lnlabfbl lnlabfwh mu lnintmed lnlabfsm bkappa bk  bq  bcapsm) over
    matrix rownames eopc_`type' =                   lnlabfbl lnlabfwh mu lnintm   lnlabfsm kappa  lnk lnq lncapsm
    matorder pfct013_`type', matrix(olsc_`type') ifcol(`niv50lst') over
    matorder olsc_`type', matrix(olsc_`type') ifrow(olslabfbl olslabfwh olsmu olsintmed olslabfsm olskappa olslnk olslnq olscapsm) over
    matorder pfct013_`type', matrix(fec_`type') ifcol(`niv50lst') over
    matorder fec_`type', matrix(fec_`type') ifrow(wilabfbl wilabfwh wimu wiintmed wilabfsm wikappa wilnk wilnq wicapsm) over
    }
local type "e"
    matorder pfct013_`type', matrix(eopc_`type') ifcol(`niv50lst') over
    matorder eopc_`type', matrix(eopc_`type') ifrow(e(N)_op) over
    matrix rownames eopc_`type' =                   e(N)_op
    matorder pfct013_`type', matrix(olsc_`type') ifcol(`niv50lst') over
    matorder olsc_`type', matrix(olsc_`type') ifrow(e(N)_ols) over
    matorder pfct013_`type', matrix(fec_`type') ifcol(`niv50lst') over
    matorder fec_`type', matrix(fec_`type') ifrow(e(N)_ols) over


/* Load long estimate bootstrap files and output long estimate tables */

local estlist "kappa lnk lnq mu lnintm lnlabfwh lnlabfbl ntkinv ntqinv lnage klegri reffpen tariff olp olnk kklegri kreffp ktarif kxolp ntkxok qklegri qreffp qtarif qxolp ntqxok"
local estmax : word count `estlist'
local nivimax : word count `niv50lst'
tokenize "`niv50lst'"
foreach type in b se {
    matrix eoplong_`type'  = J(`estmax',`nivimax',-999)
    matrix rownames eoplong_`type' = `estlist'
    }
matrix eoplong_e  = J(1,`nivimax',-999)
matrix rownames eoplong_e = r(reps)
foreach type in b se e {
    matrix colnames eoplong_`type' = `niv50lst'
    }
forvalues nivi = 1/`nivimax' { 
    local niv = substr("``nivi''",4,2)
    local run = 1
    use "tfpest/estimate/bstrp/niv`niv'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-run`run'", clear
    local exit = 0
    while ~`exit' {
        local run = `run' + 1
        capture confirm file "tfpest/estimate/bstrp/niv`niv'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-run`run'.dta"
        if _rc==601 {
            local exit=1
            }
        else {
            append using "tfpest/estimate/bstrp/niv`niv'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-run`run'"
            }
    }
    local chk 0
    local rowi 0
    foreach est of local estlist {
        local rowi = `rowi' + 1
        qui bstat `est'
        matrix eoplong_b[`rowi',`nivi'] = eopc_b[rownumb(eopc_b,"`est'"),`nivi'] 
        if eoplong_b[`rowi',`nivi']==. {
          matrix eoplong_b[`rowi',`nivi'] = r(stat)
          }
        if int(eoplong_b[`rowi',`nivi']*1000)~=int(r(stat)*1000) {  /* Check for consistency of eopc_`type' with r(stat), ignore rounding errors */
          local chk = `chk' + 1
          }
        matrix eoplong_se[`rowi',`nivi'] = r(se)
    }
    matrix eoplong_e[1,`nivi'] = r(reps)
    local tot `rowi'*`nivi'
}

foreach type in b se {
  matorder eoplong_`type', matrix(eoplong_`type') over ifrow(lnlabfbl lnlabfwh lnk lnq lnintm ntkinv ntqinv klegri reffpen tariff olp olnk kklegri kreffp ktarif kxolp ntkxok qklegri qreffp qtarif qxolp ntqxok kappa mu lnage)
  }
matrix eoplong_e = eoplong_e[1,1..`nivimax'] \ vecstp1_e[1,1..`nivimax'] 
matrix eoplong_e = eoplong_e[1..2,1..`nivimax'] \ vecstp3_e[1,1..`nivimax']
matrix eoplong_e = eoplong_e[1..3,1..`nivimax'] \ eopc_e[1,1..`nivimax']
matrix colnames eoplong_e = `niv50lst'
disp in red "Differing bootstrap point estimates from general-routine point estimates (at third digit) in " in yellow `chk' in red "/" in yellow `tot' in red " cases."
drop _all
est2tex eoplong, replace p(c:/texdocs/tfpest/stata-origs) fancy mark(it)


/* Output short comparison tables */

local enams : rownames pfct013_e
tokenize `enams'
local i 0
foreach esttype in eopc olsc fec {
    local i = `i' + 1
    matorder pfct013_e, matrix(`esttype'_e) ifcol(`niv50lst') over
    mat `esttype'_e = `esttype'_e[`i',1..`nivimax']
    matrix `esttype'_b = `esttype'_b \ `esttype'_e
    matrix drop `esttype'_e
    foreach type in se1 se2 {
        matrix `esttype'_`type' = `esttype'_`type' \ J(1,colsof(`esttype'_`type'),-999)
        }
    foreach type in b se1 se2 {
        matname `esttype'_`type' "``i''", rows(10) explicit
        }
    }
foreach type in b se1 se2 {
    matorder eopc_`type', matrix(eopc_`type') over ifrow(lnlabfbl lnlabfwh lnk lnq lnintm lnlabfsm lncapsm kappa mu e(N)_op)
    matorder fec_`type' , matrix(fec_`type')  over ifrow(wilabfbl wilabfwh wilnk wilnq wiintmed wilabfsm wicapsm wikappa wimu e(N)_wi)
    matorder olsc_`type', matrix(olsc_`type') over ifrow(olslabfbl olslabfwh olslnk olslnq olsintmed olslabfsm olscapsm olskappa olsmu e(N)_ols)
    }

local niv50lst : colfullnames eopc_b
tokenize "`niv50lst'"
local nivimax : word count `niv50lst'
foreach esttype in eopc olsc fec { 
  foreach type in b se1 se2 {
    local rowmax = rowsof(`esttype'_b)
    matrix list`esttype'_`type' = `esttype'_`type'[1..`rowmax',1]
    forvalues nivi = 2/`nivimax' { 
        matrix list`esttype'_`type' = list`esttype'_`type' \ `esttype'_`type'[1..`rowmax',`nivi']
        }
    local stp = 0
    forvalues nivi = 1/`nivimax' { 
        forvalues row = 1/`rowmax' {
            local rowid = `row' + `stp'
            matname list`esttype'_`type' "``nivi'':", rows(`rowid') explicit
            }
        local stp = `stp' + `rowmax'
        }
    matrix colnames list`esttype'_`type' = `esttype'_`type'
    }
  }

matrix listeopc_se = listeopc_se2
matrix listolsc_se = listolsc_se1
matrix listfec_se  = listfec_se1

matrix eopfeols_tbl = listeopc_b , listeopc_se , listfec_b , listfec_se , listolsc_b , listolsc_se

preserve
drop _all
est2tex eopfeols, ready replace p(c:/texdocs/tfpest/stata-origs) fancy extracols(2 4)
restore


/* Compare coefficient estimates to factor shares in output */

local niv50lst : colfullnames eopc_b
local colmax : word count `niv50lst'
local coldim = 2*`colmax'
matrix estcomplg = J(5,`coldim',-999)
matrix estcompsh = J(4,`coldim',-999)
tokenize `niv50lst'
forvalues i = 1/5 {
  local rep = 0
  foreach comptype in eop costsh {
    local rep = `rep' + 1
    local colid = (`i'-1)*2 + `rep'
    matname estcomplg "``i''_`comptype'", columns(`colid') explicit
    matname estcompsh "``i''_`comptype'", columns(`colid') explicit
    }
  }
forvalues i = 1/5 {
    local colid = (`i'-1)*2 + 1
    local coefsum = eopc_b[1,`i'] + eopc_b[2,`i'] + eopc_b[4,`i'] + eopc_b[9,`i']
    matrix estcomplg[1,`colid'] = eopc_b[1,`i']/`coefsum'
    matrix estcomplg[2,`colid'] = eopc_b[2,`i']/`coefsum'
    matrix estcomplg[3,`colid'] = eopc_b[4,`i']/`coefsum'
    matrix estcomplg[4,`colid'] = eopc_b[9,`i']/`coefsum'
    matrix estcomplg[5,`colid'] = `coefsum'
    local coefsum = eopc_b[5,`i'] + eopc_b[4,`i'] + eopc_b[9,`i']
    matrix estcompsh[1,`colid'] = eopc_b[5,`i']/`coefsum'
    matrix estcompsh[2,`colid'] = eopc_b[4,`i']/`coefsum'
    matrix estcompsh[3,`colid'] = eopc_b[9,`i']/`coefsum'
    matrix estcompsh[4,`colid'] = `coefsum'
}
matrix rownames estcomplg = labfbl labfwh intm capsm scale
matrix rownames estcompsh = labfsm intm capsm scale

use "brazprod/use-compl-`ext'`fdfl'", clear
keep firm year wagebl wagewh
sort firm year
save `wages'
use "brazprod/data/pia-ratios", clear
keep firm year deprcrat finexrat labtcrat prfslrat 
* keep firm year deprcrat finexrat labtcrat
replace prfslrat=0 if prfslrat==.
keep if deprcrat~=. & finexrat~=. & labtcrat~=.
egen _tot = rsum(deprcrat finexrat prfslrat labtcrat)
* egen _tot = rsum(deprcrat finexrat labtcrat)
gen captcrat = (deprcrat + finexrat + prfslrat)/_tot
* gen captcrat = (deprcrat + finexrat)/_tot
replace labtcrat = labtcrat/_tot
keep firm year captcrat labtcrat
sort firm year
save `labtcrat'
use "tfpest/use-tfp-`ext'`fdfl'-`outtype'-`trdtype'", clear
keep firm year niv50 lnoutput lnvaladd lnintmed
foreach var in output valadd intmed {
    gen `var' = exp(ln`var')
    drop ln`var'
    }
label var output "Output"
label var valadd "Value added"
label var intmed "Intermediate Input"
sort firm year
merge firm year using `wages', nokeep
count if _m~=3 
if `r(N)' > 0 { 
    STOP 
    }
drop _m
sort firm year
merge firm year using `labtcrat', nokeep
count if _m==2
if `r(N)' > 0 {
    STOP
    }
drop _m
keep if output~=. & intmed~=. & wagebl~=. & wagebl~=.
collapse (sum) output valadd intmed wagebl wagewh (mean) labtcrat captcrat [aw=output], by(niv50)
order niv50 output valadd intmed wagebl wagewh labtcrat captcrat
rename niv50 _rowname
save expend, replace
drop _all
matload expend, over
erase expend.dta
matrix expend = expend '
local rowmax = rowsof(expend)
local colmax = colsof(expend)
matorder expend, matrix(expenduse) ifcol(`niv50no') over
forvalues i = 1/5 {
    local colid = (`i'-1)*2 + 2
    local coefsum = expenduse[1,`i']
    matrix estcomplg[1,`colid'] = expenduse[4,`i']/`coefsum' /* wagebl */
    matrix estcomplg[2,`colid'] = expenduse[5,`i']/`coefsum' /* wagewh */
    matrix estcomplg[3,`colid'] = expenduse[3,`i']/`coefsum' /* intmed */
    matrix estcomplg[4,`colid'] = -999                       /* xxx    */
    local coefsum = expenduse[1,`i']
    matrix estcompsh[2,`colid'] = expenduse[3,`i']/`coefsum' /* intmed */
    matrix estcompsh[1,`colid'] = expenduse[6,`i'] * (1 - expenduse[3,`i']/`coefsum') /* labtcrat */
    matrix estcompsh[3,`colid'] = expenduse[7,`i'] * (1 - expenduse[3,`i']/`coefsum') /* captcrat */
}
matrix rownames estcomplg = labfbl labfwh intm capsm scale
matrix rownames estcompsh = labfsm intm capsm scale
drop _all
matrix estcomplg_tbl = estcomplg 
est2tex estcomplg, replace p(c:/texdocs/tfpest/stata-origs) fancy ready extracols(2 4 6 8)
drop _all
matrix estcompsh_tbl = estcompsh
est2tex estcompsh, replace p(c:/texdocs/tfpest/stata-origs) fancy ready extracols(2 4 6 8)


/* Prepare and output comparison matrix for EOP, no positive investment observations, and no market variables */

foreach proc in "eopc" "posinv" "nomkt" {
  local ldproc "-`proc'"
  if "`proc'"=="eopc" {
    local ldproc ""
    }
  foreach type in b se1 se2 e {
    drop _all
    matload pfct${trd}${fe}${polynl}_`type', path(tfpest/estimate/estmat/pfct`ldproc') over
    matorder pfct013_`type', matrix(`proc'_`type') ifcol(`niv50lst') over
    mat drop pfct013_`type'
  }
  foreach type in b se1 se2 {
    matorder `proc'_`type', matrix(`proc'_`type') ifrow(lnlabfbl lnlabfwh mu lnintmed lnlabfsm bkappa bk  bq  bcapsm) over
    matrix rownames `proc'_`type' =                     lnlabfbl lnlabfwh mu lnintm   lnlabfsm kappa  lnk lnq lncapsm
    }
  local type "e"
    matorder `proc'_`type', matrix(`proc'_`type') ifrow(e(N)_op) over
    matrix rownames `proc'_`type' =                     e(N)_op
}
foreach proc in "eopc" "posinv" "nomkt" {
    local i = `i' + 1
    local type "b"
        matrix `proc'_`type' = `proc'_`type' \ `proc'_e
    foreach type in se1 se2 {
        matrix `proc'_`type' = `proc'_`type' \ J(1,colsof(`proc'_`type'),-999)
        matname `proc'_`type' e(N)_op, row(10) explicit
        }
    }

foreach type in b se1 se2 {
    matorder eopc_`type'  , matrix(eopc_`type')   over ifrow(lnlabfbl lnlabfwh lnk lnq lnintm lnlabfsm lncapsm kappa mu e(N)_op)
    matorder posinv_`type', matrix(posinv_`type') over ifrow(lnlabfbl lnlabfwh lnk lnq lnintm lnlabfsm lncapsm kappa mu e(N)_op)
    matorder nomkt_`type' , matrix(nomkt_`type')  over ifrow(lnlabfbl lnlabfwh lnk lnq lnintm lnlabfsm lncapsm kappa mu e(N)_op)
    }

local niv50lst : colfullnames eopc_b
tokenize "`niv50lst'"
local nivimax : word count `niv50lst'
foreach proc in "eopc" "posinv" "nomkt" {
  foreach type in b se1 se2 {
    local rowmax = rowsof(`proc'_b)
    matrix list`proc'_`type' = `proc'_`type'[1..`rowmax',1]
    forvalues nivi = 2/`nivimax' { 
        matrix list`proc'_`type' = list`proc'_`type' \ `proc'_`type'[1..`rowmax',`nivi']
        }
    local stp = 0
    forvalues nivi = 1/`nivimax' { 
        forvalues row = 1/`rowmax' {
            local rowid = `row' + `stp'
            matname list`proc'_`type' "``nivi'':", rows(`rowid') explicit
            }
        local stp = `stp' + `rowmax'
        }
    matrix colnames list`proc'_`type' = `proc'_`type'
    }
  }

matrix listeopc_se = listeopc_se2
matrix listposinv_se = listposinv_se2
matrix listnomkt_se  = listnomkt_se2

matrix eopproc_tbl = listeopc_b , listeopc_se , listposinv_b , listposinv_se , listnomkt_b , listnomkt_se

preserve
drop _all
est2tex eopproc, ready replace p(c:/texdocs/tfpest/stata-origs) fancy extracols(2 4)
restore

matrix eopetal_tbl = listeopc_b , listeopc_se , listposinv_b , listposinv_se , listfec_b , listfec_se , listolsc_b , listolsc_se

preserve
drop _all
est2tex eopetal, ready replace p(c:/texdocs/tfpest/stata-origs) fancy extracols(2 4 6)
restore
