version 7.0
set matsize 180
set logtype text
capture log close
set more off


/* Choose Settings */
/*-----------------*/

local choice 3
/* Choice 3: FGV-IPA (and general)  Deflators 86-98 */
/*        4: FGV-DI (and general)   Deflators 86-98 */
/*        9: Apply IGP-OG to all variables */
if `choice'==3 {local ext "ipa"}
if `choice'==4 {local ext "di"}
if `choice'==9 {local ext "gen"}

local fdfl 2
/* Choice 0: Foreign inputs and investments deflated with domestic deflators */
/*        1: Foreign input and investment deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
if `fdfl'==0 { local fdfl="" }

global out 2
/* Choice 1: "valadd" */
/* Choice 2: "output" */
if $out==1 {local outtype "valadd"}
if $out==2 {local outtype "output"}

global trd 0
/* Choice 3: Klette & Griliches 96 correction */
/* Choice 2: year dummies ON, trend variables OFF */
/* Choice 1: trend variables ON, time dummies OFF  */
/* Choice 0: trend variables and year dummies OFF */
if $trd==3 {local trdtype "kletgri"}
if $trd==2 {local trdtype "dyears"}
if $trd==1 {local trdtype "trend"}
if $trd==0 {local trdtype "notrend"}

global fe 2
/* Choice 2: fixed effects in OP estimation ON, AND KletGri96 inspired correction */
/* Choice 1: fixed effects in OP estimation ON  */
/* Choice 0: fixed effects in OP estimation OFF */
if $fe==2 & "`esttype'"~="op" {global fe 1}
if $fe~=0 {local fetype "fe"}
else      {local fetype "nofe"}
if $fe==2 {local feout="fecorr"}
else      {local feout="`fetype'"}

global polynl 3
/* Choice 2: Polynomial of 2nd order is used in Step 3 */
/* Choice 3: Polynomial of 3rd order is used in Step 3 */
/* Choice 4: Polynomial of 4th order is used in Step 3 */
/* Choice 5: Polynomial of 5th order is used in Step 3 */
/* Choice 6: Polynomial of 6th order is used in Step 3 */
local polynl=$polynl

global xeff 1
/* Choice 1: Approximate for X-efficiency choice by managers */
/* Choice 0: Approximate for X-efficiency choice by managers */
if $xeff {local xeff="x"}


/* Count of capital coefficient biases */

capture log close
log using "tfpest/summ/summ-estimates.log", replace

foreach type in b se1 se2 e {
    drop _all
    matload pfct${trd}${fe}${polynl}_`type', path(tfpest/estimate/estmat/pfct) over
}

foreach type in b se1 se2 e {
    local rowmax = rowsof(pfct013_`type')
    matrix short_`type' = pfct013_`type'[1..`rowmax',5] , pfct013_`type'[1..`rowmax',10] , pfct013_`type'[1..`rowmax',18] , pfct013_`type'[1..`rowmax',22] , pfct013_`type'[1..`rowmax',27]
    }
foreach matrix in "pfct${trd}${fe}${polynl}" "short" {
    local niv50lst : colfullnames `matrix'_b
    local colmax : word count `niv50lst'
    disp
    disp in yellow "Sectors: " in green `colmax'
    disp
    local kolspos = 0
    local qolspos = 0
    local kolspossig = 0
    local qolspossig = 0
    local kolsneg = 0
    local qolsneg = 0
    local kolsnegsig = 0
    local qolsnegsig = 0
    local col = 0
    foreach sec in `niv50lst' {
        local col = `col' + 1
        if `matrix'_b[16,`col'] > `matrix'_b[7,`col'] { local kolspos = `kolspos' + 1 }
        if `matrix'_b[17,`col'] > `matrix'_b[8,`col'] { local qolspos = `qolspos' + 1 }
        if `matrix'_b[16,`col'] < `matrix'_b[7,`col'] { local kolsneg = `kolsneg' + 1 }
        if `matrix'_b[17,`col'] < `matrix'_b[8,`col'] { local qolsneg = `qolsneg' + 1 }
        local obseop   = `matrix'_e[1,`col']
        local obsols   = `matrix'_e[2,`col']
        local kmeaneop = `matrix'_b[7,`col']
        local kmeanols = `matrix'_b[16,`col']
        local qmeaneop = `matrix'_b[8,`col']
        local qmeanols = `matrix'_b[17,`col']
        local ksdveop  = `matrix'_se2[7,`col'] * sqrt(`obseop')
        local ksdvols  = `matrix'_se1[16,`col'] * sqrt(`obsols')
        local qsdveop  = `matrix'_se2[8,`col'] * sqrt(`obseop')
        local qsdvols  = `matrix'_se1[17,`col'] * sqrt(`obsols')
        qui ttesti `obseop' `kmeaneop' `ksdveop' `obsols' `kmeanols' `ksdvols'
        if `r(p_l)' < .05 { local kolspossig = `kolspossig' + 1 }
        if `r(p_u)' < .05 { local kolsnegsig = `kolsnegsig' + 1 }
        qui ttesti `obseop' `qmeaneop' `qsdveop' `obsols' `qmeanols' `qsdvols'
        if `r(p_l)' < .05 { local qolspossig = `qolspossig' + 1 }
        if `r(p_u)' < .05 { local qolsnegsig = `qolsnegsig' + 1 }
        }
    disp in yellow "Positive bias in OLS equipment coefficient (compared to EOP): " in green `kolspos' in yellow " out of " in green `col' in yellow " cases"
    disp in yellow "Positive bias in OLS structures coefficient (compared to EOP): " in green `qolspos' in yellow " out of " in green `col' in yellow " cases"
    disp in yellow "Significant positive bias in OLS equipment coefficient (comp. to EOP): " in green `kolspossig' in yellow " out of " in green `col' in yellow " cases"
    disp in yellow "Significant positive bias in OLS structures coefficient (comp. to EOP): " in green `qolspossig' in yellow " out of " in green `col' in yellow " cases"
    disp
    disp in yellow "Negative bias in OLS equipment coefficient (compared to EOP): " in green `kolsneg' in yellow " out of " in green `col' in yellow " cases"
    disp in yellow "Negative bias in OLS structures coefficient (compared to EOP): " in green `qolsneg' in yellow " out of " in green `col' in yellow " cases"
    disp in yellow "Significant negative bias in OLS equipment coefficient (comp. to EOP): " in green `kolsnegsig' in yellow " out of " in green `col' in yellow " cases"
    disp in yellow "Significant negative bias in OLS structures coefficient (comp. to EOP): " in green `qolsnegsig' in yellow " out of " in green `col' in yellow " cases"
    }

log close
