version 7
set matsize 180
set logtype text
capture log close
set more off

local esttype "op"
/* Choice "ols": OLS         */
/*        "fe" : Within Eff. */
/*        "op" : Olley-Pakes */

local choice 3
/* Choice 3: FGV-IPA (and general)  Deflators 86-98 */
/*        4: FGV-DI (and general)   Deflators 86-98 */
/*        9: Apply IGP-OG to all variables */
if `choice'==3 {local ext "ipa"}
if `choice'==4 {local ext "di"}
if `choice'==9 {local ext "gen"}

local fdfl 2
/* Choice 0: Foreign inputs and investments deflated with domestic deflators */
/*        1: Foreign input and investment deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
if `fdfl'==0 { local fdfl="" }

global out 2
/* Choice 1: "valadd" */
/* Choice 2: "output" */
if $out==1 {local outtype "valadd"}
if $out==2 {local outtype "output"}

global trd 0
/* Choice 3: Klette & Griliches 96 correction */
/* Choice 2: year dummies ON, trend variables OFF */
/* Choice 1: trend variables ON, time dummies OFF  */
/* Choice 0: trend variables and year dummies OFF */
if $trd==3 {local trdtype "kletgri"}
if $trd==2 {local trdtype "dyears"}
if $trd==1 {local trdtype "trend"}
if $trd==0 {local trdtype "notrend"}

global fe 1
/* Choice 1: fixed effects in OP estimation ON  */
/* Choice 0: fixed effects in OP estimation OFF */
if $fe {local fetype "fe"}
else   {local fetype "nofe"}

global iniols 2
/* Choice 0: Set initial values to FE estimates  */
/* Choice 1: Set initial values to OLS estimates */
/* Choice 2: Set initial values to FE estimates and terms from linear regression */
/* Choice 3: Set initial values to following values */
if $iniols==3 {
    global inikap=.1
    global inik=.2
    global iniq=.2
    }

global polynl 3
/* Choice 2: Polynomial of 2nd order is used in Step 3 */
/* Choice 3: Polynomial of 3rd order is used in Step 3 */
/* Choice 4: Polynomial of 4th order is used in Step 3 */
/* Choice 5: Polynomial of 5th order is used in Step 3 */
/* Choice 6: Polynomial of 6th order is used in Step 3 */
local polynl=$polynl

global xeff 1
/* Choice 1: Approximate for X-efficiency choice by managers */
/* Choice 0: Approximate for X-efficiency choice by managers */
if $xeff {local xeff="x"}


/* Start working */
capture log close
log using "tfpest/summ/summ-survv.log", replace

capture program drop tfpsurvv
program define tfpsurvv
    args esttype ext outtype trdtype fetype polynl
    use "tfpest/estimate/coeff-`ext'-`outtype'-`trdtype'-`fetype'-`polynl'", clear
    disp in green
    disp in green "Data"
    disp in green "----"
    summ indsurvv phat*
    keep if phatprob~=. & phatlogt~=.
    disp in green
    disp in green "Estimation Sample"
    disp in green "-----------------"
    summ indsurvv phat*
    disp in green
    disp in green "Correlations in Estimation Sample"
    disp in green "---------------------------------"
    corr indsurvv phat*
end

tfpsurvv `esttype' `ext'`fdfl' `outtype' `trdtype' `fetype' `polynl'`xeff'    /* Survival probability table */

log close
